@@ -6,6 +6,14 @@
  * The Initial Developer of the Original Code is vtiger.
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
+ * 
+ * ***********************************************************
+*  Module       : Assets
+*  Language     : ES Spanish
+*  Version      : vt5.4.0
+*  Created Date : 2012-02-27
+*  Author       : JPL TSolucio, S.L.
+*  License      : MPL 1.1
  ************************************************************************************/
 
 $mod_strings = Array(
@@ -37,6 +45,6 @@ $mod_strings = Array(
 /*picklist values*/
 'In Service'=>'En Servicio',
 'Out-of-service'=>'Fuera de servicio',
-
+'Assets ID'=>'Id Recurso',
 );
 ?>
\ No newline at end of file
