@@ -64,12 +64,12 @@ $mod_strings = Array(
 'accountindustry' => 'Cuentas por Actividad',
 'productcategory' => 'Productos por Categoría',
 'productbyqtyinstock' => 'Productos por Cantidad en stock',
-'productbypo' => 'Productos por Órdenes de Compra',
+'productbypo' => 'Productos por Ordenes de Compra',
 'productbyquotes' => 'Productos por Presupuestos',
 'productbyinvoice' => 'Productos por Facturas',
 'sobyaccounts' => 'Pedidos por Cuenta',
 'sobystatus' => 'Pedidos por Estado',
-'pobystatus' => 'Órdenes de Compra por Cuenta',
+'pobystatus' => 'Ordenes de Compra por Cuenta',
 'quotesbyaccounts' => 'Presupuestos por Cuenta',
 'quotesbystage' => 'Presupuestos por Estado',
 'invoicebyacnts' => 'Facturas por Cuenta',
