@@ -9,7 +9,7 @@
  ************************************************************************************/
 global $currentModule;
 
-checkFileAccess("modules/$currentModule/ListView.php");
+checkFileAccessForInclusion("modules/$currentModule/ListView.php");
 include_once("modules/$currentModule/ListView.php");
 
 ?>
\ No newline at end of file
