@@ -1,19 +1,19 @@
 <?php
 /***********************************************************
 *  Module       : PBX Manager
-*  Language     : Francais
-*  Version      : 5.1.0 GA*  Created Date : 2009-06-23 21:36:13 
-*  Last change  : 2009-07-21 00:49:17
-*  Author       : french-vtiger.fr 
+*  Language     : French
+*  Version      : 5.4.0 
 *  License      : GPL
-
+*  Author       : ABOnline solutions http://www.vtiger-crm.fr
 ***********************************************************/
+
 $mod_strings = Array(
 	'Asterisk' => 'Asterisk',
 	'LBL_ASTERISK_INFORMATION' => 'Information Asterisk',
-	'Call From' => 'Appel de',
-	'Call To' => 'Appel vers',
-	'Time Of Call' => 'Date de l\'appel',
+	'Call From' => 'Appel entrant de',
+	'Call To' => 'Appel sortant vers',
+	'Time Of Call' => 'Date et heure de l\'appel',
+	'PBXManager ID'=>'PBX ID',
 );
 
-?>
+?>
\ No newline at end of file
