@@ -6,6 +6,14 @@
  * The Initial Developer of the Original Code is vtiger.
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
+ * 
+ * ***********************************************************
+*  Module       : ProjectMilestone
+*  Language     : ES Spanish
+*  Version      : vt5.4.0
+*  Created Date : 2012-02-27
+*  Author       : JPL TSolucio, S.L.
+*  License      : MPL 1.1
  ************************************************************************************/
 $mod_strings = Array(
 	 
@@ -40,6 +48,7 @@ $mod_strings = Array(
     'Project Milestone Name' => 'Nombre Hito',
 	'Project Milestone No' => 'Nº Hito',
     'Milestone Date'=>'Fecha Hito',
+	'ProjectMilestone ID' => 'Id Hito',
 
 );
 
