@@ -66,46 +66,66 @@ function changeModule(pickmodule)
 
 function massRestore()
 {
-	var select_options = document.getElementsByName('selected_id');
-	var x = select_options.length;		
-	idstring = "";
-	xx = 0;
-	for(i = 0; i < x ; i++)
-	{
-		if(select_options[i].checked)
-		{
-			idstring = select_options[i].value +","+idstring
-				xx++
+	var excludedRecords = document.getElementById('excludedRecords').value;
+	var select_options  =  document.getElementById('allselectedboxes').value;
+	var searchurl = document.getElementById('search_url').value;
+	var numOfRows = document.getElementById('numOfRows').value;
+	var idstring = "";
+	if(select_options=='all'){
+		idstring = select_options;
+		var skiprecords = excludedRecords.split(";");
+		var count = skiprecords.length;
+		if(count > 1){
+			count = numOfRows - count + 1;
 		}
+		else{
+			count = numOfRows;
+		}
+	} else {
+		var x = select_options.split(";");
+		var count=x.length
+		if (count > 1)
+		{
+			document.getElementById('idlist').value=select_options;
+			idstring = select_options;
+		} else{
+			alert(mod_alert_arr.SELECT_ATLEAST_ONE_ENTITY);
+			return false;
+		}
+		count = count-1;
 	}
+	if(count > getMaxMassOperationLimit())
+	{
+		var confirm_str = alert_arr.MORE_THAN_500;
+		if(confirm(confirm_str)) var confirm_status = true;
+		else return false;
+	}
+	else confirm_status = true;
 
-	if (xx != 0)
-	{
-		document.getElementById('idlist').value=idstring;
-	}
-	else
-	{
-		alert(mod_alert_arr.SELECT_ATLEAST_ONE_ENTITY);
-		return false;
-	}
-
-	var selectmodule = $('selected_module').value;
-	if(confirm(mod_alert_arr.MSG_RESTORE_CONFIRMATION + " " + xx + " " + selectmodule + "?"))
-	{
-		$("status").style.display="inline";
-		new Ajax.Request(
-       	        'index.php',
-               	{queue: {position: 'end', scope: 'command'},
-                       	method: 'post',
-                        postBody: 'action=RecycleBinAjax&module=RecycleBin&mode=ajax&file=Restoration&idlist='+idstring+'&selectmodule='+selectmodule,
-       	                onComplete: function(response) 
-						{
-							$("status").style.display="none";
-							$("modules_datas").innerHTML=response.responseText;
-							$("search_ajax").innerHTML = '';
-                        }
-       	        }
-	        );
+	if(confirm_status){
+		var selectmodule = $('selected_module').value;
+		var selectmoduletranslated =  $('selected_module_translated').value;
+		if(confirm(mod_alert_arr.MSG_RESTORE_CONFIRMATION + " " + count + " " + selectmoduletranslated + "?"))
+		{
+			$("status").style.display="inline";
+			new Ajax.Request(
+				'index.php',
+				{
+					queue: {
+						position: 'end',
+						scope: 'command'
+					},
+					method: 'post',
+					postBody: 'action=RecycleBinAjax&module=RecycleBin&mode=ajax&file=Restoration&idlist='+idstring+'&selectmodule='+selectmodule+'&excludedRecords='+excludedRecords,
+					onComplete: function(response)
+					{
+						$("status").style.display="none";
+						$("modules_datas").innerHTML=response.responseText;
+						$("search_ajax").innerHTML = '';
+					}
+				}
+				);
+		}
 	}
 }
 
@@ -119,7 +139,7 @@ function restore(entityid,select_module)
 	        {
 				queue: {position: 'end', scope: 'command'},
 	            method: 'post',
-	            postBody: 'action=RecycleBinAjax&module=RecycleBin&mode=ajax&file=Restoration&entityid='+entityid+'&selectmodule='+select_module,
+	            postBody: 'action=RecycleBinAjax&module=RecycleBin&mode=ajax&file=Restoration&idlist='+entityid+'&selectmodule='+select_module,
 		        onComplete: function(response) {
 		            $("status").style.display="none";
 		            $("modules_datas").innerHTML=response.responseText;
@@ -132,26 +152,44 @@ function restore(entityid,select_module)
 
 function getListViewEntries_js(module,url)
 {
+	var all_selected = $('allselectedboxes').value;
+	var excludedRecords = $('excludedRecords').value;
+
 	$("status").show();
 	var selected_module = $("select_module").value;
 	var urlstring = "&selected_module=" + selected_module;
 	<!-- Ticket 6330 -->
 	if($('search_url').value!='')
-        	urlstring = $('search_url').value+"&selected_module="+selected_module;
-	
-	
+		urlstring = $('search_url').value+"&selected_module="+selected_module;
+
 	new Ajax.Request(
 		'index.php',
-		{ queue: { position: 'end', scope: 'command' },
+		{queue: {position: 'end', scope: 'command'},
 			method: 'post',
-			postBody : "module=RecycleBin&action=RecycleBinAjax&file=ListView&mode=ajax&ajax=true&"+url+urlstring,
+			postBody : "module=RecycleBin&action=RecycleBinAjax&file=ListView&mode=ajax&ajax=true&"+url+urlstring+"&allselobjs="+all_selected+"&excludedRecords="+excludedRecords,
 			onComplete: function(response) {
 				$("status").hide();
-            	if($("modules_datas")) {
-            		$("modules_datas").innerHTML = response.responseText;
-            	}
-            }
-        }
+				if($("modules_datas")) {
+					$("modules_datas").innerHTML = response.responseText;
+				}
+				if(all_selected == 'all'){
+					$('linkForSelectAll').show();
+					$('selectAllRec').style.display='none';
+					$('deSelectAllRec').style.display='inline';
+					var exculdedArray=excludedRecords.split(';');
+					var obj = document.getElementsByName('selected_id');
+					if (obj) {
+						var viewForSelectLink = showSelectAllLink(obj,exculdedArray);
+						$('selectCurrentPageRec').checked = viewForSelectLink;
+						$('allselectedboxes').value='all';
+						$('excludedRecords').value = $('excludedRecords').value+excludedRecords;
+					}
+				}else{
+					$('linkForSelectAll').hide();
+					update_selected_checkbox();
+				}
+			}
+		}
 	);
 }
 
@@ -165,16 +203,16 @@ function alphabetic(module,url,dataid)
         }
 	var selectedmodule = $('select_module').options[$('select_module').selectedIndex].value 
 	url += '&selected_module='+selectedmodule;
-        getObj(dataid).className = 'searchAlphselected';
+	getObj(dataid).className = 'searchAlphselected';
 	$("status").style.display="inline";
 	new Ajax.Request(
 		'index.php',
 		{queue: {position: 'end', scope: 'command'},
 			method: 'post',
-                        postBody:"module="+module+"&action="+module+"Ajax&file=index&mode=ajax&ajax=true&"+url,
+			postBody:"module="+module+"&action="+module+"Ajax&file=index&mode=ajax&ajax=true&"+url,
 			onComplete: function(response) {
 				$("status").style.display="none";
-                                $("modules_datas").innerHTML=response.responseText;
+				$("modules_datas").innerHTML=response.responseText;
 				$("search_ajax").innerHTML = '';
 			}
 		}
