@@ -8,15 +8,13 @@
  * All Rights Reserved.
  ********************************************************************************/
 
-if(isset($_REQUEST['idlist']) && $_REQUEST['idlist'] != '')
-{
-	$idlists = explode(',',$_REQUEST[idlist]);
-}elseif(isset($_REQUEST['entityid']) && $_REQUEST['entityid'] != '')
-{
-	$idlists = Array($_REQUEST['entityid']);
-}
+require_once('RecycleBinUtils.php');
 
+$idlist=vtlib_purify($_REQUEST['idlist']);
+$excludedRecords=vtlib_purify($_REQUEST['excludedRecords']);
 $selected_module = vtlib_purify($_REQUEST['selectmodule']);
+$idlists = getSelectedRecordIds($_REQUEST,$selected_module,$idlist,$excludedRecords);
+
 require_once('data/CRMEntity.php');
 $focus = CRMEntity::getInstance($selected_module);
 
@@ -29,4 +27,4 @@ for($i=0;$i<count($idlists);$i++) {
 $parenttab = getParentTab();
 
 header("Location: index.php?module=RecycleBin&action=RecycleBinAjax&file=index&parenttab=$parenttab&mode=ajax&selected_module=$selected_module");
-?>
+?>
\ No newline at end of file
