@@ -14,7 +14,7 @@ $mod_strings = Array(
 'Recycle Bin' => 'Papelera de Reciclaje',
 'MSG_EMPTY_RB_CONFIRMATION'=>'¿Estás seguro que quieres eliminar Permanentemente TODOS los registros borrados de la base de datos?',
 'LBL_SELECT_MODULE'=>'Selecciona Módulo',
-'LBL_EMPTY_MODULE'=>'No se han encontrado registros para restaurar en el modulo',
+'LBL_EMPTY_MODULE'=>'No se han encontrado registros en el módulo para restaurar',
 'LBL_MASS_RESTORE'=>'Restaurar',
 'LBL_EMPTY_RECYCLEBIN'=>'Vaciar Papelera de Reciclaje',
 'LNK_RESTORE'=>'restaurar',
