@@ -5,14 +5,13 @@
  * The Initial Developer of the Original Code is vtiger.
  * Portions created by vtiger are Copyright (C) vtiger.
  * *********************************************************************************
-/*********************************************************************************
- * $Header:  E:\D_root\Dokumentumok\vtiger520\hungarian52\trunk\modules\RecycleBin\language\hu_hu.lang.js - 21:43 2010.05.21. $
- * Description:  Defines the Hungarian language pack for the RecycleBin module vtiger 5.2.0
+ * $Header:  \modules\RecycleBin\language\hu_hu.lang.js - 12:11 2011.11.12. $
+ * Description:  Defines the Hungarian language pack for the RecycleBin module vtiger 5.3.x
  *
  * Contributor(s): Istvan Holbok,  e-mail: holbok@gmail.com , mobil: +3670-3420900 , Skype: holboki
  ********************************************************************************/
 
-var mod_alert_arr = {       
-	SELECT_ATLEAST_ONE_ENTITY:'Kérjük, hogy legalább egy tételt válassz ki.',
-	MSG_RESTORE_CONFIRMATION:'Biztos vagy abban, hogy helyre akarod állítani a kiválasztott '
-};
\ No newline at end of file
+var mod_alert_arr = {
+	'SELECT_ATLEAST_ONE_ENTITY' : 'Kérjük, válasszon legalább egy személy',
+	'MSG_RESTORE_CONFIRMATION' : 'Biztos benne, hogy vissza akarja állítani a kiválasztott'
+};
