@@ -45,26 +45,40 @@ class ServiceContracts extends CRMEntity {
 		/* Format: Field Label => Array(tablename, columnname) */
 		// tablename should not have prefix 'vtiger_'
 		'Subject' => Array('servicecontracts', 'subject'),
-		'Assigned To' => Array('crmentity','smownerid')
+		'Assigned To' => Array('crmentity','smownerid'),
+		'Contract No' => Array('servicecontracts','contract_no'),
+		'Used Units' => Array('servicecontracts','used_units'),
+		'Total Units' => Array('servicecontracts','total_units')
 	);
 	var $list_fields_name = Array (
 		/* Format: Field Label => fieldname */
 		'Subject' => 'subject',
-		'Assigned To' => 'assigned_user_id'
+		'Assigned To' => 'assigned_user_id',
+		'Contract No' =>  'contract_no',
+		'Used Units' => 'used_units',
+		'Total Units' => 'total_units'
 	);
 
-	// Make the field link to detail view 
+	// Make the field link to detail view
 	var $list_link_field = 'subject';
 
 	// For Popup listview and UI type support
 	var $search_fields = Array(
 		/* Format: Field Label => Array(tablename, columnname) */
 		// tablename should not have prefix 'vtiger_'
-		'Subject' => Array('servicecontracts', 'subject')
+		'Subject' => Array('servicecontracts', 'subject'),
+		'Contract No' => Array('servicecontracts', 'contract_no'),
+		'Assigned To' => Array('vtiger_crmentity','assigned_user_id'),
+		'Used Units' => Array('servicecontracts','used_units'),
+		'Total Units' => Array('servicecontracts','total_units')
 	);
 	var $search_fields_name = Array (
 		/* Format: Field Label => fieldname */
-		'Subject' => 'subject'
+		'Subject' => 'subject',
+		'Contract No' => 'contract_no',
+		'Assigned To' => 'assigned_user_id',
+		'Used Units' => 'used_units',
+		'Total Units' => 'total_units'
 	);
 
 	// For Popup window record selection
@@ -85,7 +99,7 @@ class ServiceContracts extends CRMEntity {
 	// Used when enabling/disabling the mandatory fields for the module.
 	// Refers to vtiger_field.fieldname values.
 	var $mandatory_fields = Array('subject','assigned_user_id');
-	
+
 	// Callback function list during Importing
 	var $special_functions = Array('set_import_assigned_user');
 
@@ -99,33 +113,16 @@ class ServiceContracts extends CRMEntity {
 		$this->log = $log;
 	}
 
-	function getSortOrder() {
-		global $currentModule;
-
-		$sortorder = $this->default_sort_order;
-		if($_REQUEST['sorder']) $sortorder = $this->db->sql_escape_string($_REQUEST['sorder']);
-		else if($_SESSION[$currentModule.'_Sort_Order']) 
-			$sortorder = $_SESSION[$currentModule.'_Sort_Order'];
-
-		return $sortorder;
-	}
-
-	function getOrderBy() {
-		global $currentModule;
-		
-		$use_default_order_by = '';		
-		if(PerformancePrefs::getBoolean('LISTVIEW_DEFAULT_SORTING', true)) {
-			$use_default_order_by = $this->default_order_by;
-		}
-		
-		$orderby = $use_default_order_by;
-		if($_REQUEST['order_by']) $orderby = $this->db->sql_escape_string($_REQUEST['order_by']);
-		else if($_SESSION[$currentModule.'_Order_By'])
-			$orderby = $_SESSION[$currentModule.'_Order_By'];
-		return $orderby;
-	}
-
 	function save_module($module) {
+		$return_action = $_REQUEST['return_action'];
+		$for_module = $_REQUEST['return_module'];
+		$for_crmid  = $_REQUEST['return_id'];
+		if ($return_action && $for_module && $for_crmid) {
+			if ($for_module == 'HelpDesk') {
+				$on_focus = CRMEntity::getInstance($for_module);
+				$on_focus->save_related_module($for_module, $for_crmid, $module, $this->id);
+			}
+		}
 	}
 
 	/**
@@ -152,7 +149,7 @@ class ServiceContracts extends CRMEntity {
 		// Consider custom table join as well.
 		if(!empty($this->customFieldTable)) {
 			$query .= " INNER JOIN ".$this->customFieldTable[0]." ON ".$this->customFieldTable[0].'.'.$this->customFieldTable[1] .
-				      " = $this->table_name.$this->table_index"; 
+				      " = $this->table_name.$this->table_index";
 		}
 		$query .= " LEFT JOIN vtiger_users ON vtiger_users.id = vtiger_crmentity.smownerid";
 		$query .= " LEFT JOIN vtiger_groups ON vtiger_groups.groupid = vtiger_crmentity.smownerid";
@@ -161,19 +158,19 @@ class ServiceContracts extends CRMEntity {
 				" INNER JOIN vtiger_fieldmodulerel ON vtiger_fieldmodulerel.fieldid = vtiger_field.fieldid" .
 				" WHERE uitype='10' AND vtiger_fieldmodulerel.module=?", array($module));
 		$linkedFieldsCount = $this->db->num_rows($linkedModulesQuery);
-		
+
 		for($i=0; $i<$linkedFieldsCount; $i++) {
 			$related_module = $this->db->query_result($linkedModulesQuery, $i, 'relmodule');
 			$fieldname = $this->db->query_result($linkedModulesQuery, $i, 'fieldname');
 			$columnname = $this->db->query_result($linkedModulesQuery, $i, 'columnname');
-			
+
 			$other = CRMEntity::getInstance($related_module);
 			vtlib_setup_modulevars($related_module, $other);
-			
+
 			$query .= " LEFT JOIN $other->table_name ON $other->table_name.$other->table_index =".
 					"$this->table_name.$columnname";
 		}
-		
+
 		global $current_user;
 		$query .= $this->getNonAdminAccessControlQuery($module,$current_user);
 		$query .= "WHERE vtiger_crmentity.deleted = 0 ".$where;
@@ -191,31 +188,31 @@ class ServiceContracts extends CRMEntity {
 		$sec_query = '';
 		$tabid = getTabid($module);
 
-		if($is_admin==false && $profileGlobalPermission[1] == 1 && $profileGlobalPermission[2] == 1 
+		if($is_admin==false && $profileGlobalPermission[1] == 1 && $profileGlobalPermission[2] == 1
 			&& $defaultOrgSharingPermission[$tabid] == 3) {
 
-				$sec_query .= " AND (vtiger_crmentity.smownerid in($current_user->id) OR vtiger_crmentity.smownerid IN 
+				$sec_query .= " AND (vtiger_crmentity.smownerid in($current_user->id) OR vtiger_crmentity.smownerid IN
 					(
-						SELECT vtiger_user2role.userid FROM vtiger_user2role 
-						INNER JOIN vtiger_users ON vtiger_users.id=vtiger_user2role.userid 
-						INNER JOIN vtiger_role ON vtiger_role.roleid=vtiger_user2role.roleid 
+						SELECT vtiger_user2role.userid FROM vtiger_user2role
+						INNER JOIN vtiger_users ON vtiger_users.id=vtiger_user2role.userid
+						INNER JOIN vtiger_role ON vtiger_role.roleid=vtiger_user2role.roleid
 						WHERE vtiger_role.parentrole LIKE '".$current_user_parent_role_seq."::%'
-					) 
-					OR vtiger_crmentity.smownerid IN 
+					)
+					OR vtiger_crmentity.smownerid IN
 					(
-						SELECT shareduserid FROM vtiger_tmp_read_user_sharing_per 
+						SELECT shareduserid FROM vtiger_tmp_read_user_sharing_per
 						WHERE userid=".$current_user->id." AND tabid=".$tabid."
-					) 
-					OR 
+					)
+					OR
 						(";
-		
+
 					// Build the query based on the group association of current user.
 					if(sizeof($current_user_groups) > 0) {
 						$sec_query .= " vtiger_groups.groupid IN (". implode(",", $current_user_groups) .") OR ";
 					}
-					$sec_query .= " vtiger_groups.groupid IN 
+					$sec_query .= " vtiger_groups.groupid IN
 						(
-							SELECT vtiger_tmp_read_group_sharing_per.sharedgroupid 
+							SELECT vtiger_tmp_read_group_sharing_per.sharedgroupid
 							FROM vtiger_tmp_read_group_sharing_per
 							WHERE userid=".$current_user->id." and tabid=".$tabid."
 						)";
@@ -232,26 +229,26 @@ class ServiceContracts extends CRMEntity {
 	{
 		global $current_user,$currentModule;
 		$thismodule = $_REQUEST['module'];
-		
+
 		include("include/utils/ExportUtils.php");
 
 		//To get the Permitted fields query and the permitted fields list
 		$sql = getPermittedFieldsQuery($thismodule, "detail_view");
-		
+
 		$fields_list = getFieldsListFromQuery($sql);
 
-		$query = "SELECT $fields_list, vtiger_users.user_name AS user_name 
+		$query = "SELECT $fields_list, vtiger_users.user_name AS user_name
 					FROM vtiger_crmentity INNER JOIN $this->table_name ON vtiger_crmentity.crmid=$this->table_name.$this->table_index";
 
 		if(!empty($this->customFieldTable)) {
 			$query .= " INNER JOIN ".$this->customFieldTable[0]." ON ".$this->customFieldTable[0].'.'.$this->customFieldTable[1] .
-				      " = $this->table_name.$this->table_index"; 
+				      " = $this->table_name.$this->table_index";
 		}
 
 		$query .= " LEFT JOIN vtiger_groups ON vtiger_groups.groupid = vtiger_crmentity.smownerid";
 		$query .= " LEFT JOIN vtiger_users ON vtiger_crmentity.smownerid = vtiger_users.id and ".
 		"vtiger_users.status='Active'";
-		
+
 		$linkedModulesQuery = $this->db->pquery("SELECT distinct fieldname, columnname, relmodule FROM vtiger_field" .
 				" INNER JOIN vtiger_fieldmodulerel ON vtiger_fieldmodulerel.fieldid = vtiger_field.fieldid" .
 				" WHERE uitype='10' AND vtiger_fieldmodulerel.module=?", array($thismodule));
@@ -261,10 +258,10 @@ class ServiceContracts extends CRMEntity {
 			$related_module = $this->db->query_result($linkedModulesQuery, $i, 'relmodule');
 			$fieldname = $this->db->query_result($linkedModulesQuery, $i, 'fieldname');
 			$columnname = $this->db->query_result($linkedModulesQuery, $i, 'columnname');
-			
+
 			$other = CRMEntity::getInstance($related_module);
 			vtlib_setup_modulevars($related_module, $other);
-			
+
 			$query .= " LEFT JOIN $other->table_name ON $other->table_name.$other->table_index = ".
 					"$this->table_name.$columnname";
 		}
@@ -279,71 +276,6 @@ class ServiceContracts extends CRMEntity {
 	}
 
 	/**
-	 * Initialize this instance for importing.
-	 */
-	function initImport($module) {
-		$this->db = new PearDatabase();
-		$this->initImportableFields($module);
-	}
-
-	/**
-	 * Create list query to be shown at the last step of the import.
-	 * Called From: modules/Import/UserLastImport.php
-	 */
-	function create_import_query($module) {
-		global $current_user;
-		$query = "SELECT vtiger_crmentity.crmid, case when (vtiger_users.user_name not like '') then vtiger_users.user_name else vtiger_groups.groupname end as user_name, $this->table_name.* FROM $this->table_name
-			INNER JOIN vtiger_crmentity ON vtiger_crmentity.crmid = $this->table_name.$this->table_index
-			LEFT JOIN vtiger_users_last_import ON vtiger_users_last_import.bean_id=vtiger_crmentity.crmid
-			LEFT JOIN vtiger_users ON vtiger_users.id = vtiger_crmentity.smownerid
-			LEFT JOIN vtiger_groups ON vtiger_groups.groupid = vtiger_crmentity.smownerid
-			WHERE vtiger_users_last_import.assigned_user_id='$current_user->id'
-			AND vtiger_users_last_import.bean_type='$module'
-			AND vtiger_users_last_import.deleted=0";
-		return $query;
-	}
-
-	/**
-	 * Delete the last imported records.
-	 */
-	function undo_import($module, $user_id) {
-		global $adb;
-		$count = 0;
-		$query1 = "select bean_id from vtiger_users_last_import where assigned_user_id=? AND bean_type='$module' AND deleted=0";
-		$result1 = $adb->pquery($query1, array($user_id)) or die("Error getting last import for undo: ".mysql_error()); 
-		while ( $row1 = $adb->fetchByAssoc($result1))
-		{
-			$query2 = "update vtiger_crmentity set deleted=1 where crmid=?";
-			$result2 = $adb->pquery($query2, array($row1['bean_id'])) or die("Error undoing last import: ".mysql_error()); 
-			$count++;			
-		}
-		return $count;
-	}
-
-	/**
-	 * Function which will set the assigned user id for import record.
-	 */
-	function set_import_assigned_user()
-	{
-		global $current_user, $adb;
-		$record_user = $this->column_fields["assigned_user_id"];
-		
-		if($record_user != $current_user->id){
-			$sqlresult = $adb->pquery("select id from vtiger_users where id = ? union select groupid as id from vtiger_groups where groupid = ?", array($record_user, $record_user));
-			if($this->db->num_rows($sqlresult)!= 1) {
-				$this->column_fields["assigned_user_id"] = $current_user->id;
-			} else {			
-				$row = $adb->fetchByAssoc($sqlresult, -1, false);
-				if (isset($row['id']) && $row['id'] != -1) {
-					$this->column_fields["assigned_user_id"] = $row['id'];
-				} else {
-					$this->column_fields["assigned_user_id"] = $current_user->id;
-				}
-			}
-		}
-	}
-	
-	/** 
 	 * Function which will give the basic query to find duplicates
 	 */
 	function getDuplicatesQuery($module,$table_cols,$field_values,$ui_type_arr,$select_cols='') {
@@ -359,14 +291,14 @@ class ServiceContracts extends CRMEntity {
 		// Consider custom table join as well.
 		if(isset($this->customFieldTable)) {
 			$from_clause .= " INNER JOIN ".$this->customFieldTable[0]." ON ".$this->customFieldTable[0].'.'.$this->customFieldTable[1] .
-				      " = $this->table_name.$this->table_index"; 
+				      " = $this->table_name.$this->table_index";
 		}
 		$from_clause .= " LEFT JOIN vtiger_users ON vtiger_users.id = vtiger_crmentity.smownerid
 				LEFT JOIN vtiger_groups ON vtiger_groups.groupid = vtiger_crmentity.smownerid";
-		
+
 		$where_clause = "	WHERE vtiger_crmentity.deleted = 0";
 		$where_clause .= $this->getListViewSecurityParameter($module);
-					
+
 		if (isset($select_cols) && trim($select_cols) != '') {
 			$sub_query = "SELECT $select_cols FROM  $this->table_name AS t " .
 				" INNER JOIN vtiger_crmentity AS crm ON crm.crmid = t.".$this->table_index;
@@ -374,50 +306,53 @@ class ServiceContracts extends CRMEntity {
 			if(isset($this->customFieldTable)) {
 				$sub_query .= " INNER JOIN ".$this->customFieldTable[0]." tcf ON tcf.".$this->customFieldTable[1]." = t.$this->table_index";
 			}
-			$sub_query .= " WHERE crm.deleted=0 GROUP BY $select_cols HAVING COUNT(*)>1";	
+			$sub_query .= " WHERE crm.deleted=0 GROUP BY $select_cols HAVING COUNT(*)>1";
 		} else {
 			$sub_query = "SELECT $table_cols $from_clause $where_clause GROUP BY $table_cols HAVING COUNT(*)>1";
 		}
-		
+
 		$query = $select_clause . $from_clause .
 					" LEFT JOIN vtiger_users_last_import ON vtiger_users_last_import.bean_id=" . $this->table_name .".".$this->table_index .
 					" INNER JOIN (" . $sub_query . ") AS temp ON ".get_on_clause($field_values,$ui_type_arr,$module) .
 					$where_clause .
 					" ORDER BY $table_cols,". $this->table_name .".".$this->table_index ." ASC";
-					
-		return $query;		
+
+		return $query;
 	}
 
 	/**
 	* Invoked when special actions are performed on the module.
 	* @param String Module name
 	* @param String Event Type
-	*/	
+	*/
 	function vtlib_handler($moduleName, $eventType) {
- 					
-		require_once('include/utils/utils.php');			
+
+		require_once('include/utils/utils.php');
 		global $adb;
- 		
+
  		if($eventType == 'module.postinstall') {
 			require_once('vtlib/Vtiger/Module.php');
-				
+
 			$moduleInstance = Vtiger_Module::getInstance($moduleName);
-			
+
 			$accModuleInstance = Vtiger_Module::getInstance('Accounts');
 			$accModuleInstance->setRelatedList($moduleInstance,'Service Contracts',array('add'),'get_dependents_list');
-			
+
 			$conModuleInstance = Vtiger_Module::getInstance('Contacts');
 			$conModuleInstance->setRelatedList($moduleInstance,'Service Contracts',array('add'),'get_dependents_list');
-			
+
+			$helpDeskInstance = Vtiger_Module::getInstance("HelpDesk");
+			$helpDeskInstance->setRelatedList($moduleInstance,"Service Contracts",Array('ADD','SELECT'));
+
 			// Initialize module sequence for the module
 			$adb->pquery("INSERT into vtiger_modentity_num values(?,?,?,?,?,?)",array($adb->getUniqueId("vtiger_modentity_num"),$moduleName,'SERCON',1,1,1));
-			
+
 			// Make the picklist value 'Complete' for status as non-editable
 			$adb->query("UPDATE vtiger_contract_status SET presence=0 WHERE contract_status='Complete'");
-			
+
 			// Mark the module as Standard module
 			$adb->pquery('UPDATE vtiger_tab SET customized=0 WHERE name=?', array($moduleName));
-			
+
 		} else if($eventType == 'module.disabled') {
 			$em = new VTEventsManager($adb);
 			$em->setHandlerInActive('ServiceContractsHandler');
@@ -435,24 +370,28 @@ class ServiceContracts extends CRMEntity {
 		}
  	}
 
-	/** 
+	/**
 	 * Handle saving related module information.
 	 * NOTE: This function has been added to CRMEntity (base class).
 	 * You can override the behavior by re-defining it here.
 	 */
-	function save_related_module($module, $crmid, $with_module, $with_crmid) { 
-	 	parent::save_related_module($module, $crmid, $with_module, $with_crmid);
-	 	if ($with_module == 'HelpDesk') {
-	 		$this->updateHelpDeskRelatedTo($crmid,$with_crmid);
-	 		$this->updateServiceContractState($crmid);
-	 	}	
+	function save_related_module($module, $crmid, $with_module, $with_crmids) {
+
+		if(!is_array($with_crmids)) $with_crmids = Array($with_crmids);
+		foreach($with_crmids as $with_crmid) {
+			parent::save_related_module($module, $crmid, $with_module, $with_crmid);
+			if ($with_module == 'HelpDesk') {
+				$this->updateHelpDeskRelatedTo($crmid,$with_crmid);
+				$this->updateServiceContractState($crmid);
+			}
+		}
 	 }
-	 
+
 	 // Function to Update the parent_id of HelpDesk with sc_related_to of ServiceContracts if the parent_id is not set.
 	 function updateHelpDeskRelatedTo($focusId, $entityIds) {
 		global $log;
 		$log->debug("Entering into function updateHelpDeskRelatedTo(".$entityIds.").");
-		
+
 		if(!is_array($entityIds)) $entityIds = array($entityIds);
 		$selectTicketsQuery = "SELECT ticketid FROM vtiger_troubletickets WHERE (parent_id IS NULL OR parent_id = 0) AND ticketid IN (" . generateQuestionMarks($entityIds) .")";
 		$selectTicketsResult = $this->db->pquery($selectTicketsQuery, array($entityIds));
@@ -464,17 +403,24 @@ class ServiceContracts extends CRMEntity {
 						" AND vtiger_servicecontracts.servicecontractsid = ? AND vtiger_troubletickets.ticketid = ?";
 			$updateResult = $this->db->pquery($updateQuery, array($focusId, $ticketId));
 		}
-		
+
 		$log->debug("Exit from function updateHelpDeskRelatedTo(".$entityIds.")");
 	}
-	 
+
 	// Function to Compute and Update the Used Units and Progress of the Service Contract based on all the related Trouble tickets.
 	function updateServiceContractState($focusId) {
 		$this->id = $focusId;
 		$this->retrieve_entity_info($focusId,'ServiceContracts');
-		
-		$contractTicketsResult = $this->db->pquery("SELECT relcrmid FROM vtiger_crmentityrel WHERE module = 'ServiceContracts' AND crmid = ?" .
-								" AND relmodule = 'HelpDesk'", array($focusId));
+
+		$contractTicketsResult = $this->db->pquery("SELECT relcrmid FROM vtiger_crmentityrel
+														WHERE module = 'ServiceContracts'
+														AND relmodule = 'HelpDesk' AND crmid = ?
+													UNION
+														SELECT crmid FROM vtiger_crmentityrel
+														WHERE relmodule = 'ServiceContracts'
+														AND module = 'HelpDesk' AND relcrmid = ?",
+													array($focusId,$focusId));
+
 		$noOfTickets = $this->db->num_rows($contractTicketsResult);
 		$ticketFocus = CRMEntity::getInstance('HelpDesk');
 		$totalUsedUnits = 0;
@@ -489,15 +435,15 @@ class ServiceContracts extends CRMEntity {
 			}
 		}
 		$this->updateUsedUnits($totalUsedUnits);
-		
+
 		$this->calculateProgress();
 	}
-	
+
 	// Function to Upate the Used Units of the Service Contract based on the given Ticket id.
 	function computeUsedUnits($ticketData, $operator='+') {
 		$trackingUnit = strtolower($this->column_fields['tracking_unit']);
 		$workingHoursPerDay = 24;
-		
+
 		$usedUnits = 0;
 		if ($trackingUnit == 'incidents') {
 			$usedUnits = 1;
@@ -506,39 +452,39 @@ class ServiceContracts extends CRMEntity {
 				$usedUnits = $ticketData['days'];
 			} elseif(!empty($ticketData['hours'])) {
 				$usedUnits = $ticketData['hours'] / $workingHoursPerDay;
-			} 						
+			}
 		} elseif ($trackingUnit == 'hours') {
 			if(!empty($ticketData['hours'])) {
 				$usedUnits = $ticketData['hours'];
 			} elseif(!empty($ticketData['days'])) {
 				$usedUnits = $ticketData['days'] * $workingHoursPerDay;
-			} 
+			}
 		}
 		return $usedUnits;
 	}
-	
+
 	// Function to Upate the Used Units of the Service Contract.
 	function updateUsedUnits($usedUnits) {
 		$this->column_fields['used_units'] = $usedUnits;
 		$updateQuery = "UPDATE vtiger_servicecontracts SET used_units = $usedUnits WHERE servicecontractsid = ?";
 		$this->db->pquery($updateQuery, array($this->id));
 	}
-	
+
 	// Function to Calculate the End Date, Planned Duration, Actual Duration and Progress of a Service Contract
-	function calculateProgress() {				
+	function calculateProgress() {
 		$updateCols = array();
 		$updateParams = array();
-		
+
 		$startDate = $this->column_fields['start_date'];
 		$dueDate = $this->column_fields['due_date'];
 		$endDate = $this->column_fields['end_date'];
-		
+
 		$usedUnits = $this->column_fields['used_units'];
 		$totalUnits = $this->column_fields['total_units'];
-		
+
 		$contractStatus = $this->column_fields['contract_status'];
-		
-		// Update the End date if the status is Complete or if the Used Units reaches/exceeds Total Units 
+
+		// Update the End date if the status is Complete or if the Used Units reaches/exceeds Total Units
 		// We need to do this first to make sure Actual duration is computed properly
 		if($contractStatus == 'Complete' || (!empty($usedUnits) && !empty($totalUnits) && $usedUnits >= $totalUnits)) {
 			if(empty($endDate)) {
@@ -549,7 +495,7 @@ class ServiceContracts extends CRMEntity {
 			$endDate = null;
 			$this->db->pquery('UPDATE vtiger_servicecontracts SET end_date=? WHERE servicecontractsid = ?', array(null, $this->id));
 		}
-		
+
 		// Calculate the Planned Duration based on Due date and Start date. (in days)
 		if(!empty($dueDate) && !empty($startDate)) {
 			$plannedDurationUpdate = " planned_duration = (TO_DAYS(due_date)-TO_DAYS(start_date)+1)";
@@ -557,26 +503,26 @@ class ServiceContracts extends CRMEntity {
 			$plannedDurationUpdate = " planned_duration = ''";
 		}
 		array_push($updateCols, $plannedDurationUpdate);
-		
+
 		// Calculate the Actual Duration based on End date and Start date. (in days)
 		if(!empty($endDate) && !empty($startDate)) {
 			$actualDurationUpdate = "actual_duration = (TO_DAYS(end_date)-TO_DAYS(start_date)+1)";
 		} else {
-			$actualDurationUpdate = "actual_duration = ''";					
+			$actualDurationUpdate = "actual_duration = ''";
 		}
 		array_push($updateCols, $actualDurationUpdate);
-		
+
 		// Update the Progress based on Used Units and Total Units (in percentage)
 		if(!empty($usedUnits) && !empty($totalUnits)) {
 			$progressUpdate = 'progress = ?';
 			$progressUpdateParams = floatval(($usedUnits * 100) / $totalUnits);
 		} else {
 			$progressUpdate = 'progress = ?';
-			$progressUpdateParams = null;			
+			$progressUpdateParams = null;
 		}
 		array_push($updateCols, $progressUpdate);
 		array_push($updateParams, $progressUpdateParams);
-		
+
 		if(count($updateCols) > 0) {
 			$updateQuery = 'UPDATE vtiger_servicecontracts SET '. implode(",", $updateCols) .' WHERE servicecontractsid = ?';
 			array_push($updateParams, $this->id);
@@ -593,7 +539,7 @@ class ServiceContracts extends CRMEntity {
 	 	parent::delete_related_module($module, $crmid, $with_module, $with_crmid);
 	 	if ($with_module == 'HelpDesk') {
 	 		$this->updateServiceContractState($crmid);
-	 	}		
+	 	}
 	}
 
 	/**
