@@ -40,26 +40,14 @@ if(empty($_REQUEST['record']) && $focus->mode != 'edit'){
 	setObjectValuesFromRequest($focus);
 }
 
-//needed when creating a new service with a default vtiger_vendor name to passed 
+//needed when creating a new service with a default vtiger_vendor name to passed
 if (isset($_REQUEST['name']) && is_null($focus->name)) {
 	$focus->name = $_REQUEST['name'];
 }
 
 $disp_view = getView($focus->mode);
-if($disp_view == 'edit_view') { 
 	$smarty->assign('BLOCKS', getBlocks($currentModule, $disp_view, $focus->mode, $focus->column_fields));
-} else {
-	$bas_block = getBlocks($currentModule,$disp_view,$mode,$focus->column_fields,'BAS');
-	$adv_block = getBlocks($currentModule,$disp_view,$mode,$focus->column_fields,'ADV');
 
-	$blocks['basicTab'] = $bas_block;
-	if(is_array($adv_block))
-		$blocks['moreTab'] = $adv_block;
-
-	$smarty->assign("BLOCKS",$blocks);
-	$smarty->assign("BLOCKS_COUNT",count($blocks));
-}
-	
 $smarty->assign('OP_MODE',$disp_view);
 $smarty->assign('APP', $app_strings);
 $smarty->assign('MOD', $mod_strings);
@@ -71,6 +59,7 @@ $smarty->assign("THEME", $theme);
 $smarty->assign('IMAGE_PATH', "themes/$theme/images/");
 $smarty->assign('ID', $focus->id);
 $smarty->assign('MODE', $focus->mode);
+$smarty->assign('CREATEMODE', vtlib_purify($_REQUEST['createmode']));
 
 $smarty->assign('CHECK', Button_Check($currentModule));
 $smarty->assign('DUPLICATE', $isduplicate);
@@ -87,7 +76,7 @@ if(isset($_REQUEST['return_action']))    $smarty->assign("RETURN_ACTION", vtlib_
 if(isset($_REQUEST['return_id']))        $smarty->assign("RETURN_ID", vtlib_purify($_REQUEST['return_id']));
 if (isset($_REQUEST['return_viewname'])) $smarty->assign("RETURN_VIEWNAME", vtlib_purify($_REQUEST['return_viewname']));
 
-// Field Validation Information 
+// Field Validation Information
 $tabid = getTabid($currentModule);
 $validationData = getDBValidationData($focus->tab_name,$tabid);
 $validationArray = split_validationdataArray($validationData);
@@ -170,7 +159,7 @@ $unit_price = $focus->column_fields['unit_price'];
 $price_details = getPriceDetailsForProduct($serviceid, $unit_price, 'available',$currentModule);
 $smarty->assign("PRICE_DETAILS", $price_details);
 
-$base_currency = 'curname' . $service_base_currency;	
+$base_currency = 'curname' . $service_base_currency;
 $smarty->assign("BASE_CURRENCY", $base_currency);
 
 $picklistDependencyDatasource = Vtiger_DependencyPicklist::getPicklistDependencyDatasource($currentModule);
