@@ -7,21 +7,17 @@
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
  *********************************************************************************
-/*********************************************************************************
- * $Header:  E:\D_root\Dokumentumok\vtiger520\hungarian52\trunk\modules\Tooltip\language\hu_hu.lang.php - 22:38 2010.05.21. $
- * Description:  Defines the Hungarian language pack for the Tooltip module vtiger 5.2.0
+ * $Header:  \modules\Tooltip\language\hu_hu.lang.php - 12:13 2011.11.12. $
+ * Description:  Defines the Hungarian language pack for the Tooltip module vtiger 5.3.x
  *
  * Contributor(s): Istvan Holbok,  e-mail: holbok@gmail.com , mobil: +3670-3420900 , Skype: holboki
  ********************************************************************************/
-
-$mod_strings = Array (
-'Tooltip' => 'Súgó',
-'LBL_TOOLTIP_MANAGEMENT'=>'Súgó Beállítások',
-'LBL_TOOLTIP_MANAGEMENT_DESCRIPTION'=>'Itt tudod beállítani a Súgó információkat',
-'LBL_FIELDS_IN'=>'Mezők benne',
-'LBL_TOOLTIP_HELP_TEXT'=>'Válaszd ki azokat a mezőket, amiknek a tartalmát Súgóként meg kívánod jeleníteni',
-'LBL_FIELD'=>'Mező',
-
+$mod_strings = array(
+	'Tooltip' => 'Súgó',
+	'LBL_TOOLTIP_MANAGEMENT' => 'Súgó Beállítások',
+	'LBL_TOOLTIP_MANAGEMENT_DESCRIPTION' => 'Itt tudod beállítani a Súgó információkat',
+	'LBL_FIELDS_IN' => 'Mezők benne',
+	'LBL_TOOLTIP_HELP_TEXT' => 'Válaszd ki azokat a mezőket, amiknek a tartalmát Súgóként meg kívánod jeleníteni',
+	'LBL_FIELD' => 'Mező'
 );
-
-?>
+?>
\ No newline at end of file
