@@ -1,20 +1,34 @@
 <?php
-/*********************************************************************************
- * The contents of this file are subject to the SugarCRM Publiek License Version 1.1.2
- * ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
- * Software distributed under the License is distributed on an  "AS IS"  basis,
+
+/*******************************************************************************
+ * The contents of this file are subject to the following licences:
+ * - SugarCRM Public License Version 1.1.2 http://www.sugarcrm.com/SPL
+ * - vtiger CRM Public License Version 1.0 
+ * You may not use this file except in compliance with the License
+ * Software distributed under the License is distributed on an  "AS IS" basis,
  * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
  * the specific language governing rights and limitations under the License.
- * The Original Code is:  SugarCRM Open Source
+ * The Original Code is: SugarCRM Open Source
  * The Initial Developer of the Original Code is SugarCRM, Inc.
  * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
+ * Portions created by vtiger are Copyright (C) vtiger.
+ * Portions created by Vicus are Copyright (C) Vicus.
  * All Rights Reserved.
- * Contributor(s): Vertaling Weltevree.org  www.weltevree.org
+ * Feel free to use / redistribute these languagefiles under the VPL 1.0.
+ * This translations is based on earlier work of: 
+ * - IT-Online.nl <www.it-online.nl>
+ * - Weltevree.org <www.Weltevree.org>
  ********************************************************************************/
-/*********************************************************************************
- * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Users/language/en_us.lang.php,v 1.18 2005/04/19 14:45:38 ray Exp $
- * Description:  Defines the English language pack for the Account module.
+
+/*******************************************************************************
+ * Vicus eBusiness Solutions Version Control
+ * @package 	NL-Dutch
+ * Description	Dutch language pack for vtiger CRM version 5.3.x
+ * @author	$Author: luuk $
+ * @version 	$Revision: 1.6 $ $Date: 2012/02/28 23:40:22 $
+ * @source	$Source: /var/lib/cvs/vtiger530/Dutch/modules/Users/language/nl_nl.lang.php,v $
+ * @copyright	Copyright (c)2005-2011 Vicus eBusiness Solutions bv <info@vicus.nl>
+ * @license	vtiger CRM Public License Version 1.0 (by definition)
  ********************************************************************************/
  
 $mod_strings = Array(
@@ -23,15 +37,15 @@ $mod_strings = Array(
 'LBL_SEARCH_FORM_TITLE'=>'Gebruiker zoeken',
 'LBL_LIST_FORM_TITLE'=>'Gebruikerslijst',
 'LBL_NEW_FORM_TITLE'=>'Nieuwe gebruiker',
-'LBL_CREATE_NEW_USER'=>'Maak nieuwe gebruiker',
+'LBL_CREATE_NEW_USER'=>'Maak nieuwe gebruiker aan',
 'LBL_LOGIN'=>'Login',
 'LBL_USER_ROLE'=>'Rol',
 'LBL_LIST_NAME'=>'Naam',
 'LBL_LIST_LAST_NAME'=>'Achternaam',
 'LBL_LIST_USER_NAME'=>'Gebruikersnaam',
 'LBL_LIST_DEPARTMENT'=>'Afdeling',
-'LBL_LIST_EMAIL'=>'e-Mail',
-'LBL_LIST_PRIMARY_PHONE'=>'Hoofd telefoonnummer',
+'LBL_LIST_EMAIL'=>'Email',
+'LBL_LIST_PRIMARY_PHONE'=>'Telefoon receptie',
 'LBL_LIST_ADMIN'=>'Admin',
 'LBL_LIST_CONFIRM_PASSWORD'=>'Bevestig wachtwoord',
 'LBL_LIST_USER_NAME_ROLE'=>'Gebruiker ID , naam & rol',
@@ -62,19 +76,19 @@ $mod_strings = Array(
 'LBL_CRM_ID'=>'CRM ID',
 'LBL_FIRST_NAME'=>'Voornaam',
 'LBL_LAST_NAME'=>'Achternaam',
-'LBL_YAHOO_ID'=>'Skype nummer ',
+'LBL_YAHOO_ID'=>'Tweede e-mailadres ',
 'LBL_THEME'=>'Thema:',
 'LBL_LANGUAGE'=>'Taal:',
 'LBL_ADMIN'=>'Admin',
-'LBL_OFFICE_PHONE'=>'Kantoor telefoon',
+'LBL_OFFICE_PHONE'=>'Telefoon Kantoor',
 'LBL_REPORTS_TO'=>'Rapporteert aan',
 'LBL_OTHER_PHONE'=>'Telefoon',
-'LBL_OTHER_EMAIL'=>'Prive e-Mail',
+'LBL_OTHER_EMAIL'=>'Prive e-mail',
 'LBL_DEPARTMENT'=>'Afdeling',
 'LBL_STATUS'=>'Status',
 'LBL_TITLE'=>'Titel',
-'LBL_ANY_PHONE'=>'Prive telefoon:',
-'LBL_ANY_EMAIL'=>'Bedrijfs e-Mail:',
+'LBL_ANY_PHONE'=>'Telefoon prive:',
+'LBL_ANY_EMAIL'=>'Bedrijfs e-mail:',
 'LBL_ADDRESS'=>'Straat',
 'LBL_CITY'=>'Plaats',
 'LBL_STATE'=>'Provincie',
@@ -82,19 +96,19 @@ $mod_strings = Array(
 'LBL_COUNTRY'=>'Land',
 'LBL_USER_SETTINGS'=>'Gebruikers instellingen',
 'LBL_USER_INFORMATION'=>'Gebruikers informatie',
-'LBL_MOBILE_PHONE'=>'Mobiele telefoon',
+'LBL_MOBILE_PHONE'=>'Telefoon Mobiel',
 'LBL_OTHER'=>'Anders',
 'LBL_FAX'=>'Fax',
-'LBL_EMAIL'=>'e-Mail',
-'LBL_HOME_PHONE'=>'Telefoonnummer thuis',
-'LBL_ADDRESS_INFORMATION'=>'Adres informatie',
+'LBL_EMAIL'=>'E-mail',
+'LBL_HOME_PHONE'=>'Telefoon Thuis',
+'LBL_ADDRESS_INFORMATION'=>'Adresinformatie',
 'LBL_CAL_HRFORMAT'=>'Agenda tijd formaat',
 'LBL_CAL_DURATION'=>'Dag begint met',
-'LBL_PRIMARY_ADDRESS'=>'Hoofdadres:',
+'LBL_PRIMARY_ADDRESS'=>'Bezoekadres:',
 
-'LBL_CHANGE_PASSWORD_BUTTON_TITLE'=>'Verander wachtwoord [Alt+P]',
+'LBL_CHANGE_PASSWORD_BUTTON_TITLE'=>'Wijzig wachtwoord [Alt+P]',
 'LBL_CHANGE_PASSWORD_BUTTON_KEY'=>'P',
-'LBL_CHANGE_PASSWORD_BUTTON_LABEL'=>'Verander wachtwoord',
+'LBL_CHANGE_PASSWORD_BUTTON_LABEL'=>'Wijzig wachtwoord',
 'LBL_LOGIN_BUTTON_TITLE'=>'Login [Alt+L]',
 'LBL_LOGIN_BUTTON_KEY'=>'L',
 'LBL_LOGIN_BUTTON_LABEL'=>'Login',
@@ -104,22 +118,22 @@ $mod_strings = Array(
 'LBL_LOGIN_HISTORY_TITLE'=>'Gebruikers: Login geschiedenis',
 'LBL_RESET_PREFERENCES'=>'Terug naar standaard voorkeuren',
 
-'LBL_CHANGE_PASSWORD'=>'Verander wachtwoord',
+'LBL_CHANGE_PASSWORD'=>'Wijzig wachtwoord',
 'LBL_OLD_PASSWORD'=>'Oud wachtwoord:',
 'LBL_NEW_PASSWORD'=>'Nieuw wachtwoord:',
 'LBL_CONFIRM_PASSWORD'=>'Herhaal wachtwoord:',
-'ERR_ENTER_OLD_PASSWORD'=>'Voer uw oude wachtwoord in s.v.p..',
-'ERR_ENTER_NEW_PASSWORD'=>'Voer uw nieuwe wachtwoord in s.v.p.',
-'ERR_ENTER_CONFIRMATION_PASSWORD'=>'Herhaal uw nieuwe wachtwoord s.v.p.',
-'ERR_REENTER_PASSWORDS'=>'Uw nieuwe wachtwoord opnieuw a.u.b.  Uw \"nieuwe wachtwoord\" en \"Herhaal wachtwoord\" zijn niet het zelfde.',
+'ERR_ENTER_OLD_PASSWORD'=>'Voer uw oude wachtwoord in a.u.b..',
+'ERR_ENTER_NEW_PASSWORD'=>'Voer uw nieuwe wachtwoord in a.u.b.',
+'ERR_ENTER_CONFIRMATION_PASSWORD'=>'Herhaal uw nieuwe wachtwoord a.u.b.',
+'ERR_REENTER_PASSWORDS'=>'Voer uw nieuwe wachtwoord opnieuw in a.u.b.  Uw \"nieuwe wachtwoord\" en \"Herhaal wachtwoord\" zijn niet het zelfde.',
 'ERR_INVALID_PASSWORD'=>'U moet wel een geldige gebruikersnaam en wachtwoord invullen.',
-'ERR_PASSWORD_CHANGE_FAILED_1'=>'Gebruikers wachtwoord verandering ging fout omdat ',
+'ERR_PASSWORD_CHANGE_FAILED_1'=>'Gebruikers wachtwoord wijziging ging fout omdat ',
 'ERR_PASSWORD_CHANGE_FAILED_2'=>' FOUT. Het nieuwe wachtwoord moet opnieuw.',
-'ERR_PASSWORD_INCORRECT_OLD'=>'FOUT oude wachtwoord voor gebruiker $this->user_name is niet correct. Opnieuw s.v.p..',
+'ERR_PASSWORD_INCORRECT_OLD'=>'FOUT oude wachtwoord voor gebruiker $this->gebruikersnaam is niet correct. Opnieuw a.u.b..',
 'ERR_USER_NAME_EXISTS_1'=>'De gebruikersnaam ',
 'ERR_USER_NAME_EXISTS_2'=>' bestaat al. Dubbele gebruikersnamen zijn niet toegestaan.<br>Verander de naam, deze moet uniek zijn.',
 'ERR_LAST_ADMIN_1'=>'Gebruikersnaam ',
-'ERR_LAST_ADMIN_2'=>' Dit is de laatste Admin gebruiker.  Er moet tenminste 1 admin gebruiker zijn.<br>Check de admin instellingen.',
+'ERR_LAST_ADMIN_2'=>' Dit is de laatste admin gebruiker.  Er moet tenminste 1 admin gebruiker zijn.<br>Check de admin instellingen.',
 
 'ERR_DELETE_RECORD'=>"U moet een account selecteren om deze te kunnen verwijderen.",
 
@@ -142,10 +156,10 @@ $mod_strings = Array(
 'LBL_LEADS'=>'Leads',
 'LBL_ACCOUNTS'=>'Accounts',
 'LBL_CONTACTS'=>'Contacten',
-'LBL_OPPURTUNITIES'=>'Verkoop potentieel',
+'LBL_OPPURTUNITIES'=>'Verkoopkansen',
 'LBL_TASKS'=>'Taken',
 'LBL_CASES'=>'Zaken',
-'LBL_EMAILS'=>'e-Mails',
+'LBL_EMAILS'=>'E-mails',
 'LBL_NOTES'=>'Notities',
 'LBL_MEETINGS'=>'Vergaderingen',
 'LBL_CALLS'=>'Telefoongesprekken',
@@ -153,23 +167,23 @@ $mod_strings = Array(
 'LBL_IMPORT_LEADS'=>'Importeer leads',
 'LBL_IMPORT_ACCOUNTS'=>'Importeer accounts',
 'LBL_IMPORT_CONTACTS'=>'Importeer contacten',
-'LBL_IMPORT_OPPURTUNITIES'=>'Importeer verkoop potentieel',
+'LBL_IMPORT_OPPURTUNITIES'=>'Importeer Verkoopkansen',
 
 'LBL_ROLE_DETAILS'=>'Rol details',
 //added for vtigercrm4 rc
 'LBL_FILE'=> 'Bestandsnaam',
-'LBL_FILE_TYPE'=>'Bestands type',
+'LBL_FILE_TYPE'=>'Bestandstype',
 'LBL_UPLOAD'=>'Upload bestand',
-'LBL_ATTACH_FILE'=>'Bijlage e-Mail samenvoegen in sjabloon',
-'LBL_EMAIL_TEMPLATES'=>'e-Mail sjablonen',
+'LBL_ATTACH_FILE'=>'Bijlage e-mail samenvoegen in sjabloon',
+'LBL_EMAIL_TEMPLATES'=>'E-mail sjablonen',
 'LBL_TEMPLATE_HEADER'=>'Sjabloon',
 'LBL_TEMPLATE_DETAILS'=>'Sjabloon details',
 'LBL_EDIT_TEMPLATE'=>'Wijzig sjabloon',
 'LBL_TEMPLATE_FILE'=>'Sjabloon bestand',
-'LBL_EMAIL_TEMPLATES_LIST'=>'Communicatie sjablonen > e-Mail sjabloon',
-'LBL_MAILMERGE_TEMPLATES_LIST'=>' > Communicatie sjabloon > e-Mail samenvoegen met sjabloon',
-'LBL_MAILMERGE_TEMPLATES_ATTACHMENT' => '> Communicatie sjabloon > bijlage e-Mail samenvoegen in sjabloon',
-'LBL_DOWNLOAD_NOW'=>'Nu Downloaden',
+'LBL_EMAIL_TEMPLATES_LIST'=>'Communicatie sjablonen > e-mail sjabloon',
+'LBL_MAILMERGE_TEMPLATES_LIST'=>' > Communicatie sjablonen > e-mail samenvoegen met sjabloon',
+'LBL_MAILMERGE_TEMPLATES_ATTACHMENT' => '> Communicatie sjablonen > bijlage e-mail samenvoegen in sjabloon',
+'LBL_DOWNLOAD_NOW'=>'Nu downloaden',
 'LBL_DOWNLOAD'=>'Download',
 'LBL_SELECT_MODULE'=>'Selecteer module',
 'LBL_MERGE_FILE'=>'Bestand: ',
@@ -178,10 +192,10 @@ $mod_strings = Array(
 'LBL_COPY_PASTE'=>'Kopieren & plakken',
 'LNK_GO_TO_TOP'=>'Ga naar bovenkant pagina',
 'LBL_COLON'=>':',
-'LBL_EMAIL_TEMPLATE'=>'e-Mail sjabloon',
+'LBL_EMAIL_TEMPLATE'=>'E-mail sjabloon',
 'LBL_NEW_TEMPLATE'=>'Nieuw sjabloon',
 'LBL_ADD_TEMPLATE'=>'Sjabloon toevoegen',
-'LBL_USE_MERGE_FIELDS_TO_EMAIL_CONTENT'=>'Gebruik samenvoegen velden om uw e-Mail inhoud te personifieren.',
+'LBL_USE_MERGE_FIELDS_TO_EMAIL_CONTENT'=>'Gebruik samenvoegen velden om uw e-mail inhoud te personifieren.',
 'LBL_AVAILABLE_MERGE_FIELDS'=>'Beschikbare samengevoegde velden',
 'LBL_SELECT_FIELD_TYPE'=>'Selecteer veld type',
 'LBL_SELECT_FIELD'=>'Selecteer veld:',
@@ -190,41 +204,42 @@ $mod_strings = Array(
 'LBL_CONTACT_FIELDS'=>'Contact velden',
 'LBL_LEAD_FIELDS'=>'Lead velden',
 'LBL_COPY_AND_PASTE_MERGE_FIELD'=>'Kopieer en plak waarde samengevoegde velden in uw onderstaande sjabloon.',
-'LBL_EMAIL_TEMPLATE_INFORMATION'=>'Communicatie sjablonen > e-Mail sjabloon > bekijken',
+'LBL_EMAIL_TEMPLATE_INFORMATION'=>'Communicatie sjablonen > e-mail sjabloon > bekijken',
 'LBL_FOLDER'=>'Mappen',
 'LBL_PERSONAL'=>'Persoonlijk',
 'LBL_PUBLIC'=>'Publiek',
 'LBL_TEMPLATE_NAME'=>'Naam sjabloon:',
 'LBL_SUBJECT'=>'Onderwerp',
-'LBL_BODY'=>'e-Mail omvang',
+'LBL_BODY'=>'E-mail omvang',
 'LBL_TEMPLATE_TOOLS'=>'Gereedschap',
 'LBL_TEMPLATE_PUBLIC'=>'Toegang publiek',
 'LBL_TEMPLATE_PRIVATE'=>'Toegang prive',
-'LBL_TEMPLATE_SUBJECT'=>'e-Mail onderwerp',
-'LBL_TEMPLATE_MESSAGE'=>'e-Mail bericht',
+'LBL_TEMPLATE_SUBJECT'=>'E-mail onderwerp',
+'LBL_TEMPLATE_MESSAGE'=>'E-mail bericht',
 'LBL_VIEWING'=>'Bekijken',
 'LBL_PROPERTIES'=>'Eigendom van',
 
 
 //added to fix the issue #6630
-'LBL_ASTERISKEXTENSIONS_EXIST' => 'Sterretje Extensie Bestaat Reeds!',
+'LBL_ASTERISKEXTENSIONS_EXIST' => 'Asterisk Extensie Bestaat Reeds!',
 
 // Added fields in createnewgroup.php
 'LBL_CREATE_NEW_GROUP'=>'Maak nieuwe groep',
 'LBL_NEW_GROUP'=>'Nieuwe groep',
 'LBL_EDIT_GROUP'=>'Bewerk groep',
-'LBL_GROUP_NAME'=>'Groepsnaam',
+'LBL_GROUP_NAME'=>'Groepnaam',
 'LBL_GROUP_DETAILS'=>'Groep details',
 'LBL_MEMBER'=>'Leden',
 'LBL_MEMBER_AVLBL'=>'Beschikbare entiteit & leden',
 'LBL_MEMBER_SELECTED'=>'Geselecteerde leden',
+'LBL_DESCRIPTION'=>'Omschrijving',
 'LBL_GROUP_MESG1'=>'Groepen zijn een flexibele manier voor het toekennen van rechten. U kunt verschillende entititeiten verschillende rechten toekennen zoals rollen, gebruikers, profielen enz in een groep.',
 'LBL_GROUP_MESG2'=>'Om toe te voegen, selecteer de entiteit leden en klik op ">>".',
 'LBL_GROUP_MESG3'=>'Verwijderen, selecteer de groep leden en klik op "<<".',
 
 
 // Added fields in detailViewmailtemplate.html,listgroupmembers.php,listgroups.php
-'LBL_DETAIL_VIEW_OF_EMAIL_TEMPLATE'=>'Bekijk de details van de e-Mail template',
+'LBL_DETAIL_VIEW_OF_EMAIL_TEMPLATE'=>'Bekijk de details van de e-mail sjabloon',
 'LBL_DETAIL_VIEW'=>'Bekijk details van',
 'LBL_EDIT_VIEW'=>'Verander details van de gebruiker',
 'LBL_EDITING'=>'Verander gebruiker',
@@ -232,9 +247,9 @@ $mod_strings = Array(
 'LBL_GROUPS'=>'Groepen',
 'LBL_MY_GROUPS'=>'Mijn groepen',
 'LBL_ADD_GROUP_BUTTON'=>'Toevoegen groep',
-'LBL_WORD_TEMPLATES'=>'Samenvoegen e-Mail templates',
-'LBL_NEW_WORD_TEMPLATE'=>'Nieuwe template',
-'LBL_EMAIL_TEMPLATE_DESC'=>'Beheer e-Mail templates die u gebruikt voor campagnes en massa mailing',
+'LBL_WORD_TEMPLATES'=>'Samenvoegen e-mail sjablonen',
+'LBL_NEW_WORD_TEMPLATE'=>'Nieuwe sjabloon',
+'LBL_EMAIL_TEMPLATE_DESC'=>'Beheer e-mail sjablonen die u gebruikt voor campagnes en massa mailing',
 'LBL_NAME'=>'Naam',
 
 // Added fields in TabCustomise.php,html and UpdateTab.php,html
@@ -243,8 +258,8 @@ $mod_strings = Array(
 'LBL_AVAILABLE_TABS'=>'Beschikbare tabs',
 'LBL_SELECTED_TABS'=>'Geselecteerde tabs',
 'LBL_USER'=>'Gebruiker',
-'LBL_TAB_MENU_UPDATED'=>'Tab menu updated! Graag gaan naar ',
-'LBL_TO_VIEW_CHANGES'=>' Laat veranderingen zien',
+'LBL_TAB_MENU_UPDATED'=>'Tab menu bijgewerkt! Graag gaan naar ',
+'LBL_TO_VIEW_CHANGES'=>' Laat wijzigingen zien',
 
 // Added to change homepage order
 'LBL_CHANGE_HOMEPAGE_LABEL'=>'Homepage volgorde',
@@ -256,7 +271,7 @@ $mod_strings = Array(
 // Added fields in CreateProfile.php
 'LBL_PROFILE_NAME'=>'Maak nieuw profiel:',
 'LBL_NEW_PROFILE'=>'Nieuw profiel',
-'LBL_NEW_PROFILE_NAME'=>'Profiel naam',
+'LBL_NEW_PROFILE_NAME'=>'Profielnaam',
 'LBL_PARENT_PROFILE'=>'Bijhorende profiel',
 'LBL_BASIC_PROFILE_DETAILS'=>'Basis details van het profiel',
 'LBL_STEP_1_2'=>'Stap 1 of 2',
@@ -273,7 +288,7 @@ $mod_strings = Array(
 'LBL_BASE_PROFILE_MESG'=>'Ik wil een basis profiel maken met verander rechten <b>(Geadviseerd)</b>',
 'LBL_BASE_PROFILE'=>'Basis profiel:',
 'LBL_OR'=>'of',
-'LBL_BASE_PROFILE_MESG_ADV'=>'Ik wil alle rechten verwijderen vanaf de start <b>(Ervaren Gebruikers)</b>',
+'LBL_BASE_PROFILE_MESG_ADV'=>'Ik wil alle rechten verwijderen vanaf het begin <b>(Ervaren Gebruikers)</b>',
 'LBL_FOR'=>'voor',
 'LBL_GLOBAL_MESG_OPTION'=>'Selecteer opties om de globale rechten te wijzigen',
 'LBL_VIEW_ALL'=>'Bekijk alle',
@@ -281,12 +296,12 @@ $mod_strings = Array(
 'LBL_ALLOW'=>'Staat toe',
 'LBL_MESG_VIEW'=>'Bekijk alle informatie / modules van vTiger CRM',
 'LBL_MESG_EDIT'=>'Verander alle informatie / modules van vTiger CRM',
-'LBL_STD_MESG_OPTION'=>'Geselecteerde standaard akties zijn toegestaan',
+'LBL_STD_MESG_OPTION'=>'Geselecteerde standaard acties zijn toegestaan',
 'LBL_TAB_MESG_OPTION'=>'Modules laten zien',
 'LBL_UTILITY_MESG_OPTION'=>'Selecteer de mogelijkheid: akties zijn toegestaan',
 'LBL_FIELD_MESG_OPTION'=>'Geselecteerde velden zijn toegestaan',
 'LBL_FINISH_BUTTON'=>'Klaar',
-'LBL_PROFILE_DETAIL_VIEW'=>'Detail: Bekijk het profiel',
+'LBL_PROFILE_DETAIL_VIEW'=>'Detail: bekijk het profiel',
 'LBL_PROFILE_MESG'=>'Bekijk toegangrechten van',
 'LBL_PROFILE_M'=>'Profiel',
 'LBL_DEFINE_PRIV_FOR'=>' Definieer de rechten van ',
@@ -296,10 +311,10 @@ $mod_strings = Array(
 'LBL_FIELDS_AND_TOOLS_SETTINGS'=>'Velden & Gereedschap instellingen',
 'LBL_SHOW_FIELDS'=>'Laat velden zien',
 'LBL_TOOLS_TO_BE_SHOWN'=>'Laat gereedschap zien',
-'LBL_WELCOME_PROFILE_CREATE'=>'Welkom bij de rechten profiel maker ',
+'LBL_WELCOME_PROFILE_CREATE'=>'Welkom bij de rechten van de profiel maker ',
 'LBL_SELECT_CHOICE_NEW_PROFILE'=>'Selecteer hoe u een nieuw profiel wenst te maken',
-'LBL_ADD_CUSTOM_RULE'=>'Toevoegen van rechten',
-'LBL_EDIT_CUSTOM_RULE'=>'Veranderen van rechten',
+'LBL_ADD_CUSTOM_RULE'=>'Toevoegen rechten',
+'LBL_EDIT_CUSTOM_RULE'=>'Aanpassen rechten',
 'LBL_CLOSE'=>'Sluiten',
 'LBL_SELECT_ENTITY'=>'Selecteer een entiteit',
 'LBL_CAN_BE_ACCESSED_BY'=>'Toegang voor',
@@ -313,7 +328,7 @@ $mod_strings = Array(
 //Added fields in createrole.php
 'LBL_HDR_ROLE_NAME'=>'Maak nieuwe rol:',
 'LBL_TITLE_ROLE_NAME'=>'Nieuwe rol',
-'LBL_ROLE_NAME'=>'Rol naam',
+'LBL_ROLE_NAME'=>'Rolnaam',
 'LBL_ROLE_PROFILE_NAME'=>'Voeg samen met profiel',
 'LBL_SPECIFY_ROLE_NAME'=>'Specificeer een naam voor deze rol :',
 'LBL_ASSIGN_PROFILE'=>'Toewijzen profiel(en)',
@@ -329,13 +344,13 @@ $mod_strings = Array(
 'LBL_ORG_SHARING_PRIVILEGES'=>'Organisatie gedeelde rechten',
 'LBL_EDIT_PERMISSIONS'=>'Verander toestemmingen',
 'LBL_SAVE_PERMISSIONS'=>'Bewaar toestemmingen',
-'LBL_READ_ONLY'=>'Publiek: Alleen lezen',
+'LBL_READ_ONLY'=>'Publiek: alleen lezen',
 'LBL_EDIT_CREATE_ONLY'=>'Publiek: lezen, maak',
 'LBL_READ_CREATE_EDIT_DEL'=>'Publiek: lezen, maak, verwijder',
 'LBL_PRIVATE'=>'Prive',
 
 //Added fields in listnotificationschedulers.php
-'LBL_HDR_EMAIL_SCHDS'=>'Gebruikers : e-Mail notificaties',
+'LBL_HDR_EMAIL_SCHDS'=>'Gebruikers : e-mail notificaties',
 'LBL_EMAIL_SCHDS_DESC'=>'Hier is de lijst van notificaties die automatisch wordt geactiveerd door de corresponderende afspraak.',
 'LBL_ACTIVE'=>'Actief',
 'LBL_INACTIVE'=>'Inactief',
@@ -343,24 +358,24 @@ $mod_strings = Array(
 'LBL_DESCRIPTION'=>'Omschrijving',
 'LBL_TASK_NOTIFICATION'=>'Uitgestelde taak notificatie',
 'LBL_TASK_NOTIFICATION_DESCRITPION'=>'Notificatie als een taak langer wordt uitgesteld als 24 uur',
-'LBL_MANY_TICKETS'=>'Te veel tickets notificaties',
+'LBL_MANY_TICKETS'=>'Te veel ticket notificaties',
 'LBL_MANY_TICKETS_DESCRIPTION'=>'Laat mij weten als iemand te veel onbehandelde tickets heeft, dit kan service level problemen geven',
 'LBL_PENDING_TICKETS'=>'Wacht op ticket notificatie',
 'LBL_TICKETS_DESCRIPTION'=>'Laat mij weten als er tickets openstaan met de status wachten',
-'LBL_START_NOTIFICATION'=>'Support start notificatie',
-'LBL_START_DESCRIPTION'=>'Notificatie van de start van support/service',
+'LBL_START_NOTIFICATION'=>'Ondersteuning start notificatie',
+'LBL_START_DESCRIPTION'=>'Notificatie van de start van Ondersteuning/service',
 'LBL_BIG_DEAL'=>'Grote order notificatie',
 'LBL_BIG_DEAL_DESCRIPTION'=>'Laat mij weten als een grote order wordt afgesloten',
-'LBL_SUPPORT_NOTICIATION'=>'Support einde notificatie',
-'LBL_SUPPORT_DESCRIPTION'=>'Laat mij weten wanneer support wordt beeindigd',
-'LBL_BUTTON_UPDATE'=>'Update',
+'LBL_SUPPORT_NOTICIATION'=>'Ondersteuning einde notificatie',
+'LBL_SUPPORT_DESCRIPTION'=>'Laat mij weten wanneer Ondersteuning wordt beeindigd',
+'LBL_BUTTON_UPDATE'=>'Bijwerken',
 'LBL_MODULENAMES'=>'Module',
 
 //Added fields in ListFieldPermissions.html
-'LBL_FIELD_PERMISSION_FIELD_NAME'=>'Veld naam',
+'LBL_FIELD_PERMISSION_FIELD_NAME'=>'Veldnaam',
 'LBL_FIELD_PERMISSION_VISIBLE'=>'Zichtbaar',
 'LBL_FIELD_PERMISSIOM_TABLE_HEADER'=>'Standaard velden',
-'LBL_FIELD_LEVEL_ACCESS'=>'Veld niveau toegang',
+'LBL_FIELD_LEVEL_ACCESS'=>'Toegang veld niveau',
 
 //Added fields after 4.0.1
 'LBL_SIGNATURE'=>'Handtekening',
@@ -399,21 +414,21 @@ $mod_strings = Array(
 
 
 //Added for 4.2GA support for mail server integration
-'LBL_ADD_MAILSERVER_BUTTON_TITLE'=>'Toevoegen e-Mail server',
+'LBL_ADD_MAILSERVER_BUTTON_TITLE'=>'Toevoegen e-mail server',
 'LBL_ADD_MAILSERVER_BUTTON_KEY'=>'M',
-'LBL_ADD_MAILSERVER_BUTTON_LABEL'=>'Toevoegen e-Mail server',
+'LBL_ADD_MAILSERVER_BUTTON_LABEL'=>'Toevoegen e-mail server',
 
-'LBL_LIST_MAILSERVER_BUTTON_TITLE'=>'Lijst e-Mail server',
+'LBL_LIST_MAILSERVER_BUTTON_TITLE'=>'Lijst e-mail server',
 'LBL_LIST_MAILSERVER_BUTTON_KEY'=>'L',
-'LBL_LIST_MAILSERVER_BUTTON_LABEL'=>'Lijst e-Mail server',
+'LBL_LIST_MAILSERVER_BUTTON_LABEL'=>'Lijst e-mail server',
 //added for inventory terms and conditions
-'INV_TANDC'=>'Algemene voorwaarden',
-'INV_TERMSANDCONDITIONS'=>'Algemene voorwaarden',
+'INV_TANDC'=>'Algemene Voorwaarden',
+'INV_TERMSANDCONDITIONS'=>'Algemene Voorwaarden',
 'LBL_INV_TERMSANDCONDITIONS'=>'Voorraad beheer', 
 
 
 'INVENTORYNOTIFICATION'=>'Voorraad notificaties',
-'LBL_INVENTORY_NOTIFICATIONS'=>'Verander voorraad e-Mail notificaties',
+'LBL_INVENTORY_NOTIFICATIONS'=>'Verander voorraad e-mail notificaties',
 'LBL_INV_NOT_DESC'=>'De volgende lijst van notificaties wordt naar de product manager gestuurd als de voorraad op het minimum komt.',
 
 'InvoiceNotification'=>'Product voorraad notificatie tijdens het maken van een factuur',
@@ -439,15 +454,15 @@ $mod_strings = Array(
 
 'LBL_CONTACT_FIELD_ACCESS'=>'Contact veld toegang',
 
-'LBL_OPPORTUNITY_FIELD_ACCESS'=>'Potentieel veld toegang',
+'LBL_OPPORTUNITY_FIELD_ACCESS'=>'Verkoopkans veld toegang',
 
 'LBL_HELPDESK_FIELD_ACCESS'=>'Helpdesk veld toegang',
 
-'LBL_PRODUCT_FIELD_ACCESS'=>'Produkt veld toegang',
+'LBL_PRODUCT_FIELD_ACCESS'=>'Product veld toegang',
 
 'LBL_NOTE_FIELD_ACCESS'=>'Notitie veld toegang',
 
-'LBL_EMAIL_FIELD_ACCESS'=>'e-Mail veld toegang',
+'LBL_EMAIL_FIELD_ACCESS'=>'E-mail veld toegang',
 
 'LBL_TASK_FIELD_ACCESS'=>'Taak veld toegang',
 
@@ -468,9 +483,9 @@ $mod_strings = Array(
 'LBL_HOMEPAGE_ID'=>'Blok volgorde',
 'ERR_INVALID_USER'=>'Geen toegang--probeer via mijn accounts',
 'ALVT'=>'Accounts',
-'PLVT'=>'Verkoop potentieel',
+'PLVT'=>'Verkoopkansen',
 'QLTQ'=>'Offertes',
-'CVLVT'=>'Belangrijke Metrics',
+'CVLVT'=>'Belangrijke gegevens',
 'HLT'=>'Helpdesk tickets',
 'OLV'=>'Open afspraken',
 'GRT'=>'Mijn groep allocatie',
@@ -478,7 +493,7 @@ $mod_strings = Array(
 'ILTI'=>'Facturen',
 'HDB'=>'Home pagina dashboard',
 'OLTPO'=>'Inkooporders',
-'LTFAQ'=>'Recente vragen',
+'LTFAQ'=>'Recente FAQ\'s',
 'UA'=>'Activiteiten Aanstaande',
 'PA'=>'Activiteiten Wachtend',
 
@@ -486,7 +501,7 @@ $mod_strings = Array(
 'LBL_GROUP_NAME_ERROR'=>'Groepsnaam bestaat al!',
 'MNL'=>'Nieuwe leads',
 'LBL_LEAD_VIEW'=>'Standaard lead overzicht',
-'LBL_TAG_CLOUD'=>'Koppelingen',
+'LBL_TAG_CLOUD'=>'Koppelingen wolk',
 'LBL_LIST_TOOLS'=>'Gereedschap',
 'LBL_STATISTICS'=>'Statistieken',
 'LBL_TOTAL'=>'Totaal :',
@@ -494,7 +509,7 @@ $mod_strings = Array(
 'LBL_USERS'=>'Gebruiker(s)',
 'LBL_USER_LOGIN_ROLE'=>'Gebruiker login & rol',
 'LBL_USER_MORE_INFN'=>'Meer informatie',
-'LBL_USER_ADDR_INFN'=>'Adres informatie',
+'LBL_USER_ADDR_INFN'=>'Adresinformatie',
 'LBL_USER_IMAGE'=>'Gebruiker foto',
 'LBL_USR'=>'Gebruikers',
 
@@ -503,8 +518,8 @@ $mod_strings = Array(
 'LBL_MY_DESG'=>'Mijn benoeming & contact details',
 'LBL_MY_ADDR'=>'Mijn postadres',
 'LBL_MY_PHOTO'=>'Mijn foto',
-'LBL_CHANGE_PHOTO'=>'Verander foto...',
-'LBL_CHANGE'=>'Verander',
+'LBL_CHANGE_PHOTO'=>'Wijzig foto...',
+'LBL_CHANGE'=>'Wijzig',
 
 
 //Added for Access Privileges
@@ -530,30 +545,31 @@ $mod_strings = Array(
 
 //Added for 5.0 for all fields
 'Role'=>'Rol',
-'Email'=>'e-Mail',
+'Email'=>'E-mail',
 'Admin'=>'Admin',
 'User Name'=>'Gebruikersnaam',
 'First Name'=>'Voornaam',
 'Last Name'=>'Achternaam',
 'Status'=>'Status',
-'Default Activity View'=>'Standaard activiteit overzicht',
-'Default Lead View'=>'Standaard lead overzicht',
+'Default Activity View'=>'Standaard Activiteiten overzicht',
+'Default Lead View'=>'Standaard Lead overzicht',
 'Currency'=>'Valuta',
 'Title'=>'Titel',
-'Office Phone'=>'Telefoonnummer Kantoor',
+'Office Phone'=>'Telefoon Kantoor',
 'Department'=>'Afdeling',
-'Mobile'=>'Mobiel',
+'Mobile'=>'Telefoon Mobiel',
 'Reports To'=>'Rapporteert aan',
-'Other Phone'=>'Prive telefoon',
-'Other Email'=>'Prive e-Mailadres',
+'Other Phone'=>'Telefoon Prive ',
+'Other Email'=>'Prive e-mail',
 'Fax'=>'Fax',
-'Yahoo id'=>'Skype nummer',
-'Home Phone'=>'Telefoonnummer thuis',
-'User Image'=>'Laad gebruiker foto',
+'Yahoo id'=>'Tweede e-mailadres',
+'Home Phone'=>'Thuis telefoon',
+'User Image'=>'Foto Gebruiker ',
 'Date Format'=>'Datum formaat',
-'Tag Cloud'=>'Koppelingen cloud',
+'Tag Cloud'=>'Tag cloud',
 'Signature'=>'Handtekening',
 'Notes'=>'Notities',
+'Documents'=>'Documenten',
 'Street Address'=>'Adres',
 'City'=>'Plaats',
 'State'=>'Provincie',
@@ -565,7 +581,7 @@ $mod_strings = Array(
 'LBL_HIDDEN'=>'Verborgen',
 'LBL_SHOW'=>'Laten zien',
 'LBL_HIDE'=>'Verberg',
-'LBL_HOME_PAGE_COMP'=>'Home Pagina componenten',
+'LBL_HOME_PAGE_COMP'=>'Home pagina componenten',
 'LBL_LOGIN_HISTORY'=>'Login geschiedenis',
 'LBL_USERDETAIL_INFO'=>'Bekijk details van de gebruiker',
 'LBL_DELETE_GROUP'=>'Verwijder groep',
@@ -584,7 +600,7 @@ $mod_strings = Array(
 'LBL_NO'=>'Nee',
 
 'LBL_MANDATORY_MSG'=>'Verplichte velden',
-'LBL_DISABLE_FIELD_MSG'=>'Velden onbruikbaar van Globale Veld Toegangs Instellingen',
+'LBL_DISABLE_FIELD_MSG'=>'Velden onbruikbaar van Global Field Access Settings',
 
 //Added for About Us
 
@@ -594,22 +610,22 @@ $mod_strings = Array(
 'LBL_TEAM'=>'Team',
 'LBL_CREDITS'=>'Credits',
 'LBL_THIRD_PARTY'=>'Pakket derde partij',
-'LBL_COMMUNITY'=>'en vTiger Community',
+'LBL_COMMUNITY'=>'en vtiger Community',
 
 'LBL_ASSIGN_ROLE'=>'Rol toewijzen',
 
 //Moved from Settings to here for Webmail client integration (for 5.0.3 release)
 
-'LBL_ADD_MAIL_ACCOUNT'=>'Toevoegen e-Mail Account',
-'LBL_NEW_MAIL_ACCOUNT_TITLE'=>'Nieuwe e-Mail Account [Alt+M]',
+'LBL_ADD_MAIL_ACCOUNT'=>'Toevoegen e-mail Account',
+'LBL_NEW_MAIL_ACCOUNT_TITLE'=>'Nieuwe e-mail Account [Alt+M]',
 'LBL_NEW_MAIL_ACCOUNT_KEY'=>'M',
-'LBL_NEW_MAIL_ACCOUNT_LABEL'=>'Nieuwe e-Mail Account',
+'LBL_NEW_MAIL_ACCOUNT_LABEL'=>'Nieuw e-mail Account',
 'LBL_GENERAL_INFO'=>'Algemene informatie',
 'LBL_DISPLAY_NAME'=>'Naam tonen',
-'LBL_MAIL_PROTOCOL'=>'e-Mail Protocol',
+'LBL_MAIL_PROTOCOL'=>'E-mail Protocol',
 'LBL_LIST_PASSWORD'=>'Wachtwoord',
-'LBL_MAIL_SERVER_NAME'=>'e-Mail server naam of IP',
-'LBL_INCOME_SERVER_SETTINGS'=>'Inkomende (pop3) server',
+'LBL_MAIL_SERVER_NAME'=>'Email Server Naam of IP',
+'LBL_INCOME_SERVER_SETTINGS'=>'Inkomende server',
 'LBL_TEST_SETTINGS'=>'Test per direct mijn account instellingen',
 'LBL_TEST_BUTTON_TITLE'=>'Test nu mijn account! [Alt+T]',
 'LBL_TEST_BUTTON_KEY'=>'T',
@@ -629,14 +645,14 @@ $mod_strings = Array(
 'LBL_INT_MAILER_NOUSE'=>'Nee',
 'LBL_VAL_SSL_CERT'=>'Bevestig SSL Cert',
 'LBL_DONOT_VAL_SSL_CERT'=>'Bevestig niet SSL Cert',
-'LBL_WEB_MAIL_CONFIG'=>'Web e-Mail configuratie',
-'LBL_CONFIGURE_WEB_MAIL'=>' - Configureer web e-Mail',
-'LBL_LIST_MAIL_ACCOUNT'=>'  Lijst e-Mail Account',
-'LBL_MY_MAIL_SERVER_DET'=>'Mijn inkomende e-Mail server (pop3) details',
+'LBL_WEB_MAIL_CONFIG'=>'Web e-mail configuratie',
+'LBL_CONFIGURE_WEB_MAIL'=>' - Configureer web e-mail',
+'LBL_LIST_MAIL_ACCOUNT'=>'  Lijst e-mail Account',
+'LBL_MY_MAIL_SERVER_DET'=>'Mijn inkomende e-mail server (pop3) details',
 'LBL_MY_DETAILS'=>'Mijn details',
-'LBL_EMAIL_ID'=>'e-Mailadres',
-'LBL_EMAIL_ADDRESS'=>'e-Mail',
-'LBL_NAME_EXAMPLE'=>'(voorbeeld : John Fenner)',
+'LBL_EMAIL_ID'=>'E-mailadres',
+'LBL_EMAIL_ADDRESS'=>'E-mail',
+'LBL_NAME_EXAMPLE'=>'(voorbeeld : Luuk Roovers)',
 'LBL_EMAIL_EXAMPLE'=>'(voorbeeld : johnfenner@xyz.com)',
 'LBL_REFRESH_TIMEOUT'=>'Verversen onderbreken',
 'LBL_1_MIN'=>'1 minuut',
@@ -644,41 +660,164 @@ $mod_strings = Array(
 'LBL_3_MIN'=>'3 minuten',
 'LBL_4_MIN'=>'4 minuten',
 'LBL_5_MIN'=>'5 minuten',
-'LBL_EMAILS_PER_PAGE'=>'e-Mail per pagina',
+'LBL_EMAILS_PER_PAGE'=>'E-mail per pagina',
 // Added for 5.0.3
 
-'LBL_ENTER_PROFILE'=>'Geef naam profiel',
-'TITLE_USER_DOCUMENT'=>'Niet getiteld document',
+'LBL_ENTER_PROFILE'=>'Geef het profiel op',
+'TITLE_USER_DOCUMENT'=>'Document zonder titel',
 'TITLE_VTIGER_CRM_5'=>'vtiger CRM 5.1 - gratis, commercieel gekwalificeerd Open Source CRM',
 'ROLE_DRAG_ERR_MSG'=>'U kunt geen Ouder Node onderschikken aan een Kind Node',
 
-'LBL_NOTIFICATION_ACTIVITY'=>'Notificatie activiteiten',
-'LBL_NOTIFICATION_EMAIL_INFO'=>'Notificatie e-Mail informatie',
-'LBL_GOTO_LISTVIEW_BUTTON'=>'Ga naar bekijk lijst',
+'LBL_NOTIFICATION_ACTIVITY'=>'Notificatie Activiteit',
+'LBL_NOTIFICATION_EMAIL_INFO'=>'Notificatie e-mail Informatie',
+'LBL_GOTO_LISTVIEW_BUTTON'=>'Ga naar ListView',
+//Added to provide User based TagCloud
+'LBL_TAGCLOUD_DISPLAY'=>'Tag Cloud Tonen',
+'INTERNAL_MAIL_COMPOSER'=>'Interne Mail-box',
 
+// Added for 5.0.4 to Support Email notication on User Creation
+'User Login Details'=>'Gebruikers Login gegevens',
+'LBL_TO_LOGIN' => 'om in te loggen',
+'LBL_MAIL_SEND_STATUS' => 'Mail verzendstatus:',
+'LBL_MAIL_NOT_SENT_TO_USER' => 'Mail kon niet worden verstuurd naar ',
+'LBL_PLS_CHECK_EMAIL_N_SERVER' => 'Controleer svp het emailid/Server settings',
 // Added/Updated for vtiger CRM 5.0.4
 
 'LBL_SSL' => 'SSL',
 //Added to fix the issue #4081
-'LBL_USERNAME_EXIST' => 'Gebruikersnaam bestaat al!',
-'LBL_UNAUTHORIZED_ACCESS' => 'Toegang niet toegestaan als Admin',
+'LBL_USERNAME_EXIST' => 'Een gebruiker met deze naam bestaat al!',
+'LBL_UNAUTHORIZED_ACCESS' => 'ongeautoriseerde toegang tot de gebruikersadministratie',
 //Added to provide User based TagCloud
-'LBL_TAGCLOUD_DISPLAY'=>'Label Cloud Weergave',
-'INTERNAL_MAIL_COMPOSER'=>'Nieuwe e-Mail maken',
+'LBL_TAGCLOUD_DISPLAY'=>'Toon Tag Cloud',
+'INTERNAL_MAIL_COMPOSER'=>'Interne e-mail Composer',
 
 // Added for 5.0.4 to Support Email notication on User Creation
-'User Login Details'=>'Gebruiker login details',
-'LBL_TO_LOGIN' => 'voor het inlog scherm',
+'User Login Details'=>'Gebruiker Login Details',
+'LBL_TO_LOGIN' => 'naar Login',
 
 // Added after 5.0.4 GA
 
-'LBL_USER_ADV_OPTIONS'=>'Gebruikers Geavanceerde Opties',
-'Reminder Interval'=>'Herinnerings Interval',
-'Webservice Access Key'=>'Toegangs Sleutel',
+'LBL_USER_ADV_OPTIONS'=>'Geavanceerde gebruikersopties',
+'Reminder Interval'=>'herinnerings Interval',
+'Webservice Access Key'=>'Toegangssleutel',
 
 //user-group fixes
-'LBL_GROUPNAME_EXIST' => 'Een Groep met de opgegeven naam bestaat reeds!',
-'LBL_PROFILENAME_EXIST' => 'Een Profiel met de opgegeven naam bestaat reeds!',
+'LBL_GROUPNAME_EXIST' => 'Een groep met die naam bestaat reeds!',
+'LBL_PROFILENAME_EXIST' => 'Een profiel met die naam bestaat reeds!',
+//Fixed For Asterisk Configration
+'Asterisk Configuration' => 'Asterisk Configuration',
+'Asterisk Extension' => 'Asterisk Extension',
+' Receive Incoming Calls' => 'Receive Incoming Calls',
+
+// Added for Create Custom Fields 
+'LBL_USER_CUSTOMFIELDS_DESCRIPTION' => 'Create Custom Fields for Users ',
+'LBL_USER_CUSTOMFIELDS' => 'Gebruikers Eigen velden',
+
+'LBL_CURRENCY_CONFIGURATION'=> 'Currency Configuration',
+
+//Time zones-Dont change any value
+'Kwajalein' => '(UTC-12:00) International Date Line West',
+'Pacific/Midway' => '(UTC-11:00) Coordinated Universal Time-11',
+'Pacific/Samoa' => '(UTC-11:00) Samoa',
+'Pacific/Honolulu' => '(UTC-10:00) Hawaii',
+'America/Anchorage' => '(UTC-09:00) Alaska',
+'America/Los_Angeles' => '(UTC-08:00) Pacific Time (US &amp; Canada)',
+'America/Tijuana' => '(UTC-08:00) Tijuana, Baja California',
+'America/Denver' => '(UTC-07:00) Mountain Time (US &amp; Canada)',
+'America/Chihuahua' => '(UTC-07:00) Chihuahua, La Paz, Mazatlan',
+'America/Mazatlan' => '(UTC-07:00) Mazatlan',
+'America/Phoenix' => '(UTC-07:00) Arizona',
+'America/Regina' => '(UTC-06:00) Saskatchewan',
+'America/Tegucigalpa' => '(UTC-06:00) Central America',
+'America/Chicago' => '(UTC-06:00) Central Time (US &amp; Canada)',
+'America/Mexico_City' => '(UTC-06:00) Mexico City',
+'America/Monterrey' => '(UTC-06:00) Monterrey',
+'America/New_York' => '(UTC-05:00) Eastern Time (US &amp; Canada)',
+'America/Bogota' => '(UTC-05:00) Bogota, Lima, Quito',
+'America/Lima' => '(UTC-05:00) Lima',
+'America/Rio_Branco' => '(UTC-05:00) Rio Branco',
+'America/Indiana/Indianapolis' => '(UTC-05:00) Indiana (East)',
+'America/Caracas' => '(UTC-04:30) Caracas',
+'America/Halifax' => '(UTC-04:00) Atlantic Time (Canada)',
+'America/Manaus' => '(UTC-04:00) Manaus',
+'America/Santiago' => '(UTC-04:00) Santiago',
+'America/La_Paz' => '(UTC-04:00) La Paz',
+'America/Cuiaba' => '(UTC-04:00) Cuiaba',
+'America/Asuncion' => '(UTC-04:00) Asuncion',
+'America/St_Johns' => '(UTC-03:30) Newfoundland',
+'America/Argentina/Buenos_Aires' => '(UTC-03:00) Buenos Aires',
+'America/Sao_Paulo' => '(UTC-03:00) Brasilia',
+'America/Godthab' => '(UTC-03:00) Greenland',
+'America/Montevideo' => '(UTC-03:00) Montevideo',
+'Atlantic/South_Georgia' => '(UTC-02:00) Mid-Atlantic',
+'Atlantic/Azores' => '(UTC-01:00) Azores',
+'Atlantic/Cape_Verde' => '(UTC-01:00) Cape Verde Is.',
+'Europe/London' => '(UTC) London, Edinburgh, Dublin, Lisbon',
+'UTC' => '(UTC) Coordinated Universal Time, Greenwich Mean Time',
+'Africa/Monrovia' => '(UTC) Monrovia, Reykjavik',
+'Africa/Casablanca' => '(UTC) Casablanca',
+'Europe/Belgrade' => '(UTC+01:00) Belgrade, Bratislava, Budapest, Ljubljana, Prague',
+'Europe/Sarajevo' => '(UTC+01:00) Sarajevo, Skopje, Warsaw, Zagreb',
+'Europe/Brussels' => '(UTC+01:00) Brussels, Copenhagen, Madrid, Paris',
+'Africa/Algiers' => '(UTC+01:00) West Central Africa',
+'Europe/Amsterdam' => '(UTC+01:00) Amsterdam, Berlin, Bern, Rome, Stockholm, Vienna',
+'Europe/Minsk' => '(UTC+02:00) Minsk',
+'Africa/Cairo' => '(UTC+02:00) Cairo',
+'Europe/Helsinki' => '(UTC+02:00) Helsinki, Riga, Sofia, Tallinn, Vilnius',
+'Europe/Athens' => '(UTC+02:00) Athens, Bucharest',
+'Europe/Istanbul' => '(UTC+02:00) Istanbul',
+'Asia/Jerusalem' => '(UTC+02:00) Jerusalem',
+'Asia/Amman' => '(UTC+02:00) Amman',
+'Asia/Beirut' => '(UTC+02:00) Beirut',
+'Africa/Windhoek' => '(UTC+02:00) Windhoek',
+'Africa/Harare' => '(UTC+02:00) Harare',
+'Asia/Kuwait' => '(UTC+03:00) Kuwait, Riyadh',
+'Asia/Baghdad' => '(UTC+03:00) Baghdad',
+'Africa/Nairobi' => '(UTC+03:00) Nairobi',
+'Asia/Tehran' => '(UTC+03:30) Tehran',
+'Asia/Tbilisi' => '(UTC+04:00) Tbilisi',
+'Europe/Moscow' => '(UTC+04:00) Moscow, Volgograd',
+'Asia/Muscat' => '(UTC+04:00) Abu Dhabi, Muscat',
+'Asia/Baku' => '(UTC+04:00) Baku',
+'Asia/Yerevan' => '(UTC+04:00) Yerevan',
+'Asia/Karachi' => '(UTC+05:00) Islamabad, Karachi',
+'Asia/Tashkent' => '(UTC+05:00) Tashkent',
+'Asia/Kolkata' => '(UTC+05:30) Chennai, Kolkata, Mumbai, New Delhi',
+'Asia/Colombo' => '(UTC+05:30) Sri Jayawardenepura',
+'Asia/Katmandu' => '(UTC+05:45) Kathmandu',
+'Asia/Dhaka' => '(UTC+06:00) Dhaka',
+'Asia/Almaty' => '(UTC+06:00) Almaty',
+'Asia/Yekaterinburg' => '(UTC+06:00) Ekaterinburg',
+'Asia/Rangoon' => '(UTC+06:30) Yangon (Rangoon)',
+'Asia/Novosibirsk' => '(UTC+07:00) Novosibirsk',
+'Asia/Bangkok' => '(UTC+07:00) Bangkok, Jakarta',
+'Asia/Brunei' => '(UTC+08:00) Beijing, Chongqing, Hong Kong, Urumqi',
+'Asia/Krasnoyarsk' => '(UTC+08:00) Krasnoyarsk',
+'Asia/Ulaanbaatar' => '(UTC+08:00) Ulaan Bataar',
+'Asia/Kuala_Lumpur' => '(UTC+08:00) Kuala Lumpur, Singapore',
+'Asia/Taipei' => '(UTC+08:00) Taipei',
+'Australia/Perth' => '(UTC+08:00) Perth',
+'Asia/Irkutsk' => '(UTC+09:00) Irkutsk',
+'Asia/Seoul' => '(UTC+09:00) Seoul',
+'Asia/Tokyo' => '(UTC+09:00) Tokyo',
+'Australia/Darwin' => '(UTC+09:30) Darwin',
+'Australia/Adelaide' => '(UTC+09:30) Adelaide',
+'Australia/Canberra' => '(UTC+10:00) Canberra, Melbourne, Sydney',
+'Australia/Brisbane' => '(UTC+10:00) Brisbane',
+'Australia/Hobart' => '(UTC+10:00) Hobart',
+'Asia/Vladivostok' => '(UTC+10:00) Vladivostok',
+'Pacific/Guam' => '(UTC+10:00) Guam, Port Moresby',
+'Asia/Yakutsk' => '(UTC+10:00) Yakutsk',
+'Pacific/Fiji' => '(UTC+12:00) Fiji',
+'Asia/Kamchatka' => '(UTC+12:00) Kamchatka',
+'Pacific/Auckland' => '(UTC+12:00) Auckland',
+'Asia/Magadan' => '(UTC+12:00) Magadan',
+'Pacific/Tongatapu' => '(UTC+13:00) Nukualofa',
+
+'Theme'=>'Thema',
+'Language'=>'Taal',
+'Secondary Email'=>'Tweede E-mail',
+'Time Zone'=>'Tijdzone',
 );
 
-?>
+?>
\ No newline at end of file
