@@ -9,6 +9,15 @@
   *
   ********************************************************************************/
 
-	checkFileAccessForInclusion('modules/'.$_REQUEST['module'].'/'.$_REQUEST['file'].'.php');
-	require_once('modules/'.$_REQUEST['module'].'/'.$_REQUEST['file'].'.php');
+$moduleFilepath = 'modules/'.$_REQUEST['module'].'/'.$_REQUEST['file'].'.php';
+
+if(file_exists($moduleFilepath) == false) {
+
+	$moduleFilepath = 'modules/Vtiger/'.$_REQUEST['file'].'.php';
+
+}
+
+checkFileAccessForInclusion($moduleFilepath);
+
+require_once $moduleFilepath;
 ?>
