@@ -57,8 +57,7 @@ class ListViewController {
 		$isRoleBased = vtws_isRoleBasedPicklist($name);
 		$this->picklistRoleMap[$name] = $isRoleBased;
 		if ($this->picklistRoleMap[$name]) {
-			$this->picklistValueMap[$name] = getAssignedPicklistValues($fieldName,
-					$this->user->roleid, $this->db);
+			$this->picklistValueMap[$name] = getAssignedPicklistValues($name,$this->user->roleid, $this->db);
 		}
 	}
 
@@ -173,6 +172,8 @@ class ListViewController {
 			}
 		}
 
+		$useAsterisk = get_use_asterisk($this->user->id);
+
 		$data = array();
 		for ($i = 0; $i < $rowCount; ++$i) {
 			//Getting the recordId
@@ -196,12 +197,9 @@ class ListViewController {
 					$activityType = $this->db->query_result($result, $i, 'activitytype');
 				}
 
-				if(stristr(html_entity_decode($rawValue), "<a href") === false &&
-						$field->getUIType() != 8){
-					$value = textlength_check($rawValue);
-				}elseif($uitype != 8){
-					$value = html_entity_decode($rawValue,ENT_QUOTES);
-				}else{
+				if($uitype != 8){
+					$value = html_entity_decode($rawValue,ENT_QUOTES,$default_charset);
+				} else {
 					$value = $rawValue;
 				}
 
@@ -255,12 +253,12 @@ class ListViewController {
 							$value = "<a href='index.php?module=uploads&action=downloadfile&".
 									"entityid=$recordId&fileid=$fileId' title='".
 									getTranslatedString("LBL_DOWNLOAD_FILE",$module).
-									"' onclick='javascript:dldCntIncrease($recordId);'>".$value.
+									"' onclick='javascript:dldCntIncrease($recordId);'>".textlength_check($value).
 									"</a>";
 						} elseif($downloadType == 'E') {
 							$value = "<a target='_blank' href='$fileName' onclick='javascript:".
 									"dldCntIncrease($recordId);' title='".
-									getTranslatedString("LBL_DOWNLOAD_FILE",$module)."'>".$value.
+									getTranslatedString("LBL_DOWNLOAD_FILE",$module)."'>".textlength_check($value).
 									"</a>";
 						} else {
 							$value = ' --';
@@ -301,8 +299,8 @@ class ListViewController {
 						$value = ' --';
 					}
 				}elseif ($field->getFieldDataType() == 'picklist') {
-					if (!$is_admin && $this->picklistRoleMap[$fieldName] &&
-							!in_array($tmpValue, $this->picklistValueMap[$fieldName])) {
+					if ($value != '' && !$is_admin && $this->picklistRoleMap[$fieldName] &&
+							!in_array($value, $this->picklistValueMap[$fieldName])) {
 						$value = "<font color='red'>".getTranslatedString('LBL_NOT_ACCESSIBLE',
 								$module)."</font>";
 					} else {
@@ -331,6 +329,7 @@ class ListViewController {
 								$currencyInfo = getInventoryCurrencyInfo($module, $recordId);
 								$currencySymbol = $currencyInfo['currency_symbol'];
 							}
+							$value = number_format($value, 2,'.','');
 							$currencyValue = CurrencyField::convertToUserFormat($value, null, true);
 							$value = CurrencyField::appendCurrencySymbol($currencyValue, $currencySymbol);
 						} else {
@@ -345,18 +344,18 @@ class ListViewController {
                     $matchPattern = "^[\w]+:\/\/^";
                     preg_match($matchPattern, $rawValue, $matches);
                     if(!empty ($matches[0])){
-                        $value = '<a href="'.$rawValue.'" target="_blank">'.$value.'</a>';
+                        $value = '<a href="'.$rawValue.'" target="_blank">'.textlength_check($value).'</a>';
                     }else{
-                        $value = '<a href="http://'.$rawValue.'" target="_blank">'.$value.'</a>';
+                        $value = '<a href="http://'.$rawValue.'" target="_blank">'.textlength_check($value).'</a>';
                     }
 				} elseif ($field->getFieldDataType() == 'email') {
 					if($_SESSION['internal_mailer'] == 1) {
 						//check added for email link in user detailview
 						$fieldId = $field->getFieldId();
 						$value = "<a href=\"javascript:InternalMailer($recordId,$fieldId,".
-						"'$fieldName','$module','record_id');\">$value</a>";
+						"'$fieldName','$module','record_id');\">".textlength_check($value)."</a>";
 					}else {
-						$value = '<a href="mailto:'.$rawValue.'">'.$value.'</a>';
+						$value = '<a href="mailto:'.$rawValue.'">'.textlength_check($value).'</a>';
 					}
 				} elseif($field->getFieldDataType() == 'boolean') {
 					if($value == 1) {
@@ -395,12 +394,17 @@ class ListViewController {
 							}
 						}
 						$value = implode(', ', $tmpArray);
+						$value = textlength_check($value);
 					}
 				} elseif ($field->getFieldDataType() == 'skype') {
-					$value = ($value != "") ? "<a href='skype:$value?call'>$value</a>" : "";
+					$value = ($value != "") ? "<a href='skype:$value?call'>".textlength_check($value)."</a>" : "";
 				} elseif ($field->getFieldDataType() == 'phone') {
-					$value = "<a href='javascript:;' onclick='startCall(&quot;$value&quot;, ".
-						"&quot;$recordId&quot;)'>$value</a>";
+					if($useAsterisk == 'true') {
+						$value = "<a href='javascript:;' onclick='startCall(&quot;$value&quot;, ".
+							"&quot;$recordId&quot;)'>".textlength_check($value)."</a>";
+					} else {
+						$value = textlength_check($value);
+					}
 				} elseif($field->getFieldDataType() == 'reference') {
 					$referenceFieldInfoList = $this->queryGenerator->getReferenceFieldInfoList();
 					$moduleList = $referenceFieldInfoList[$fieldName];
@@ -414,7 +418,7 @@ class ListViewController {
 						$value = textlength_check($this->nameList[$fieldName][$value]);
 						if ($parentMeta->isModuleEntity() && $parentModule != "Users") {
 							$value = "<a href='index.php?module=$parentModule&action=DetailView&".
-								"record=$rawValue' title='$parentModule'>$value</a>";
+								"record=$rawValue' title='".getTranslatedString($parentModule, $parentModule)."'>$value</a>";
 						}
 					} else {
 						$value = '--';
@@ -437,20 +441,21 @@ class ListViewController {
 						$json = new Zend_Json();
 						$value = vt_suppressHTMLTags(implode(',',$json->decode($temp_val)));
 					}
-				}
-				if ( in_array($uitype,array(7,9,90)) ) {
-					$value = "<span align='right'>$value</div>";
+				} elseif ( in_array($uitype,array(7,9,90)) ) {
+					$value = "<span align='right'>".textlength_check($value)."</div>";
+				} else {
+					$value = textlength_check($value);
 				}
 
                                     $parenttab = getParentTab();
 				$nameFields = $this->queryGenerator->getModuleNameFields($module);
 				$nameFieldList = explode(',',$nameFields);
-				if(in_array($fieldName, $nameFieldList) && $module != 'Emails') {
+				if(in_array($fieldName, $nameFieldList) && $module != 'Emails' ) {
 					$value = "<a href='index.php?module=$module&parenttab=$parenttab&action=DetailView&record=".
-					"$recordId' title='$module'>$value</a>";
+					"$recordId' title='".getTranslatedString($module, $module)."'>$value</a>";
 				} elseif($fieldName == $focus->list_link_field && $module != 'Emails') {
 					$value = "<a href='index.php?module=$module&parenttab=$parenttab&action=DetailView&record=".
-					"$recordId' title='$module'>$value</a>";
+					"$recordId' title='".getTranslatedString($module, $module)."'>$value</a>";
 				}
 
 				// vtlib customization: For listview javascript triggers
@@ -545,8 +550,12 @@ class ListViewController {
 		$requestModule = vtlib_purify($_REQUEST['module']);
 		$requestRecord = vtlib_purify($_REQUEST['record']);
 		$requestAction = vtlib_purify($_REQUEST['action']);
+		$requestFile = vtlib_purify($_REQUEST['file']);
 		$isCustomModule = vtlib_isCustomModule($requestModule);
-		if($isCustomModule && !in_array($requestAction, Array('index','ListView'))) {
+
+		if($isCustomModule && (!in_array($requestAction, Array('index','ListView')) &&
+				($requestAction == $requestModule.'Ajax' && !in_array($requestFile, Array('index','ListView'))))) {
+
 			$link = "index.php?module=$requestModule&action=updateRelations&parentid=$requestRecord";
 			$link .= "&destination_module=$module&idlist=$entity_id&mode=delete&parenttab=$parenttab";
 		}
@@ -598,6 +607,9 @@ class ListViewController {
 					$label .=' ('.getTranslatedString('LBL_IN', $module).' '.
 							$user_info['currency_symbol'].')';
 				}
+				if($field->getUIType() == '9') {
+					$label .=' (%)';
+				}
 				if($module == 'Users' && $fieldName == 'User Name') {
 					$name = "<a href='javascript:;' onClick='getListViewEntries_js(\"".$module.
 						"\",\"parenttab=".$tabname."&order_by=".$field->getColumnName()."&sorder=".
@@ -677,11 +689,11 @@ class ListViewController {
 			if($i++ == 0) {
 				$selected = "selected";
 			}
-						
+
 			// place option in array for sorting later
 			//$blockName = getTranslatedString(getBlockName($field->getBlockId()), $module);
 			$blockName = getTranslatedString($field->getBlockName(), $module);
-			
+
 			$fieldLabelEscaped = str_replace(" ","_",$field->getFieldLabelKey());
 			$optionvalue = $field->getTableName().":".$field->getColumnName().":".$fieldName.":".$module."_".$fieldLabelEscaped.":".$typeOfData;
 
@@ -690,14 +702,14 @@ class ListViewController {
 		}
 	   	// sort array on block label
 	    ksort($OPTION_SET, SORT_STRING);
-	    	    
+
 		foreach ($OPTION_SET as $key=>$value) {
 	  		$shtml .= "<optgroup label='$key' class='select' style='border:none'>";
 	   		// sort array on field labels
 	   		ksort($value, SORT_STRING);
 	  		$shtml .= implode('',$value);
 	  	}
-	    
+
 	    return $shtml;
 	}
 
