@@ -29,12 +29,12 @@ class QueryGenerator {
 	private $whereFields;
 	/**
 	 *
-	 * @var VtigerCRMObjectMeta 
+	 * @var VtigerCRMObjectMeta
 	 */
 	private $meta;
 	/**
 	 *
-	 * @var Users 
+	 * @var Users
 	 */
 	private $user;
 	private $advFilterList;
@@ -54,7 +54,7 @@ class QueryGenerator {
 	public static $AND = 'AND';
 	public static $OR = 'OR';
 	private $customViewFields;
-	
+
 	public function __construct($module, $user) {
 		$db = PearDatabase::getInstance();
 		$this->module = $module;
@@ -146,7 +146,7 @@ class QueryGenerator {
 	public function getConditionalWhere() {
 		return $this->conditionalWhere;
 	}
-	
+
 	public function getDefaultCustomViewQuery() {
 		$customView = new CustomView($this->module);
 		$viewId = $customView->getViewId($this->module);
@@ -228,7 +228,7 @@ class QueryGenerator {
 					}
 					$this->endGroup();
 					$groupConditionGlue = $groupcolumns['condition'];
-					if(!empty($groupConditionGlue)) 
+					if(!empty($groupConditionGlue))
 						$this->addConditionGlue($groupConditionGlue);
 				}
 			}
@@ -279,7 +279,7 @@ class QueryGenerator {
 			$baseTableIndex = $moduleTableIndexList[$baseTable];
 			return $baseTable.'.'.$baseTableIndex;
 		}
-		
+
 		$moduleFields = $this->meta->getModuleFields();
 		$field = $moduleFields[$name];
 		$sql = '';
@@ -522,7 +522,7 @@ class QueryGenerator {
 							if($module == 'Users') {
 								$instance = CRMEntity::getInstance($module);
 								$referenceTable = $instance->table_name;
-								if(count($this->ownerFields) > 0 || 
+								if(count($this->ownerFields) > 0 ||
 										$this->getModule() == 'Quotes') {
 									$referenceTable .= '2';
 								}
@@ -536,17 +536,17 @@ class QueryGenerator {
 							$columnList[] = "$referenceTable.$column";
 						}
 						if(count($columnList) > 1) {
-							$columnSql = getSqlForNameInDisplayFormat(array('f'=>$columnList[1],'l'=>$columnList[0]));
+							$columnSql = getSqlForNameInDisplayFormat(array('first_name'=>$columnList[0],'last_name'=>$columnList[1]),'Users');
 						} else {
 							$columnSql = implode('', $columnList);
 						}
-						
-						$fieldSql .= "$fieldGlue $columnSql $valueSql";
+
+						$fieldSql .= "$fieldGlue trim($columnSql) $valueSql";
 						$fieldGlue = ' OR';
 					}
 				} elseif (in_array($fieldName, $this->ownerFields)) {
-					$concatSql = getSqlForNameInDisplayFormat(array('f'=>"vtiger_users.first_name",'l'=>"vtiger_users.last_name"));
-					$fieldSql .= "$fieldGlue $concatSql $valueSql or "."vtiger_groups.groupname $valueSql";
+					$concatSql = getSqlForNameInDisplayFormat(array('first_name'=>"vtiger_users.first_name",'last_name'=>"vtiger_users.last_name"), 'Users');
+					$fieldSql .= "$fieldGlue trim($concatSql) $valueSql or "."vtiger_groups.groupname $valueSql";
 				} else {
 					if($fieldName == 'birthday' && !$this->isRelativeSearchOperators(
 							$conditionInfo['operator'])) {
@@ -572,7 +572,7 @@ class QueryGenerator {
 			$conditionInfo['value'].")";
 			$fieldSqlList[$index] = $fieldSql;
 		}
-		
+
 		$groupSql = $this->makeGroupSqlReplacements($fieldSqlList, $groupSql);
 		if($this->conditionInstanceCount > 0) {
 			$this->conditionalWhere = $groupSql;
@@ -590,14 +590,14 @@ class QueryGenerator {
 	 * @param WebserviceField $field
 	 */
 	private function getConditionValue($value, $operator, $field) {
-		
+
 		$operator = strtolower($operator);
 		$db = PearDatabase::getInstance();
 
 		if(is_string($value)) {
 			$valueArray = explode(',' , $value);
 		} elseif(is_array($value)) {
-			$valueArray = $value;		
+			$valueArray = $value;
 		} else{
 			$valueArray = array($value);
 		}
@@ -648,7 +648,7 @@ class QueryGenerator {
 			} else {
 				$value = $db->sql_escape_string($value);
 			}
-			
+
 			if(trim($value) == '' && ($operator == 's' || $operator == 'ew' || $operator == 'c')
 					&& ($this->isStringType($field->getFieldDataType()) ||
 					$field->getFieldDataType() == 'picklist' ||
@@ -698,6 +698,9 @@ class QueryGenerator {
 							&& $this->isRelativeSearchOperators($operator)))){
 				$value = "'$value'";
 			}
+			if($this->isNumericType($field->getFieldDataType()) && empty($value)) {
+				$value = '0';
+			}
 			$sql[] = "$sqlOperator $value";
 		}
 		return $sql;
@@ -705,11 +708,13 @@ class QueryGenerator {
 
 	private function makeGroupSqlReplacements($fieldSqlList, $groupSql) {
 		$pos = 0;
+		$nextOffset = 0;
 		foreach ($fieldSqlList as $index => $fieldSql) {
-			$pos = strrpos($groupSql, $index.'');
+			$pos = strpos($groupSql, $index.'', $nextOffset);
 			if($pos !== false) {
 				$beforeStr = substr($groupSql,0,$pos);
 				$afterStr = substr($groupSql, $pos + strlen($index));
+				$nextOffset = strlen($beforeStr.$fieldSql);
 				$groupSql = $beforeStr.$fieldSql.$afterStr;
 			}
 		}
@@ -725,13 +730,13 @@ class QueryGenerator {
 	}
 
 	private function isStringType($type) {
-		return ($type == 'string' || $type == 'text' || $type == 'email');
+		return ($type == 'string' || $type == 'text' || $type == 'email' || $type == 'reference');
 	}
 
 	private function isDateType($type) {
 		return ($type == 'date' || $type == 'datetime');
 	}
-	
+
 	private function fixDateTimeValue($name, $value, $first = true) {
 		$moduleFields = $this->meta->getModuleFields();
 		$field = $moduleFields[$name];
@@ -766,41 +771,46 @@ class QueryGenerator {
 	}
 
 	private function getConditionalArray($fieldname,$value,$operator) {
+		if(is_string($value)) {
+			$value = trim($value);
+		} elseif(is_array($value)) {
+			$value = array_map(trim, $value);
+		}
 		return array('name'=>$fieldname,'value'=>$value,'operator'=>$operator);
 	}
 
-	private function startGroup($groupType) {
-		$this->groupInfo .= "$groupType (";
+	public function startGroup($groupType) {
+		$this->groupInfo .= " $groupType (";
 	}
 
-	private function endGroup() {
+	public function endGroup() {
 		$this->groupInfo .= ')';
 	}
 
-	private function addConditionGlue($glue) {
-		$this->groupInfo .= "$glue ";
+	public function addConditionGlue($glue) {
+		$this->groupInfo .= " $glue ";
 	}
 
 	public function addUserSearchConditions($input) {
 		global $log,$default_charset;
 		if($input['searchtype']=='advance') {
-			
-			$json = new Zend_Json();	
+
+			$json = new Zend_Json();
 			$advft_criteria = $_REQUEST['advft_criteria'];
-			if(!empty($advft_criteria))	$advft_criteria = $json->decode($advft_criteria);	
+			if(!empty($advft_criteria))	$advft_criteria = $json->decode($advft_criteria);
 			$advft_criteria_groups = $_REQUEST['advft_criteria_groups'];
 			if(!empty($advft_criteria_groups))	$advft_criteria_groups = $json->decode($advft_criteria_groups);
-			
+
 			if(empty($advft_criteria) || count($advft_criteria) <= 0) {
 				return ;
 			}
-			
-			$advfilterlist = getAdvancedSearchCriteriaList($advft_criteria, $advft_criteria_groups);
-			
+
+			$advfilterlist = getAdvancedSearchCriteriaList($advft_criteria, $advft_criteria_groups, $this->getModule());
+
 			if(empty($advfilterlist) || count($advfilterlist) <= 0) {
 				return ;
 			}
-			
+
 			if($this->conditionInstanceCount > 0) {
 				$this->startGroup(self::$AND);
 			} else {
@@ -825,7 +835,7 @@ class QueryGenerator {
 					}
 					$this->endGroup();
 					$groupConditionGlue = $groupcolumns['condition'];
-					if(!empty($groupConditionGlue)) 
+					if(!empty($groupConditionGlue))
 						$this->addConditionGlue($groupConditionGlue);
 				}
 			}
@@ -842,14 +852,14 @@ class QueryGenerator {
 			$noOfConditions = count($conditionList);
 			$noOfRelatedConditions = count($relatedConditionList);
 			foreach ($conditionList as $index=>$conditionInfo) {
-				$this->addCondition($conditionInfo['fieldname'], $conditionInfo['value'], 
+				$this->addCondition($conditionInfo['fieldname'], $conditionInfo['value'],
 						$conditionInfo['operator']);
 				if($index < $noOfConditions - 1 || $noOfRelatedConditions > 0) {
 					$this->addConditionGlue(self::$AND);
 				}
 			}
 			foreach ($relatedConditionList as $index => $conditionInfo) {
-				$this->addRelatedModuleCondition($conditionInfo['relatedModule'], 
+				$this->addRelatedModuleCondition($conditionInfo['relatedModule'],
 						$conditionInfo['conditionModule'], $conditionInfo['finalValue'],
 						$conditionInfo['SQLOperator']);
 				if($index < $noOfRelatedConditions - 1) {
@@ -879,8 +889,8 @@ class QueryGenerator {
 				if(!$this->isStringType($type)) {
 					$value=trim($stringConvert);
 				}
-				
-				if($type == 'picklist') { 
+
+				if($type == 'picklist') {
 					global $mod_strings;
 					// Get all the keys for the for the Picklist value
 					$mod_keys = array_keys($mod_strings, $value);
@@ -1007,5 +1017,32 @@ class QueryGenerator {
 		}
 		return array('conditions'=>$conditionList,'relatedConditions'=>$relatedConditionList);
 	}
+
+	public function initForGlobalSearchByType($type, $value, $operator='s') {
+		$fieldList = $this->meta->getFieldNameListByType($type);
+		if($this->conditionInstanceCount <= 0) {
+			$this->startGroup('');
+		} else {
+			$this->startGroup(self::$AND);
+		}
+		$nameFieldList = explode(',',$this->getModuleNameFields($this->module));
+		foreach ($nameFieldList as $nameList) {
+			$field = $this->meta->getFieldByColumnName($nameList);
+			$this->fields[] = $field->getFieldName();
+		}
+		foreach ($fieldList as $index => $field) {
+			$fieldName = $this->meta->getFieldByColumnName($field);
+			$this->fields[] = $fieldName->getFieldName();
+			if($index > 0) {
+				$this->addConditionGlue(self::$OR);
+			}
+			$this->addCondition($fieldName->getFieldName(), $value, $operator);
+		}
+		$this->endGroup();
+		if(!in_array('id', $this->fields)) {
+				$this->fields[] = 'id';
+		}
+	}
+
 }
 ?>
\ No newline at end of file
