@@ -163,7 +163,7 @@ class VtigerCRMActorMeta extends EntityMeta {
 	}
 	
 	public function hasPermission($operation,$webserviceId){
-		if($this->user->is_admin){
+		if(is_admin($this->user)){
 			return true;
 		}else{
 			if(strcmp($operation,EntityMeta::$RETRIEVE)===0){
@@ -174,7 +174,7 @@ class VtigerCRMActorMeta extends EntityMeta {
 	}
 	
 	public function hasAssignPrivilege($ownerWebserviceId){
-		if($this->user->is_admin){
+		if(is_admin($this->user)){
 			return true;
 		}else{
 			$idComponents = vtws_getIdComponents($webserviceId);
@@ -187,7 +187,7 @@ class VtigerCRMActorMeta extends EntityMeta {
 	}
 	
 	public function hasDeleteAccess(){
-		if($this->user->is_admin){
+		if(is_admin($this->user)){
 			return true;
 		}else{
 			return false;
@@ -203,7 +203,7 @@ class VtigerCRMActorMeta extends EntityMeta {
 	}
 	
 	public function hasWriteAccess(){
-		if($this->user->is_admin){
+		if(is_admin($this->user)){
 			return true;
 		}else{
 			return false;
