@@ -14,10 +14,17 @@ class VtigerModuleOperation extends WebserviceEntityOperation {
 	
 	public function VtigerModuleOperation($webserviceObject,$user,$adb,$log){
 		parent::__construct($webserviceObject,$user,$adb,$log);
-		$this->meta = new VtigerCRMObjectMeta($this->webserviceObject,$this->user);
+		$this->meta = $this->getMetaInstance();
 		$this->tabId = $this->meta->getTabId();
 	}
 	
+	protected function getMetaInstance(){
+		if(empty(WebserviceEntityOperation::$metaCache[$this->webserviceObject->getEntityName()][$this->user->id])){
+			WebserviceEntityOperation::$metaCache[$this->webserviceObject->getEntityName()][$this->user->id]  = new VtigerCRMObjectMeta($this->webserviceObject,$this->user);
+		}
+		return WebserviceEntityOperation::$metaCache[$this->webserviceObject->getEntityName()][$this->user->id];
+	}
+	
 	public function create($elementType,$element){
 		$crmObject = new VtigerCRMObject($elementType, false);
 		
@@ -31,12 +38,18 @@ class VtigerModuleOperation extends WebserviceEntityOperation {
 		}
 		
 		$id = $crmObject->getObjectId();
+
+		// Bulk Save Mode
+		if(CRMEntity::isBulkSaveMode()) {		
+			// Avoiding complete read, as during bulk save mode, $result['id'] is enough
+			return array('id' => vtws_getId($this->meta->getEntityId(), $id) );
+		}
 		
 		$error = $crmObject->read($id);
 		if(!$error){
 			throw new WebServiceException(WebServiceErrorCode::$DATABASEQUERYERROR,
-					vtws_getWebserviceTranslatedString('LBL_'.
-							WebServiceErrorCode::$DATABASEQUERYERROR));
+				vtws_getWebserviceTranslatedString('LBL_'.
+						WebServiceErrorCode::$DATABASEQUERYERROR));
 		}
 		
 		return DataTransform::filterAndSanitize($crmObject->getFields(),$this->meta);
