@@ -13,7 +13,15 @@ $app_strings = array (
 	'DocumentFolders'=>'Carpetas Documentos',
 	'Currency'=>'Monedas',
 	'SINGLE_Groups'=>'Grupo',
-	'SINGLE_DocumentFolders'=>'Carpeta Document',
+	'SINGLE_DocumentFolders'=>'Carpeta Documento',
 	'SINGLE_Currency'=>'Moneda',
 );
+
+$webservice_strings = array(
+	'LBL_INVALID_OLD_PASSWORD' => 'Contraseña anterior inválida.',
+	'LBL_NEW_PASSWORD_MISMATCH' => "Nueva contraseña y confirmación no coinciden.",
+	'LBL_DATABASE_QUERY_ERROR' => 'Error de base de datos al procesar la operación',
+	'LBL_CHANGE_PASSWORD_FAILURE' => 'No se ha podido cambiar la contraseña',
+);
+
 ?>
