@@ -18,7 +18,12 @@ $optionalModuleStrings = array(
 	'SMSNotifier_description'=>'Envío de mensajes SMS a Cuentas, Contactos y PreContactos',
 	'Assets_description'=>'Gestión de Recursos',
 	'ModComments_description' => 'Permite añadir comentarios a las entidades relacionadas',
-    'Projects_description' => 'Gestión de Proyectos, Tareas e Hitos',
+	'Projects_description' => 'Gestión de Proyectos, Tareas e Hitos',
+	'Dutch_description' => 'Dutch Language pack',
+	'French_description' => 'Pack de langue Francais',
+	'Hungarian_description' => 'Hungarian Language pack',
+	'Spanish_description' => 'Paquete Idioma Español',
+	'Deutsch_description' => 'Paquete Idioma Alemán',
 );
 
 $installationStrings = array(
@@ -42,7 +47,7 @@ $installationStrings = array(
 	'LBL_SYSTEM_CONFIGURATION'=> 'Configuración Sistema',
 	'LBL_INSTALLATION_CHECK' => 'Verificación de Instalación',
 	'LBL_PRE_INSTALLATION_CHECK' => 'Verificación antes de Instalación',
-	'LBL_CHECK_AGAIN' => 'Verificar de nuevo',
+	'LBL_CHECK_AGAIN' => 'Verificar',
 	'LBL_CONFIRM_SETTINGS' => 'Confirmar Configuración',
 	'LBL_CONFIRM_CONFIG_SETTINGS' => 'Confirmar Datos de Configuración',
 	'LBL_CONFIG_FILE_CREATION' => 'Creando Fichero Configuración',
@@ -53,7 +58,7 @@ $installationStrings = array(
 	'MSG_CONFIG_FILE_CREATED' => 'Fichero de Configuración (config.inc.php) creado correctamente',
 	'LBL_FINISH' => 'Terminar',
 	'LBL_CONFIG_COMPLETED' => 'Configuración Completada',
-	'LBL_PHP_VERSION_GT_5' => 'Versión PHP >= 5.0',
+	'LBL_PHP_VERSION_GT_5' => 'Versión PHP >= 5.2',
 	'LBL_YES' => 'Sí',
 	'LBL_NO' => 'No',
 	'LBL_NOT_CONFIGURED' => 'No Configurado',
@@ -94,7 +99,7 @@ $installationStrings = array(
 	'LBL_MISSING_REQUIRED_FIELDS' => 'Faltan campos obligatorios',
 	'ERR_ADMIN_EMAIL_INVALID' => 'La cuenta de correo del usuario admin es inválida',
 	'ERR_STANDARDUSER_EMAIL_INVALID' => 'La cuenta de correo del usuario standard es inválida',
-	'WARNING_LOCALHOST_IN_SITE_URL' => 'Indica el nombre de servidor exacto en vez de \"localhost\" en la URL del servidor, o tendrá algunos problemas con las extensiones de la aplicación. ¿Quieres continuar?',
+	'WARNING_LOCALHOST_IN_SITE_URL' => 'Indica el nombre de servidor exacto en vez de "localhost" en la URL del servidor, o tendrá algunos problemas con las extensiones de la aplicación. ¿Quieres continuar?',
 	'LBL_DATABASE_CONFIGURATION' => 'Configuración Base de Datos',
 	'LBL_ENABLED' => 'Habilitado',
 	'LBL_NOT_ENABLED' => 'No Habilitado',
@@ -214,9 +219,22 @@ $installationStrings = array(
 	'LBL_OLD_VERSION_IS_AT' => 'La versión anterior está disponible en : ',
 	'LBL_CURRENT_SOURCE_PATH_IS' => 'El camino del código es : ',
 	'LBL_DATABASE_EXTENSION' =>'Extensión Base de Datos',
-	'LBL_DOCUMENTATION_LINK' => 'Para obtener más información, accede a <a href="http://wiki.vtiger.com" target="_blank">Manual vtigerCRM</a>',
+	'LBL_DOCUMENTATION_TEXT' => 'Documentación, incluiendo el Manual del Usuario, puede obtenerse en',
     'LBL_USER_PASSWORD_CHANGE_NOTE' => 'contraseñas de todos los usuarios se cambiará al nombre del usuario. Por favor, informa a todos los usuarios y que procedan a cambiar su contraseña',
-	'LBL_PASSWORD_FIELD_CHANGE_FAILURE' => "no se ha podido cambiar el campo de contraseña"
-
+	'LBL_PASSWORD_FIELD_CHANGE_FAILURE' => "no se ha podido cambiar el campo de contraseña",
+	'LBL_OPENSSL_SUPPORT' => 'Soporte de OpenSSL',
+	'LBL_OPTIONAL_MORE_LANGUAGE_PACK' => 'Paquetes de idioma adicionales se pueden obtener en',
+	'LBL_GETTING_STARTED' => 'Primeros pasos:',
+	'LBL_GETTING_STARTED_TEXT' => 'Puedes empezar a utilizar tu CRM ahora.',
+	'LBL_YOUR_LOGIN_PAGE' => 'La página de acceso:',
+	'LBL_ADD_USERS' => 'Para añadir más usuarios, accede a la página de Configuración.',
+	'LBL_SETUP_BACKUP' => "No olvides configurar el 'Servidor de Copias' para mantener un copia de la información y los ficheros de tu CRM en otra ubicación regularmente. ",
+	'LBL_RECOMMENDED_STEPS' => 'Pasos Recomendados:',
+	'LBL_RECOMMENDED_STEPS_TEXT' => 'Es importante que completes los siguientes pasos',
+	'LBL_DOCUMENTATION_TUTORIAL' => 'Documentación y Tutorial',
+	'LBL_WELCOME_FEEDBACK' => 'Agradecemos tus comentarios',
+	'LBL_TUTORIAL_TEXT' => 'Hay tutoriales en vídeo disponibles en',
+	'LBL_DROP_A_MAIL' => 'Mándanos un email a',
+	'LBL_LOGIN_PAGE' => 'La página de acceso: ',
 );
 ?>
