@@ -21,7 +21,7 @@
  ********************************************************************************/
 $app_strings = array (
 'LBL_BROWSER_TITLE' => 'vtiger CRM 5 - Commercial Open Source CRM',
-'LBL_MY_ACCOUNT' => 'My Account',
+'LBL_MY_ACCOUNT' => 'My Organization',
 'LBL_MY_PREFERENCES' => 'My Preferences',
 'LBL_ADMIN' => 'Admin',
 'LBL_LOGOUT' => 'Sign Out',
@@ -118,7 +118,7 @@ $app_strings = array (
 'LBL_LIST_EMAIL' => 'Email',
 'LBL_LIST_PHONE' => 'Phone',
 'LBL_LIST_CONTACT_NAME' => 'Contact Name',
-'LBL_LIST_ACCOUNT_NAME' => 'Account Name',
+'LBL_LIST_ACCOUNT_NAME' => 'Organization Name',
 'LBL_USER_LIST' => 'User List',
 'LBL_CONTACT_LIST' => 'Contact List',
 'LBL_LNK_SETTINGS' => 'Settings',
@@ -143,7 +143,7 @@ $app_strings = array (
 'LNK_VTDOCS' => 'vtiger Docs',
 'LNK_ABOUT' => 'About',
 'LNK_OUTLOOK' => './include/images/outlook_download.gif',
-'SINGLE_Accounts' => 'Account',
+'SINGLE_Accounts' => 'Organization',
 'SINGLE_Contacts' => 'Contact',
 'SINGLE_Campaigns' => 'Campaign',
 'SINGLE_HelpDesk' => 'Ticket',
@@ -155,7 +155,7 @@ $app_strings = array (
 'SINGLE_Faq' => 'Faq',
 'SINGLE_Home' => 'Home',
 'SINGLE_Invoice' => 'Invoice',
-'SINGLE_Potentials' => 'Potential',
+'SINGLE_Potentials' => 'Opportunity',
 'SINGLE_Products' => 'Product',
 'SINGLE_Vendors' => 'Vendor',
 'SINGLE_PriceBooks' => 'PriceBook',
@@ -176,7 +176,7 @@ $app_strings = array (
 'NTC_TIME_FORMAT' => '(24:00)',
 'NTC_DATE_TIME_FORMAT' => '(yyyy-mm-dd 24:00)',
 'NTC_DELETE_CONFIRMATION' => 'Are you sure you want to delete this record?',
-'NTC_ACCOUNT_DELETE_CONFIRMATION' => 'Deleting this account will remove its related Potentials & Quotes. Are you sure you want to delete this account?',
+'NTC_ACCOUNT_DELETE_CONFIRMATION' => 'Deleting this account will remove its related Opportunities & Quotes. Are you sure you want to delete this account?',
 'NTC_VENDOR_DELETE_CONFIRMATION' => 'Deleting this vendor will remove its related Purchase Orders. Are you sure you want to delete this vendor?',
 'ERR_DELETE_RECORD' => 'A record number must be specified to delete the contact.',
 'ERR_CREATING_TABLE' => 'Error creating table: ',
@@ -200,6 +200,7 @@ $app_strings = array (
 'NTC_LOGIN_MESSAGE' => 'Login',
 'LBL_NONE' => '--None--',
 'LBL_BACK' => 'Back',
+'LBL_TIMEFIELD'=>'(HH:mm:ss)',
 'LBL_IMPORT' => 'Import',
 'LBL_EXPORT' => 'Export',
 'LBL_EXPORT_ALL' => 'Export All',
@@ -207,7 +208,7 @@ $app_strings = array (
 'Export' => 'Export',
 'Import' => 'Import',
 'Merge' => 'Merge',
-'ConvertLead' => 'ConvertLead',
+'ConvertLead' => 'Convert Lead',
 'LBL_SHOW_RESULTS' => 'Show Results in',
 'LBL_TOTAL_RECORDS_FOUND' => 'Total Records found :',
 'LBL_SEARCH_RESULTS_FOR' => ' -- Search results for ',
@@ -281,7 +282,7 @@ $app_strings = array (
 'LBL_NEW_TASK' => 'New Task',
 'LBL_NEW_EVENT' => 'New Event',
 'LBL_ATTACHMENT_AND_NOTES' => 'Attachments & Notes',
-'LBL_POTENTIAL_NAME' => 'Potential Name',
+'LBL_POTENTIAL_NAME' => 'Opportunity Name',
 'LBL_CONTACT_NAME' => 'Contact Name',
 'LBL_DEPARTMENT' => 'Department',
 'LBL_ROLE' => 'Role',
@@ -299,11 +300,11 @@ $app_strings = array (
 'LBL_PURCHASE_DATE' => 'Purchase Date',
 'LBL_TICKET_ID' => 'Ticket Id',
 'LBL_TICKETS' => 'Tickets',
-'LBL_POTENTIAL_TITLE' => 'Potentials',
-'LBL_NEW_POTENTIAL' => 'New Potential',
+'LBL_POTENTIAL_TITLE' => 'Opportunities',
+'LBL_NEW_POTENTIAL' => 'New Opportunity',
 'LBL_LEAD_NAME' => 'Lead Name',
-'LBL_ACCOUNT_NAME' => 'Account Name',
-'LBL_ACCOUNT_TYPE' => 'Account Type',
+'LBL_ACCOUNT_NAME' => 'Organization Name',
+'LBL_ACCOUNT_TYPE' => 'Organization Type',
 'LBL_USER_TITLE' => 'Users',
 'LBL_CONTACT_TITLE' => 'Contacts',
 'LBL_SHOWING' => 'Showing',
@@ -325,9 +326,9 @@ $app_strings = array (
 'LBL_HOUR_AND_MINUTE' => '(hours/minutes)',
 'YEAR_MONTH_DATE' => '24:00',
 'COMBO_LEADS' => 'Leads',
-'COMBO_ACCOUNTS' => 'Accounts',
+'COMBO_ACCOUNTS' => 'Organizations',
 'COMBO_CONTACTS' => 'Contacts',
-'COMBO_POTENTIALS' => 'Potentials',
+'COMBO_POTENTIALS' => 'Opportunities',
 'COMBO_PRODUCTS' => 'Products',
 'COMBO_HELPDESK' => 'Trouble Tickets',
 'COMBO_USERS' => 'Users',
@@ -341,10 +342,10 @@ $app_strings = array (
 'Website' => 'Website',
 'Email' => 'Email',
 'Assigned To' => 'Assigned To',
-'Account Name' => 'Account Name',
+'Account Name' => 'Organization Name',
 'City' => 'City',
 'Title' => 'Title',
-'Potential' => 'Potential',
+'Potential' => 'Opportunity',
 'Sales Stage' => 'Sales Stage',
 'Amount' => 'Amount',
 'Expected Close' => 'Expected Close',
@@ -372,10 +373,10 @@ $app_strings = array (
 'LBL_CUSTOM_INFORMATION' => 'Custom Information',
 'LBL_NONE_SCHEDULED' => 'None Scheduled',
 'Leads' => 'Leads',
-'Accounts' => 'Accounts',
-'Accounts & Contacts' => 'Accounts & Contacts',
+'Accounts' => 'Organizations',
+'Accounts & Contacts' => 'Organizations & Contacts',
 'Contacts' => 'Contacts',
-'Potentials' => 'Potentials',
+'Potentials' => 'Opportunities',
 'Products' => 'Products',
 'Emails' => 'Email',
 'HelpDesk' => 'Trouble Tickets',
@@ -424,9 +425,9 @@ $app_strings = array (
 'LBL_EDITING' => 'Editing',
 'LBL_NEW' => 'New',
 'Lead' => 'Lead',
-'Account' => 'Account',
+'Account' => 'Organization',
 'Contact' => 'Contact',
-'Opportunity' => 'Potential',
+'Opportunity' => 'Opportunity',
 'Product' => 'Product',
 'Activity' => 'Activity',
 'Event' => 'Event',
@@ -450,7 +451,7 @@ $app_strings = array (
 'LBL_ABOUTUS_TITLE' => 'vtiger CRM - About Us',
 'LBL_DISCUSS' => 'Discuss with other users',
 'Quote Stage' => 'Quote Stage',
-'Potential Name' => 'Potential Name',
+'Potential Name' => 'Opportunity Name',
 'Total' => 'Total Amount',
 'First Name' => 'First Name',
 'Last Name' => 'Last Name',
@@ -511,10 +512,11 @@ $app_strings = array (
 'LBL_JSCALENDAR_LANG' => 'en',
 'LNK_CV_EDIT' => 'Edit',
 'LNK_CV_DELETE' => 'Delete',
-'LNK_CV_CREATEVIEW' => 'New',
+'LNK_CV_CREATEVIEW' => 'Create Filter',
 'LBL_UPD_FIELD_ORD' => 'Update Field Order',
 'LBL_SEND_CUSTOM_MAIL_BUTTON' => 'Send Custom Mail',
 'LBL_UPDATED_TODAY' => 'Updated today',
+'LBL_BY' => 'By ',
 'LBL_UPDATED' => 'Updated',
 'LBL_DAY_AGO' => 'day ago',
 'LBL_DAYS_AGO' => 'days ago',
@@ -573,7 +575,6 @@ $app_strings = array (
 'LBL_NO' => 'No',
 'LBL_FOUND' => 'Found',
 'LBL_YOU_CAN_CREATE' => 'You can Create',
-'LBL_NOW' => 'now',
 'LBL_CLICK_THE_LINK' => 'Click the link below',
 'LBL_CREATE' => 'Create',
 'LBL_A' => 'a',
@@ -616,7 +617,7 @@ $app_strings = array (
 'industry' => 'Industry',
 'Severity' => 'Severity',
 'Product Category' => 'Product Category',
-'GL Account' => 'GL Account',
+'GL Account' => 'GL Organization',
 'Usage Unit' => 'Usage Unit',
 'Carrier' => 'Carrier',
 'Expected Response' => 'Expected Response',
@@ -683,17 +684,17 @@ $app_strings = array (
 'Thank_You_HelpDesk' => ' is yet to be closed<br> Thank You,<br> HelpDesk Team<br>',
 'Big_Deal_Closed_Successfully' => 'Big Deal Closed Successfully',
 'Dear_Team' => 'Dear Team,<br>',
-'Potential_Name' => 'Potential Name:',
-'Potential_Id' => 'Potential Id:',
+'Potential_Name' => 'Opportunity Name:',
+'Potential_Id' => 'Opportunity Id:',
 'Dear_Team_Time_to_Party' => '<br>Congratulations!Time to Party! <br>We closed a deal worth more than 10000!!!!<br> Time to hit the dance floor!<br>',
 'Task_Not_completed' => 'Task Not completed',
 'Too_many_pending_tickets' => 'Too many pending tickets',
-'Dear_Admin_too_ many_tickets_pending' => 'Dear Admin,<br> This is to bring to your notice that there are too many tickets pending. Kindly take the necessary action required for addressing the same<br><br> Thanks and Regards,<br> HelpDesk Team<br>',
+'Dear_Admin_too_many_tickets_pending' => 'Dear Admin,<br> This is to bring to your notice that there are too many tickets pending. Kindly take the necessary action required for addressing the same<br><br> Thanks and Regards,<br> HelpDesk Team<br>',
 
 //Added for java script alerts
 'DELETE_CONFIRMATION' => 'Are you sure you want to delete the selected ',
 'SELECT_ATLEAST_ONE' => 'Please select at least one entity',
-'DELETING_ACCOUNT' => 'Deleting this account(s) will remove its related Potentials,Quotes,Sales Orders & Invoice. Are you sure you want to delete the selected ',
+'DELETING_ACCOUNT' => 'Deleting this account(s) will remove its related Opportunities,Quotes,Sales Orders & Invoice. Are you sure you want to delete the selected ',
 'DELETING_VENDOR' => 'Deleting this vendor(s) will remove its related Purchase Orders. Are you sure you want to delete the selected ',
 'PLEASE_SELECT_MAILID' => 'Please Select a mailid',
 'OVERWRITE_EXISTING_ACCOUNT1' => 'Do you want to Overwrite the existing address with this selected account(',
@@ -716,7 +717,7 @@ $app_strings = array (
 'SHOULDNOTBE_EQUAL' => ' should not be equal to ',
 'PORTAL_PROVIDE_EMAILID' => 'Portal user should provide email Id for portal login',
 'ADD_CONFIRMATION' => 'Are you sure you want to add the selected ',
-'ACCOUNTNAME_CANNOT_EMPTY' => 'AccountName Cannot be Empty',
+'ACCOUNTNAME_CANNOT_EMPTY' => 'OrganizationName Cannot be Empty',
 'CANT_SELECT_CONTACTS' => "You can\'t select related contacts from Lead",
 'LBL_THIS' => 'This ',
 'DOESNOT_HAVE_MAILIDS' => " doesn\'t have any mail ids",
@@ -724,7 +725,7 @@ $app_strings = array (
 'ARE_YOU_SURE' => 'Are you sure?',
 'MISSING_REPORT_NAME' => 'Missing Report Name',
 'REPORT_NAME_EXISTS' => 'Report name already exists, try again...',
-'WANT_TO_CHANGE_CONTACT_ADDR' => 'Do you want to change the addresses of the Contacts related to this Account?',
+'WANT_TO_CHANGE_CONTACT_ADDR' => 'Do you want to change the addresses of the Contacts related to this Organization?',
 'SURE_TO_DELETE' => 'Are you sure you want to delete ?',
 'RECORDS' => ' records ?',
 'NO_PRODUCT_SELECTED' => 'No product is selected. Select at least one Product',
@@ -752,7 +753,7 @@ $app_strings = array (
 'FOLLOWUPTIME_GREATER_THAN_STARTTIME' => 'Followup Time should be greater than End Time ',
 'MISSING_EVENT_NAME' => 'Missing Event Name',
 'EVENT_TYPE_NOT_SELECTED' => 'Event Type is not selected',
-'OPPORTUNITYNAME_CANNOT_BE_EMPTY' => 'Potential Name field cannot be empty',
+'OPPORTUNITYNAME_CANNOT_BE_EMPTY' => 'Opportunity Name field cannot be empty',
 'CLOSEDATE_CANNOT_BE_EMPTY' => 'Close Date field cannot be empty',
 'SITEURL_CANNOT_BE_EMPTY' => 'Site Url cannot be empty',
 'SITENAME_CANNOT_BE_EMPTY' => 'Site Name cannot be empty',
@@ -767,7 +768,7 @@ $app_strings = array (
 'SPECIAL_CHARACTERS_NOT_ALLOWED' => 'Special characters are not allowed in Label field',
 'DUPLICATE_MAPPING_ACCOUNTS' => 'Duplicate mapping for accounts!!',
 'DUPLICATE_MAPPING_CONTACTS' => 'Duplicate mapping for Contacts!!',
-'DUPLICATE_MAPPING_POTENTIAL' => 'Duplicate mapping for Potential!!',
+'DUPLICATE_MAPPING_POTENTIAL' => 'Duplicate mapping for Opportunity!!',
 'ERROR_WHILE_EDITING' => 'Error while Editing',
 'PLEASE_ENTER_TAG' => 'Please enter a tag',
 'PLEASE_SELECT_LINE_ITEM' => 'Please select a Line Item',
@@ -787,7 +788,7 @@ $app_strings = array (
 'DELETE_REPORT_CONFIRMATION' => 'Are you sure you want to delete this report ?',
 'MOVE_REPORT_CONFIRMATION' => 'Are you sure you want to move this report to ',
 'FOLDER' => ' folder ?',
-'ACCOUNT_ACCESS_INFO' => 'Potentials, HelpDesk, Quotes, SalesOrder & Invoice Access must be set to Private when the Account Access is set to Private',
+'ACCOUNT_ACCESS_INFO' => 'Opportunities, HelpDesk, Quotes, SalesOrder & Invoice Access must be set to Private when the Organization Access is set to Private',
 'PROFILENAME_CANNOT_BE_EMPTY' => 'Profile Name Cannot be empty',
 'PROFILE_DETAILS_UPDATED' => 'Profile Details are updated',
 'CURRENCY_CHANGE_INFO' => 'Currency Changes has been made Successfully',
@@ -886,8 +887,8 @@ $app_strings = array (
 'LBL_CREATING_NEW_Contacts' => 'Creating New Contact',
 'LBL_CREATING_NEW_Campaigns' => 'Creating New Campaign',
 'LBL_CREATING_NEW_Leads' => 'Creating New Lead',
-'LBL_CREATING_NEW_Accounts' => 'Creating New Account',
-'LBL_CREATING_NEW_Potentials' => 'Creating New Potential',
+'LBL_CREATING_NEW_Accounts' => 'Creating New Organization',
+'LBL_CREATING_NEW_Potentials' => 'Creating New Opportunity',
 'LBL_CREATING_NEW_Quotes' => 'Creating New Quote',
 'LBL_CREATING_NEW_SalesOrder' => 'Creating New Sales Order',
 'LBL_CREATING_NEW_Invoice' => 'Creating New Invoice',
@@ -945,7 +946,6 @@ $app_strings = array (
 'LBL_DATA_IN_CURRENT_PAGE'=>'Export data in current page',
 'LBL_ONLY_SELECTED_RECORDS'=>'Export selected records',
 'LBL_YES'=>'Yes',
-'LBL_NO'=>'No',
 'Planned'=>'Planned',
 'Held'=>'Held',
 'Not Held'=>'Not Held',
@@ -1049,7 +1049,7 @@ $app_strings = array (
 'Req. No.'=>'Req. No.',
 'Customer Name'=>'Customer Name',
 'SO Number'=>'SO Number',
-'Account Number'=>'Account Number',
+'Account Number'=>'Organization Number',
 'Valid Till'=>'Valid Till',
 'Quote Number'=>'Quote Number',
 'Invoice Number'=>'Invoice Number',
@@ -1164,7 +1164,7 @@ $app_strings = array (
 'LBL_ASTERISK_SET_ERROR'=>'Asterisk server details are not set. Set them first.',
 'LBL_CREATE_LEAD'=>'Create Lead',
 'LBL_CREATE_CONTACT'=>'Create Contact',
-'LBL_CREATE_ACCOUNT'=>'Create Account',
+'LBL_CREATE_ACCOUNT'=>'Create Organization',
 'LBL_CREATE_TICKET'=>'Create Tickets',
 'LBL_INCOMING_CALL'=>'Incoming Call',
 'LBL_CALLER_INFORMATION'=>'Caller Information',
@@ -1207,7 +1207,7 @@ $app_strings = array (
 'PUBLIC_FILTER'=>'Public',
 
 // Account Hierarchy
-'LBL_ACCOUNT_HIERARCHY' => 'Account Hierarchy', 
+'LBL_ACCOUNT_HIERARCHY' => 'Organization Hierarchy',
 
 //Prod Bundles
 'LBL_NO_SUB_PRODUCTS'=>'Not a Bundle',
@@ -1267,19 +1267,43 @@ $app_strings = array (
 		  is no longer applicable, please reset your password.',
 	'LBL_RESET_PASSWORD_DESCRIPTION' => 'you can reset password for all users using a script and set it to thier respective
 			  user names.',
-
 'LBL_CRITERIA_AND'=>'and',
 'LBL_CRITERIA_OR'=>'or',
 'LBL_NEW_GROUP'=>'New Group',
 'LBL_DELETE_GROUP'=>'Delete Group',
 'LBL_NEW_CONDITION'=>'New Condition',
 'LBL_ADVANCED_FILTER' => 'Advanced Search',
-
 'LBL_CHANGE'=>'Change',
 'LBL_CHANGE_TITLE'=>'Change [Alt+C]',
-
 'LBL_NEXT_BUTTON_LABEL' => 'Next',
-
+'LBL_MAX_SIZE'=> 'Maximum upload size is', //added for uploadsize limit message
+'LBL_FILESIZEIN_MB'=> 'MB', //added to show filesize in MB
+'LBL_DISABLED' => 'Disabled',
+'LBL_RUNNING' => 'Running',
+'LBL_LAST_SCAN_TIMED_OUT' => 'Last Scan Timed Out',
+'LBL_LAST_SCAN_AT' => 'Last Scan @',
+'LBL_TIME_TAKEN' => 'Time taken',
+'LBL_SHORT_SECONDS' => 'sec',
+'Projects' => 'Projects',
+'End Time' => 'End Time',
+'Start Time' => 'Start Time',
+'Email2' => 'Email2',
+'Comments' => 'Comments',
+'Issued Date' => 'Issued Date',
+'Shipping & Handling Charges' => 'Shipping & Handling Charges',
+'Shipping & Handling Tax:' => 'Shipping & Handling Tax:',
+'Quantity' => 'Quantity',
+'Net Total' => 'Net Total',
+'Send SMS' => 'Send SMS',
+'LBL_MORE'=>'More',
+'LBL_CRM_SETTINGS' => 'CRM Settings',
+'LBL_RELATED_TO_THIS' =>'related to this',
+'LBL_DESELECT_ALL' => 'Deselect all',
+'LBL_RECORDS_IN' => 'records in',
+'LBL_FOLDER' => 'folder',
+'LBL_ADD_MAPPING'=> 'Add Mapping',
+'LBL_FIELD_MAPPING' => 'Field Mapping',
+'LBL_MANDATORY_FIELD_MISSING'=>'Mandatory Field value is missing',
 );
 
 $app_list_strings = array (
@@ -1289,8 +1313,8 @@ $app_list_strings = array (
     'Dashboard' => 'Dashboard',
     'Leads' => 'Leads',
     'Contacts' => 'Contacts',
-    'Accounts' => 'Accounts',
-    'Potentials' => 'Potentials',
+    'Accounts' => 'Organizations',
+    'Potentials' => 'Oppurtunities',
     'Campaigns' => 'Campaigns',
     'Emails' => 'Emails',
     'Activities' => 'Activities',
@@ -1369,10 +1393,10 @@ $app_list_strings = array (
     'Active' => 'Active',
     'Inactive' => 'Inactive',
   ),
-  'record_type_default_key' => 'Accounts',
+  'record_type_default_key' => 'Organizations',
   'record_type_display' => 
   array (
-    'Accounts' => 'Account',
+    'Accounts' => 'Organization',
     'Leads' => 'Lead',
     'Opportunities' => 'Opportunity',
   ),
