@@ -19,7 +19,7 @@ function getProductDetailsBlockInfo($mode,$module,$focus='',$num_of_products='',
 {
 	global $log;
 	$log->debug("Entering getProductDetailsBlockInfo(".$mode.",".$module.",".$num_of_products.",".$associated_prod.") method ...");
-	
+
 	$productDetails = Array();
 	$productBlock = Array();
 	if($num_of_products=='')
@@ -47,7 +47,7 @@ function getProductDetailsBlockInfo($mode,$module,$focus='',$num_of_products='',
 	else
 	{
 		$productBlock[] = Array(Array());
-		
+
 	}
 	$log->debug("Exiting getProductDetailsBlockInfo method ...");
 	return $productBlock;
@@ -58,7 +58,7 @@ function getProductDetailsBlockInfo($mode,$module,$focus='',$num_of_products='',
  * Param $productid - product id
  * Param $qty - product quantity in no's
  * Param $mode - mode type
- * Param $ext_prod_arr - existing vtiger_products 
+ * Param $ext_prod_arr - existing vtiger_products
  * Param $module - module name
  * return type void
  */
@@ -76,10 +76,10 @@ function updateStk($product_id,$qty,$mode,$ext_prod_arr,$module)
 	$prod_name = getProductName($product_id);
 	$qtyinstk= getPrdQtyInStck($product_id);
 	$log->debug("Prd Qty in Stock ".$qtyinstk);
-	
+
 	$upd_qty = $qtyinstk-$qty;
 	sendPrdStckMail($product_id,$upd_qty,$prod_name,$qtyinstk,$qty,$module);
-	
+
 	$log->debug("Exiting updateStk method ...");
 }
 
@@ -88,8 +88,8 @@ function updateStk($product_id,$qty,$mode,$ext_prod_arr,$module)
  * Param $product_id - product id
  * Param $upd_qty - updated product quantity in no's
  * Param $prod_name - product name
- * Param $qtyinstk - quantity in stock 
- * Param $qty - quantity  
+ * Param $qtyinstk - quantity in stock
+ * Param $qty - quantity
  * Param $module - module name
  * return type void
  */
@@ -106,9 +106,13 @@ function sendPrdStckMail($product_id,$upd_qty,$prod_name,$qtyinstk,$qty,$module)
 	if($upd_qty < $reorderlevel)
 	{
 		//send mail to the handler
-		$handler=getPrdHandler($product_id);
-		$handler_name = getUserName($handler);
-		$to_address= getUserEmail($handler);
+		$handler = getRecordOwnerId($product_id);
+		$handler_name = getOwnerName($handler);
+		if(vtws_isRecordOwnerUser($handler)) {
+			$to_address = getUserEmail($handler);
+		} else {
+			$to_address = implode(',', getDefaultAssigneeEmailIds($handler));
+		}
 
 		//Get the email details from database;
 		if($module == 'SalesOrder')
@@ -131,24 +135,24 @@ function sendPrdStckMail($product_id,$upd_qty,$prod_name,$qtyinstk,$qty,$module)
 		$subject = $adb->query_result($result,0,'notificationsubject');
 		$body = $adb->query_result($result,0,'notificationbody');
 		$status = $adb->query_result($result,0,'status');
-		
+
 		if($status == 0 || $status == '')
 				return false;
-	
+
 		$subject = str_replace('{PRODUCTNAME}',$prod_name,$subject);
-		$body = str_replace('{HANDLER}',$handler_name,$body);	
-		$body = str_replace('{PRODUCTNAME}',$prod_name,$body);	
+		$body = str_replace('{HANDLER}',$handler_name,$body);
+		$body = str_replace('{PRODUCTNAME}',$prod_name,$body);
 		if($module == 'Invoice')
 		{
-			$body = str_replace('{CURRENTSTOCK}',$upd_qty,$body);	
+			$body = str_replace('{CURRENTSTOCK}',$upd_qty,$body);
 			$body = str_replace('{REORDERLEVELVALUE}',$reorderlevel,$body);
 		}
 		else
 		{
-			$body = str_replace('{CURRENTSTOCK}',$qtyinstk,$body);	
-			$body = str_replace($quan_name,$qty,$body);	
+			$body = str_replace('{CURRENTSTOCK}',$qtyinstk,$body);
+			$body = str_replace($quan_name,$qty,$body);
 		}
-		$body = str_replace('{CURRENTUSER}',$current_user->user_name,$body);	
+		$body = str_replace('{CURRENTUSER}',$current_user->user_name,$body);
 
 		$mail_status = send_mail($module,$to_address,$current_user->user_name,$current_user->email1,decode_html($subject),nl2br(to_html($body)));
 	}
@@ -188,23 +192,6 @@ function getPrdReOrderLevel($product_id)
 	return $reorderlevel;
 }
 
-/**This function is used to get the handler for a given product
-*Param $product_id - product id
-*Returns type numeric
-*/
-
-function getPrdHandler($product_id)
-{
-	global $log;
-	$log->debug("Entering getPrdHandler(".$product_id.") method ...");
-	global $adb;
-	$query1 = "SELECT handler FROM vtiger_products WHERE productid = ?";
-	$result=$adb->pquery($query1, array($product_id));
-	$handler= $adb->query_result($result,0,"handler");
-	$log->debug("Exiting getPrdHandler method ...");
-	return $handler;
-}
-
 /**	function to get the taxid
  *	@param string $type - tax type (VAT or Sales or Service)
  *	return int   $taxid - taxid corresponding to the Tax type from vtiger_inventorytaxinfo vtiger_table
@@ -291,7 +278,7 @@ function addInventoryHistory($module, $id, $relatedname, $total, $history_fldval
 	$histid = $adb->getUniqueID($history_table_array[$module]);
  	$modifiedtime = $adb->formatDate(date('Y-m-d H:i:s'), true);
  	$query = "insert into $history_table_array[$module] values(?,?,?,?,?,?)";
-	$qparams = array($histid,$id,$relatedname,$total,$history_fldval,$modifiedtime);	
+	$qparams = array($histid,$id,$relatedname,$total,$history_fldval,$modifiedtime);
 	$adb->pquery($query, $qparams);
 
 	$log->debug("Exit from function addInventoryHistory");
@@ -319,7 +306,7 @@ function getAllTaxes($available='all', $sh='',$mode='',$id='')
 		$tablename = 'vtiger_inventorytaxinfo';
 		$value_table='vtiger_inventoryproductrel';
 	}
-	
+
 	if($mode == 'edit' && $id != '' )
 	{
 		//Getting total no of taxes
@@ -362,11 +349,11 @@ function getAllTaxes($available='all', $sh='',$mode='',$id='')
 		{
 			$where = " where $tablename.deleted=0";
 		}
-	
+
 		$res = $adb->pquery("select * from $tablename $where order by deleted",array());
 
 	}
-	
+
 	$noofrows = $adb->num_rows($res);
 	for($i=0;$i<$noofrows;$i++)
 	{
@@ -377,7 +364,7 @@ function getAllTaxes($available='all', $sh='',$mode='',$id='')
 		$taxtypes[$i]['deleted'] = $adb->query_result($res,$i,'deleted');
 	}
 	$log->debug("Exit from the function getAllTaxes($available,$sh,$mode,$id)");
-	
+
 	return $taxtypes;
 }
 
@@ -412,7 +399,7 @@ function getTaxDetailsForProduct($productid, $available='all')
 		//Postgres 8 fixes
  		if( $adb->dbType == "pgsql")
  		    $query = fixPostgresQuery( $query, $log, 0);
-		
+
 		$res = $adb->pquery($query, $params);
 		for($i=0;$i<$adb->num_rows($res);$i++)
 		{
@@ -442,7 +429,7 @@ function deleteInventoryProductDetails($focus)
 {
 	global $log, $adb,$updateInventoryProductRel_update_product_array;
 	$log->debug("Entering into function deleteInventoryProductDetails(".$focus->id.").");
-	
+
 	$product_info = $adb->pquery("SELECT productid, quantity, sequence_no, incrementondel from vtiger_inventoryproductrel WHERE id=?",array($focus->id));
 	$numrows = $adb->num_rows($product_info);
 	for($index = 0;$index <$numrows;$index++){
@@ -450,17 +437,17 @@ function deleteInventoryProductDetails($focus)
 		$sequence_no = $adb->query_result($product_info,$index,'sequence_no');
 		$qty = $adb->query_result($product_info,$index,'quantity');
 		$incrementondel = $adb->query_result($product_info,$index,'incrementondel');
-		
+
 		if($incrementondel){
 			$focus->update_product_array[$focus->id][$sequence_no][$productid]= $qty;
-			$sub_prod_query = $adb->pquery("SELECT productid from vtiger_inventorysubproductrel WHERE id=? AND sequence_no=?",array($focus->id,$sequence_no)); 
+			$sub_prod_query = $adb->pquery("SELECT productid from vtiger_inventorysubproductrel WHERE id=? AND sequence_no=?",array($focus->id,$sequence_no));
 			if($adb->num_rows($sub_prod_query)>0){
 				for($j=0;$j<$adb->num_rows($sub_prod_query);$j++){
 					$sub_prod_id = $adb->query_result($sub_prod_query,$j,"productid");
 					$focus->update_product_array[$focus->id][$sequence_no][$sub_prod_id]= $qty;
 				}
 			}
-			
+
 		}
 	}
 	$updateInventoryProductRel_update_product_array = $focus->update_product_array;
@@ -492,7 +479,7 @@ function updateInventoryProductRel($entity)
 		}
 	}
 	$adb->pquery("UPDATE vtiger_inventoryproductrel SET incrementondel=1 WHERE id=?",array($entity_id));
-	
+
 	$product_info = $adb->pquery("SELECT productid,sequence_no, quantity from vtiger_inventoryproductrel WHERE id=?",array($entity_id));
 	$numrows = $adb->num_rows($product_info);
 	for($index = 0;$index <$numrows;$index++){
@@ -502,7 +489,7 @@ function updateInventoryProductRel($entity)
 		$qtyinstk= getPrdQtyInStck($productid);
 		$upd_qty = $qtyinstk-$qty;
 		updateProductQty($productid, $upd_qty);
-		$sub_prod_query = $adb->pquery("SELECT productid from vtiger_inventorysubproductrel WHERE id=? AND sequence_no=?",array($entity_id,$sequence_no)); 
+		$sub_prod_query = $adb->pquery("SELECT productid from vtiger_inventorysubproductrel WHERE id=? AND sequence_no=?",array($entity_id,$sequence_no));
 		if($adb->num_rows($sub_prod_query)>0){
 			for($j=0;$j<$adb->num_rows($sub_prod_query);$j++){
 				$sub_prod_id = $adb->query_result($sub_prod_query,$j,"productid");
@@ -598,7 +585,7 @@ function saveInventoryProductDetails(&$focus, $module, $update_prod_stock='false
 		$query ="insert into vtiger_inventoryproductrel(id, productid, sequence_no, quantity, listprice, comment, description) values(?,?,?,?,?,?,?)";
 		$qparams = array($focus->id,$prod_id,$prod_seq,$qty,$listprice,$comment,$description);
 		$adb->pquery($query,$qparams);
-		
+
 		$lineitem_id = $adb->getLastInsertID();
 
 		$sub_prod_str = $_REQUEST['subproduct_ids'.$i];
@@ -656,7 +643,7 @@ function saveInventoryProductDetails(&$focus, $module, $update_prod_stock='false
 			{
 				$tax_name = $taxes_for_product[$tax_count]['taxname'];
 				$request_tax_name = $tax_name."_percentage".$i;
-			
+
 				$updatequery .= " $tax_name = ?,";
 				array_push($updateparams, $_REQUEST[$request_tax_name]);
 			}
@@ -693,7 +680,7 @@ function saveInventoryProductDetails(&$focus, $module, $update_prod_stock='false
 		$updatequery .= " discount_amount=?,";
 		array_push($updateparams, $discount_amount_final);
 	}
-	
+
 	$shipping_handling_charge = $_REQUEST['shipping_handling_charge'];
 	$updatequery .= " s_h_amount=?,";
 	array_push($updateparams, $shipping_handling_charge);
@@ -756,7 +743,7 @@ function getInventoryTaxType($module, $id)
 
 	$inv_table_array = Array('PurchaseOrder'=>'vtiger_purchaseorder','SalesOrder'=>'vtiger_salesorder','Quotes'=>'vtiger_quotes','Invoice'=>'vtiger_invoice');
 	$inv_id_array = Array('PurchaseOrder'=>'purchaseorderid','SalesOrder'=>'salesorderid','Quotes'=>'quoteid','Invoice'=>'invoiceid');
-	
+
 	$res = $adb->pquery("select taxtype from $inv_table_array[$module] where $inv_id_array[$module]=?", array($id));
 
 	$taxtype = $adb->query_result($res,0,'taxtype');
@@ -779,7 +766,7 @@ function getInventoryCurrencyInfo($module, $id)
 
 	$inv_table_array = Array('PurchaseOrder'=>'vtiger_purchaseorder','SalesOrder'=>'vtiger_salesorder','Quotes'=>'vtiger_quotes','Invoice'=>'vtiger_invoice');
 	$inv_id_array = Array('PurchaseOrder'=>'purchaseorderid','SalesOrder'=>'salesorderid','Quotes'=>'quoteid','Invoice'=>'invoiceid');
-	
+
 	$inventory_table = $inv_table_array[$module];
 	$inventory_id = $inv_id_array[$module];
 	$res = $adb->pquery("select currency_id, $inventory_table.conversion_rate as conv_rate, vtiger_currency_info.* from $inventory_table
@@ -808,7 +795,7 @@ function getInventoryProductTaxValue($id, $productid, $taxname)
 {
 	global $log, $adb;
 	$log->debug("Entering into function getInventoryProductTaxValue($id, $productid, $taxname).");
-	
+
 	$res = $adb->pquery("select $taxname from vtiger_inventoryproductrel where id = ? and productid = ?", array($id, $productid));
 	$taxvalue = $adb->query_result($res,0,$taxname);
 
@@ -829,7 +816,7 @@ function getInventorySHTaxPercent($id, $taxname)
 {
 	global $log, $adb;
 	$log->debug("Entering into function getInventorySHTaxPercent($id, $taxname)");
-	
+
 	$res = $adb->pquery("select $taxname from vtiger_inventoryshippingrel where id= ?", array($id));
 	$taxpercentage = $adb->query_result($res,0,$taxname);
 
@@ -848,14 +835,14 @@ function getInventorySHTaxPercent($id, $taxname)
 function getAllCurrencies($available='available') {
 	global $adb, $log;
 	$log->debug("Entering into function getAllCurrencies($available)");
-	
+
 	$sql = "select * from vtiger_currency_info";
 	if ($available != 'all') {
 		$sql .= " where currency_status='Active' and deleted=0";
 	}
 	$res=$adb->pquery($sql, array());
 	$noofrows = $adb->num_rows($res);
-	
+
 	for($i=0;$i<$noofrows;$i++)
 	{
 		$currency_details[$i]['currencylabel'] = $adb->query_result($res,$i,'currency_name');
@@ -863,12 +850,12 @@ function getAllCurrencies($available='available') {
 		$currency_details[$i]['currencysymbol'] = $adb->query_result($res,$i,'currency_symbol');
 		$currency_details[$i]['curid'] = $adb->query_result($res,$i,'id');
 		$currency_details[$i]['conversionrate'] = $adb->query_result($res,$i,'conversion_rate');
-		$currency_details[$i]['curname'] = 'curname' . $adb->query_result($res,$i,'id');			
+		$currency_details[$i]['curname'] = 'curname' . $adb->query_result($res,$i,'id');
 	}
-	
+
 	$log->debug("Entering into function getAllCurrencies($available)");
 	return $currency_details;
-	
+
 }
 
 /**	Function used to get all the price details for different currencies which are associated to the given product
@@ -887,19 +874,19 @@ function getPriceDetailsForProduct($productid, $unit_price, $available='availabl
 		$product_base_conv_rate = getBaseConversionRateForProduct($productid,'edit',$itemtype);
 		// Detail View
 		if ($available == 'available_associated') {
-			$query = "select vtiger_currency_info.*, vtiger_productcurrencyrel.converted_price, vtiger_productcurrencyrel.actual_price 
-					from vtiger_currency_info 
+			$query = "select vtiger_currency_info.*, vtiger_productcurrencyrel.converted_price, vtiger_productcurrencyrel.actual_price
+					from vtiger_currency_info
 					inner join vtiger_productcurrencyrel on vtiger_currency_info.id = vtiger_productcurrencyrel.currencyid
-					where vtiger_currency_info.currency_status = 'Active' and vtiger_currency_info.deleted=0 
+					where vtiger_currency_info.currency_status = 'Active' and vtiger_currency_info.deleted=0
 					and vtiger_productcurrencyrel.productid = ? and vtiger_currency_info.id != ?";
 			$params = array($productid, $product_currency_id);
 		} else { // Edit View
-			$query = "select vtiger_currency_info.*, vtiger_productcurrencyrel.converted_price, vtiger_productcurrencyrel.actual_price 
-					from vtiger_currency_info 
-					left join vtiger_productcurrencyrel 
+			$query = "select vtiger_currency_info.*, vtiger_productcurrencyrel.converted_price, vtiger_productcurrencyrel.actual_price
+					from vtiger_currency_info
+					left join vtiger_productcurrencyrel
 					on vtiger_currency_info.id = vtiger_productcurrencyrel.currencyid and vtiger_productcurrencyrel.productid = ?
 					where vtiger_currency_info.currency_status = 'Active' and vtiger_currency_info.deleted=0";
-			$params = array($productid);			
+			$params = array($productid);
 		}
 
 		//Postgres 8 fixes
@@ -917,12 +904,12 @@ function getPriceDetailsForProduct($productid, $unit_price, $available='availabl
 			$price_details[$i]['curid'] = $currency_id;
 			$price_details[$i]['curname'] = 'curname' . $adb->query_result($res,$i,'id');
 			$cur_value = $adb->query_result($res,$i,'actual_price');
-			
-			// Get the conversion rate for the given currency, get the conversion rate of the product currency to base currency. 
+
+			// Get the conversion rate for the given currency, get the conversion rate of the product currency to base currency.
 			// Both together will be the actual conversion rate for the given currency.
 			$conversion_rate = $adb->query_result($res,$i,'conversion_rate');
 			$actual_conversion_rate = $product_base_conv_rate * $conversion_rate;
-			
+
 			if ($cur_value == null || $cur_value == '') {
 				$price_details[$i]['check_value'] = false;
 				if	($unit_price != null) {
@@ -935,25 +922,25 @@ function getPriceDetailsForProduct($productid, $unit_price, $available='availabl
 			}
 			$price_details[$i]['curvalue'] = CurrencyField::convertToUserFormat($cur_value, null, true);
 			$price_details[$i]['conversionrate'] = $actual_conversion_rate;
-			
+
 			$is_basecurrency = false;
 			if ($currency_id == $product_currency_id) {
 				$is_basecurrency = true;
 			}
-			$price_details[$i]['is_basecurrency'] = $is_basecurrency;		
+			$price_details[$i]['is_basecurrency'] = $is_basecurrency;
 		}
 	}
 	else
 	{
 		if($available == 'available') { // Create View
 			global $current_user;
-			
+
 			$user_currency_id = fetchCurrency($current_user->id);
-			
-			$query = "select vtiger_currency_info.* from vtiger_currency_info 
+
+			$query = "select vtiger_currency_info.* from vtiger_currency_info
 					where vtiger_currency_info.currency_status = 'Active' and vtiger_currency_info.deleted=0";
 			$params = array();
-			
+
 			$res = $adb->pquery($query, $params);
 			for($i=0;$i<$adb->num_rows($res);$i++)
 			{
@@ -963,23 +950,23 @@ function getPriceDetailsForProduct($productid, $unit_price, $available='availabl
 				$currency_id = $adb->query_result($res,$i,'id');
 				$price_details[$i]['curid'] = $currency_id;
 				$price_details[$i]['curname'] = 'curname' . $adb->query_result($res,$i,'id');
-				
-				// Get the conversion rate for the given currency, get the conversion rate of the product currency(logged in user's currency) to base currency. 
+
+				// Get the conversion rate for the given currency, get the conversion rate of the product currency(logged in user's currency) to base currency.
 				// Both together will be the actual conversion rate for the given currency.
 				$conversion_rate = $adb->query_result($res,$i,'conversion_rate');
 				$user_cursym_convrate = getCurrencySymbolandCRate($user_currency_id);
 				$product_base_conv_rate = 1 / $user_cursym_convrate['rate'];
 				$actual_conversion_rate = $product_base_conv_rate * $conversion_rate;
-				
+
 				$price_details[$i]['check_value'] = false;
 				$price_details[$i]['curvalue'] = '0';
-				$price_details[$i]['conversionrate'] = $actual_conversion_rate;		
-			
+				$price_details[$i]['conversionrate'] = $actual_conversion_rate;
+
 				$is_basecurrency = false;
 				if ($currency_id == $user_currency_id) {
 					$is_basecurrency = true;
 				}
-				$price_details[$i]['is_basecurrency'] = $is_basecurrency;				
+				$price_details[$i]['is_basecurrency'] = $is_basecurrency;
 			}
 		} else {
 			$log->debug("Product id is empty. we cannot retrieve the associated prices.");
@@ -997,14 +984,14 @@ function getPriceDetailsForProduct($productid, $unit_price, $available='availabl
 function getProductBaseCurrency($productid,$module='Products') {
 	global $adb, $log;
 	if ($module == 'Services') {
-		$sql = "select currency_id from vtiger_service where serviceid=?";		
+		$sql = "select currency_id from vtiger_service where serviceid=?";
 	} else {
 		$sql = "select currency_id from vtiger_products where productid=?";
 	}
-	$params = array($productid);	
+	$params = array($productid);
 	$res = $adb->pquery($sql, $params);
-	$currencyid = $adb->query_result($res, 0, 'currency_id');	
-	return $currencyid;	
+	$currencyid = $adb->query_result($res, 0, 'currency_id');
+	return $currencyid;
 }
 
 /**	Function used to get the conversion rate for the product base currency with respect to the CRM base currency
@@ -1014,24 +1001,24 @@ function getProductBaseCurrency($productid,$module='Products') {
  */
 function getBaseConversionRateForProduct($productid, $mode='edit', $module='Products') {
 	global $adb, $log, $current_user;
-	
+
 	if ($mode == 'edit') {
-		if ($module == 'Services') {			
-			$sql = "select conversion_rate from vtiger_service inner join vtiger_currency_info 
+		if ($module == 'Services') {
+			$sql = "select conversion_rate from vtiger_service inner join vtiger_currency_info
 					on vtiger_service.currency_id = vtiger_currency_info.id where vtiger_service.serviceid=?";
 		} else {
-			$sql = "select conversion_rate from vtiger_products inner join vtiger_currency_info 
+			$sql = "select conversion_rate from vtiger_products inner join vtiger_currency_info
 					on vtiger_products.currency_id = vtiger_currency_info.id where vtiger_products.productid=?";
 		}
 		$params = array($productid);
 	} else {
 		$sql = "select conversion_rate from vtiger_currency_info where id=?";
-		$params = array(fetchCurrency($current_user->id));		
+		$params = array(fetchCurrency($current_user->id));
 	}
-	
+
 	$res = $adb->pquery($sql, $params);
 	$conv_rate = $adb->query_result($res, 0, 'conversion_rate');
-	
+
 	return 1 / $conv_rate;
 }
 
@@ -1042,7 +1029,7 @@ function getBaseConversionRateForProduct($productid, $mode='edit', $module='Prod
  */
 function getPricesForProducts($currencyid, $product_ids, $module='Products') {
 	global $adb,$log,$current_user;
-	
+
 	$price_list = array();
 	if (count($product_ids) > 0) {
 		if ($module == 'Services') {
@@ -1060,23 +1047,23 @@ function getPricesForProducts($currencyid, $product_ids, $module='Products') {
 					"FROM (vtiger_currency_info, vtiger_products) " .
 					"left join vtiger_productcurrencyrel on vtiger_products.productid = vtiger_productcurrencyrel.productid " .
 					"and vtiger_currency_info.id = vtiger_productcurrencyrel.currencyid " .
-					"where vtiger_products.productid in (". generateQuestionMarks($product_ids) .") and vtiger_currency_info.id = ?";			
+					"where vtiger_products.productid in (". generateQuestionMarks($product_ids) .") and vtiger_currency_info.id = ?";
 		}
 		$params = array($product_ids, $currencyid);
 		$result = $adb->pquery($query, $params);
-		
+
 		for($i=0;$i<$adb->num_rows($result);$i++)
 		{
 			$product_id = $adb->query_result($result, $i, 'productid');
 			if(getFieldVisibilityPermission($module,$current_user->id,'unit_price') == '0') {
 				$actual_price = $adb->query_result($result, $i, 'actual_price');
-				
+
 				if ($actual_price == null || $actual_price == '') {
 					$unit_price = $adb->query_result($result, $i, 'unit_price');
 					$product_conv_rate = $adb->query_result($result, $i, 'conversion_rate');
 					$product_base_conv_rate = getBaseConversionRateForProduct($product_id,'edit',$module);
 					$conversion_rate = $product_conv_rate * $product_base_conv_rate;
-					
+
 					$actual_price = $unit_price * $conversion_rate;
 				}
 				$price_list[$product_id] = $actual_price;
