@@ -633,7 +633,7 @@ if(!$skipHeaders) {
 		{
 			$category = getParentTabFromModule($currentModule);
 		}
-		include('themes/'.$theme.'/header.php');
+		include('modules/Vtiger/header.php');
 	}
 	
 	if(isset($_SESSION['administrator_error']))
@@ -828,7 +828,7 @@ if((!$viewAttachment) && (!$viewAttachment && $action != 'home_rss') && $action
 		// END
 		echo "<script language = 'JavaScript' type='text/javascript' src = 'include/js/popup.js'></script>";
 		echo "<br><br><br><table border=0 cellspacing=0 cellpadding=5 width=100% class=settingsSelectedUI >";
-		echo "<tr><td class=small align=left><span>Powered by vtiger CRM - $vtiger_current_version</span></td>";
+		echo "<tr><td class=small align=left><span style='color: rgb(153, 153, 153);'>Powered by vtiger CRM <span id='_vtiger_product_version_'>$vtiger_current_version</span></span></td>";
 		echo "<td class=small align=right><span>&copy; 2004-".date('Y')." <a href='http://www.vtiger.com' target='_blank'>vtiger.com</a> | <a href='javascript:mypopup()'>".$app_strings['LNK_READ_LICENSE']."</a> | <a href='http://www.vtiger.com/products/crm/privacy_policy.html' target='_blank'>".getTranslatedString('LNK_PRIVACY_POLICY')."</a></span> $statimage</td></tr></table>";
 			
 	//	echo "<table align='center'><tr><td align='center'>";
@@ -889,6 +889,6 @@ if((!$viewAttachment) && (!$viewAttachment && $action != 'home_rss') && $action
 	// End
 	
 	if((!$skipFooters) && ($action != "body") && ($action != $module."Ajax") && ($action != "ActivityAjax"))
-		include('themes/'.$theme.'/footer.php');
+		include('modules/Vtiger/footer.php');
 }
 ?>
\ No newline at end of file
