@@ -9,10 +9,6 @@
  ************************************************************************************/
 
 require_once 'modules/Vtiger/EditView.php';
-
-if ($focus->mode == 'edit')
 $smarty->display('salesEditView.tpl');
-else
-$smarty->display('CreateView.tpl');
 
 ?>
\ No newline at end of file
