@@ -21,7 +21,7 @@ $customviews = Array(Array('viewname'=>'All',
 		     Array('viewname'=>'This Month Leads',
 			   'setdefault'=>'0','setmetrics'=>'0','status'=>'3','userid'=>'1',
 			   'cvmodule'=>'Leads','stdfilterid'=>'0','advfilterid'=>''),
-			
+
 		     Array('viewname'=>'All',
                            'setdefault'=>'1','setmetrics'=>'0','status'=>'0','userid'=>'1',
                            'cvmodule'=>'Accounts','stdfilterid'=>'','advfilterid'=>''),
@@ -29,7 +29,7 @@ $customviews = Array(Array('viewname'=>'All',
 		     Array('viewname'=>'Prospect Accounts',
                            'setdefault'=>'0','setmetrics'=>'1','status'=>'3','userid'=>'1',
                            'cvmodule'=>'Accounts','stdfilterid'=>'','advfilterid'=>'1'),
-		     
+
 		     Array('viewname'=>'New This Week',
                            'setdefault'=>'0','setmetrics'=>'0','status'=>'3','userid'=>'1',
                            'cvmodule'=>'Accounts','stdfilterid'=>'1','advfilterid'=>''),
@@ -57,15 +57,15 @@ $customviews = Array(Array('viewname'=>'All',
 		     Array('viewname'=>'Prospecting',
                            'setdefault'=>'0','setmetrics'=>'0','status'=>'3','userid'=>'1',
                            'cvmodule'=>'Potentials','stdfilterid'=>'','advfilterid'=>'3'),
- 	 	     
+
 		     Array('viewname'=>'All',
                            'setdefault'=>'1','setmetrics'=>'0','status'=>'0','userid'=>'1',
                            'cvmodule'=>'HelpDesk','stdfilterid'=>'','advfilterid'=>''),
-	
+
 	             Array('viewname'=>'Open Tickets',
                            'setdefault'=>'0','setmetrics'=>'1','status'=>'3','userid'=>'1',
                            'cvmodule'=>'HelpDesk','stdfilterid'=>'','advfilterid'=>'4'),
-       	             
+
 		     Array('viewname'=>'High Prioriy Tickets',
                            'setdefault'=>'0','setmetrics'=>'0','status'=>'3','userid'=>'1',
                            'cvmodule'=>'HelpDesk','stdfilterid'=>'','advfilterid'=>'5'),
@@ -85,11 +85,11 @@ $customviews = Array(Array('viewname'=>'All',
 		    Array('viewname'=>'All',
                           'setdefault'=>'1','setmetrics'=>'0','status'=>'0','userid'=>'1',
                           'cvmodule'=>'Calendar','stdfilterid'=>'','advfilterid'=>''),
-		    
+
 		    Array('viewname'=>'All',
                           'setdefault'=>'1','setmetrics'=>'0','status'=>'0','userid'=>'1',
                           'cvmodule'=>'Emails','stdfilterid'=>'','advfilterid'=>''),
-	
+
 		    Array('viewname'=>'All',
                           'setdefault'=>'1','setmetrics'=>'0','status'=>'0','userid'=>'1',
                           'cvmodule'=>'Invoice','stdfilterid'=>'','advfilterid'=>''),
@@ -97,11 +97,11 @@ $customviews = Array(Array('viewname'=>'All',
 		    Array('viewname'=>'All',
                           'setdefault'=>'1','setmetrics'=>'0','status'=>'0','userid'=>'1',
                           'cvmodule'=>'Documents','stdfilterid'=>'','advfilterid'=>''),
-		    
+
 	            Array('viewname'=>'All',
                           'setdefault'=>'1','setmetrics'=>'0','status'=>'0','userid'=>'1',
-                          'cvmodule'=>'PriceBooks','stdfilterid'=>'','advfilterid'=>''),	
-	
+                          'cvmodule'=>'PriceBooks','stdfilterid'=>'','advfilterid'=>''),
+
 	            Array('viewname'=>'All',
                           'setdefault'=>'1','setmetrics'=>'0','status'=>'0','userid'=>'1',
                           'cvmodule'=>'Products','stdfilterid'=>'','advfilterid'=>''),
@@ -132,8 +132,8 @@ $customviews = Array(Array('viewname'=>'All',
 
 		    Array('viewname'=>'Drafted FAQ',
                           'setdefault'=>'0','setmetrics'=>'0','status'=>'3','userid'=>'1',
-                          'cvmodule'=>'Faq','stdfilterid'=>'','advfilterid'=>'8'),	
-		    
+                          'cvmodule'=>'Faq','stdfilterid'=>'','advfilterid'=>'8'),
+
 		    Array('viewname'=>'Published FAQ',
                           'setdefault'=>'0','setmetrics'=>'0','status'=>'3','userid'=>'1',
 			  'cvmodule'=>'Faq','stdfilterid'=>'','advfilterid'=>'9'),
@@ -141,7 +141,7 @@ $customviews = Array(Array('viewname'=>'All',
 	            Array('viewname'=>'Open Purchase Orders',
                           'setdefault'=>'0','setmetrics'=>'0','status'=>'3','userid'=>'1',
                           'cvmodule'=>'PurchaseOrder','stdfilterid'=>'','advfilterid'=>'10'),
-				    
+
 	            Array('viewname'=>'Received Purchase Orders',
                           'setdefault'=>'0','setmetrics'=>'0','status'=>'3','userid'=>'1',
                           'cvmodule'=>'PurchaseOrder','stdfilterid'=>'','advfilterid'=>'11'),
@@ -182,7 +182,7 @@ $cvcolumns = Array(Array('vtiger_leaddetails:lead_no:lead_no:Leads_Lead_No:V',
                          'vtiger_leaddetails:leadsource:leadsource:Leads_Lead_Source:V',
                          'vtiger_leadsubdetails:website:website:Leads_Website:V',
                          'vtiger_leaddetails:email:email:Leads_Email:E'),
-	
+
 		  		 Array('vtiger_account:account_no:account_no:Accounts_Account_No:V',
 				 		'vtiger_account:accountname:accountname:Accounts_Account_Name:V',
                          'vtiger_accountbillads:bill_city:bill_city:Accounts_City:V',
@@ -218,7 +218,7 @@ $cvcolumns = Array(Array('vtiger_leaddetails:lead_no:lead_no:Leads_Lead_No:V',
                          'vtiger_contactaddress:mailingstate:mailingstate:Contacts_Mailing_State:V',
 			 'vtiger_contactaddress:mailingzip:mailingzip:Contacts_Mailing_Zip:V',
 			 'vtiger_contactaddress:mailingcountry:mailingcountry:Contacts_Mailing_Country:V'),
-		   
+
 		   Array('vtiger_contactdetails:firstname:firstname:Contacts_First_Name:V',
                  'vtiger_contactdetails:lastname:lastname:Contacts_Last_Name:V',
                  'vtiger_contactdetails:title:title:Contacts_Title:V',
@@ -226,7 +226,7 @@ $cvcolumns = Array(Array('vtiger_leaddetails:lead_no:lead_no:Leads_Lead_No:V',
                  'vtiger_contactdetails:email:email:Contacts_Email:E',
 				 'vtiger_contactsubdetails:otherphone:otherphone:Contacts_Phone:V',
 				 'vtiger_crmentity:smownerid:assigned_user_id:Contacts_Assigned_To:V'),
-		  
+
 		   Array('vtiger_potential:potential_no:potential_no:Potentials_Potential_No:V',
  	   			 'vtiger_potential:potentialname:potentialname:Potentials_Potential_Name:V',
                  'vtiger_potential:related_to:related_to:Potentials_Related_To:V',
@@ -288,7 +288,7 @@ $cvcolumns = Array(Array('vtiger_leaddetails:lead_no:lead_no:Leads_Lead_No:V',
 						'vtiger_quotes:accountid:account_id:Quotes_Account_Name:I',
                          'vtiger_quotes:validtill:validtill:Quotes_Valid_Till:D',
                          'vtiger_crmentity:smownerid:assigned_user_id:Quotes_Assigned_To:V'),
-			
+
 		   Array('vtiger_activity:status:taskstatus:Calendar_Status:V',
                          'vtiger_activity:activitytype:activitytype:Calendar_Type:V',
                          'vtiger_activity:subject:subject:Calendar_Subject:V',
@@ -300,25 +300,25 @@ $cvcolumns = Array(Array('vtiger_leaddetails:lead_no:lead_no:Leads_Lead_No:V',
 		   Array('vtiger_activity:subject:subject:Emails_Subject:V',
        			 'vtiger_emaildetails:to_email:saved_toid:Emails_To:V',
                  	 'vtiger_activity:date_start:date_start:Emails_Date_Sent:D'),
-		
+
 		   Array('vtiger_invoice:invoice_no:invoice_no:Invoice_Invoice_No:V',
                          'vtiger_invoice:subject:subject:Invoice_Subject:V',
                          'vtiger_invoice:salesorderid:salesorder_id:Invoice_Sales_Order:I',
                          'vtiger_invoice:invoicestatus:invoicestatus:Invoice_Status:V',
                          'vtiger_invoice:total:hdnGrandTotal:Invoice_Total:I',
                          'vtiger_crmentity:smownerid:assigned_user_id:Invoice_Assigned_To:V'),
-		
+
 		  Array('vtiger_notes:note_no:note_no:Notes_Note_No:V',
 		  				'vtiger_notes:title:notes_title:Notes_Title:V',
                         'vtiger_notes:filename:filename:Notes_File:V',
-                        'vtiger_crmentity:modifiedtime:modifiedtime:Notes_Modified_Time:V',
+                        'vtiger_crmentity:modifiedtime:modifiedtime:Notes_Modified_Time:DT',
 		  				'vtiger_crmentity:smownerid:assigned_user_id:Notes_Assigned_To:V'),
-		
+
 		  Array('vtiger_pricebook:pricebook_no:pricebook_no:PriceBooks_PriceBook_No:V',
 					  'vtiger_pricebook:bookname:bookname:PriceBooks_Price_Book_Name:V',
                         'vtiger_pricebook:active:active:PriceBooks_Active:V',
                         'vtiger_pricebook:currency_id:currency_id:PriceBooks_Currency:I'),
-		  
+
 		  Array('vtiger_products:product_no:product_no:Products_Product_No:V',
 		  		'vtiger_products:productname:productname:Products_Product_Name:V',
                         'vtiger_products:productcode:productcode:Products_Part_Number:V',
@@ -326,14 +326,14 @@ $cvcolumns = Array(Array('vtiger_leaddetails:lead_no:lead_no:Leads_Lead_No:V',
 			'vtiger_products:qtyinstock:qtyinstock:Products_Quantity_In_Stock:V',
                         'vtiger_products:qty_per_unit:qty_per_unit:Products_Qty/Unit:V',
                         'vtiger_products:unit_price:unit_price:Products_Unit_Price:V'),
-		  
+
 		  Array('vtiger_purchaseorder:purchaseorder_no:purchaseorder_no:PurchaseOrder_PurchaseOrder_No:V',
                         'vtiger_purchaseorder:subject:subject:PurchaseOrder_Subject:V',
                         'vtiger_purchaseorder:vendorid:vendor_id:PurchaseOrder_Vendor_Name:I',
                         'vtiger_purchaseorder:tracking_no:tracking_no:PurchaseOrder_Tracking_Number:V',
 						'vtiger_purchaseorder:total:hdnGrandTotal:PurchaseOrder_Total:V',
                         'vtiger_crmentity:smownerid:assigned_user_id:PurchaseOrder_Assigned_To:V'),
-		  
+
 	          Array('vtiger_salesorder:salesorder_no:salesorder_no:SalesOrder_SalesOrder_No:V',
                         'vtiger_salesorder:subject:subject:SalesOrder_Subject:V',
 						'vtiger_salesorder:accountid:account_id:SalesOrder_Account_Name:I',
@@ -357,7 +357,7 @@ $cvcolumns = Array(Array('vtiger_leaddetails:lead_no:lead_no:Leads_Lead_No:V',
 		       'vtiger_faq:product_id:product_id:Faq_Product_Name:I',
 		       'vtiger_crmentity:createdtime:createdtime:Faq_Created_Time:DT',
                        'vtiger_crmentity:modifiedtime:modifiedtime:Faq_Modified_Time:DT'),
-		      //this sequence has to be maintained 
+		      //this sequence has to be maintained
 		 Array('vtiger_campaign:campaign_no:campaign_no:Campaigns_Campaign_No:V',
 		 		'vtiger_campaign:campaignname:campaignname:Campaigns_Campaign_Name:V',
 		       'vtiger_campaign:campaigntype:campaigntype:Campaigns_Campaign_Type:N',
@@ -390,14 +390,14 @@ $cvcolumns = Array(Array('vtiger_leaddetails:lead_no:lead_no:Leads_Lead_No:V',
 			 'vtiger_purchaseorder:vendorid:vendor_id:PurchaseOrder_Vendor_Name:I',
 			 'vtiger_crmentity:smownerid:assigned_user_id:PurchaseOrder_Assigned_To:V',
 			 'vtiger_purchaseorder:duedate:duedate:PurchaseOrder_Due_Date:V'),
-		 
+
 		 Array ('vtiger_purchaseorder:subject:subject:PurchaseOrder_Subject:V',
 			 'vtiger_purchaseorder:vendorid:vendor_id:PurchaseOrder_Vendor_Name:I',
 			 'vtiger_crmentity:smownerid:assigned_user_id:PurchaseOrder_Assigned_To:V',
 			 'vtiger_purchaseorder:postatus:postatus:PurchaseOrder_Status:V',
 			 'vtiger_purchaseorder:carrier:carrier:PurchaseOrder_Carrier:V',
 			 'vtiger_poshipads:ship_street:ship_street:PurchaseOrder_Shipping_Address:V'),
-		
+
 		 Array(  'vtiger_invoice:invoice_no:invoice_no:Invoice_Invoice_No:V',
 		 	 'vtiger_invoice:subject:subject:Invoice_Subject:V',
 			 'vtiger_invoice:accountid:account_id:Invoice_Account_Name:I',
@@ -405,7 +405,7 @@ $cvcolumns = Array(Array('vtiger_leaddetails:lead_no:lead_no:Leads_Lead_No:V',
 			 'vtiger_invoice:invoicestatus:invoicestatus:Invoice_Status:V',
 			 'vtiger_crmentity:smownerid:assigned_user_id:Invoice_Assigned_To:V',
 			 'vtiger_crmentity:createdtime:createdtime:Invoice_Created_Time:DT'),
-		 
+
 		 Array(	 'vtiger_invoice:invoice_no:invoice_no:Invoice_Invoice_No:V',
 			 'vtiger_invoice:subject:subject:Invoice_Subject:V',
 			 'vtiger_invoice:accountid:account_id:Invoice_Account_Name:I',
@@ -564,11 +564,11 @@ foreach($customviews as $key=>$customview)
 
 	/** to store the details of the customview in vtiger_customview table
 	  * @param $viewname :: Type String
-	  * @param $setdefault :: Type Integer 
-	  * @param $setmetrics :: Type Integer 
+	  * @param $setdefault :: Type Integer
+	  * @param $setmetrics :: Type Integer
 	  * @param $cvmodule :: Type String
 	  * @returns  $customviewid of the stored custom view :: Type integer
-	 */	
+	 */
 function insertCustomView($viewname,$setdefault,$setmetrics,$cvmodule,$status,$userid)
 {
 	global $adb;
@@ -609,7 +609,7 @@ function insertCvColumns($CVid,$columnslist)
 	  * @param $filtercriteria(filter name) :: Type String
 	  * @param $startdate :: Type String
 	  * @param $enddate :: Type String
-	  * returns nothing 
+	  * returns nothing
 	 */
 function insertCvStdFilter($CVid,$filtercolumn,$filtercriteria,$startdate,$enddate)
 {
@@ -625,7 +625,7 @@ function insertCvStdFilter($CVid,$filtercolumn,$filtercriteria,$startdate,$endda
 	/** to store the custom view advfilter of the customview in vtiger_cvadvfilter table
 	  * @param $cvid :: Type Integer
 	  * @param $filters :: Type Array('columnname'=>$tablename:$columnname:$fieldname:$fieldlabel,'comparator'=>$comparator,'value'=>$value)
-	  * returns nothing 
+	  * returns nothing
 	 */
 
 function insertCvAdvFilter($CVid,$filters)
