@@ -14,7 +14,7 @@
  ********************************************************************************/
 /*********************************************************************************
  * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Notes/language/en_us.lang.php,v 1.10 2005/03/28 06:33:37 rank Exp $
- * Description:  Defines the English language pack for the Account module.
+ * Description:  Defines the English language pack for the Documents module.
  * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
  * All Rights Reserved.
  * Contributor(s): ______________________________________..
@@ -137,6 +137,9 @@ $mod_strings = Array(
 // Added after 5.1.0 GA
 'Folder Name'=>'Folder Name',
 'Document No'=>'Document No',
+
+'Documents' => 'Documents',
+'Documents ID' => 'Documents ID',
 );
 
 ?>
