@@ -41,6 +41,8 @@ if($ajaxaction == "DETAILVIEW")
 	{
 		echo ":#:FAILURE";
 	}
+} elseif($ajaxaction == "LOADRELATEDLIST" || $ajaxaction == "DISABLEMODULE") {
+	require_once 'include/ListView/RelatedListViewContents.php';
 }
 elseif($_REQUEST['ajaxmode'] == 'qcreate')
 {
