@@ -11,7 +11,7 @@
 require_once('include/database/PearDatabase.php');
 require_once('user_privileges/default_module_view.php');
 
-global $adb, $singlepane_view, $currentModule;
+global $singlepane_view, $currentModule;
 $idlist = vtlib_purify($_REQUEST['idlist']);
 $dest_mod = vtlib_purify($_REQUEST['destination_module']);
 $parenttab = vtlib_purify($_REQUEST['parenttab']);
@@ -31,16 +31,8 @@ if(!empty($_REQUEST['idlist'])) {
 	$storearray = array($_REQUEST['entityid']);
 }
 $focus = CRMEntity::getInstance($currentModule);
-foreach($storearray as $id)
-{
-	if($id != '')
-	{
-		if($dest_mod == 'Documents')
-			$adb->pquery("insert into vtiger_senotesrel values (?,?)", array($forCRMRecord,$id));
-		else {
-			$focus->save_related_module($currentModule, $forCRMRecord, $dest_mod, $id);
-		}
-	}
+if(!empty($storearray)) {
+	relateEntities($focus, $currentModule, $forCRMRecord, $dest_mod, $storearray);
 }
 
 header("Location: index.php?action=$action&module=$currentModule&record=$forCRMRecord&parenttab=$parenttab");
