@@ -29,7 +29,7 @@ if(isset($_REQUEST['isDuplicate']) && $_REQUEST['isDuplicate'] == 'true')
 if($_REQUEST['mail_error'] != '')
 {
     require_once("modules/Emails/mail.php");
-	$ticket_owner = getUserName($focus->column_fields['assigned_user_id']);
+	$ticket_owner = getUserFullName($focus->column_fields['assigned_user_id']);
     $error_msg = strip_tags(parseEmailErrorString($_REQUEST['mail_error']));
 	$error_msg = $app_strings['LBL_MAIL_NOT_SENT_TO_USER']. ' ' . $ticket_owner. '. ' .$app_strings['LBL_PLS_CHECK_EMAIL_N_SERVER'];
 	echo $mod_strings['LBL_MAIL_SEND_STATUS'].' <b><font class="warning">'.$error_msg.'</font></b>';
