@@ -23,7 +23,6 @@
 
 include_once('config.php');
 require_once('include/logging.php');
-require_once('data/SugarBean.php');
 require_once('include/utils/utils.php');
 require_once('user_privileges/default_module_view.php');
 
@@ -39,11 +38,11 @@ class Invoice extends CRMEntity {
 	/**
 	 * Mandatory table for supporting custom fields.
 	 */
-	var $customFieldTable = Array('vtiger_invoicecf', 'invoiceid');			
-	
+	var $customFieldTable = Array('vtiger_invoicecf', 'invoiceid');
+
 	var $column_fields = Array();
 
-	var $update_product_array = Array();	
+	var $update_product_array = Array();
 
 	var $sortby_fields = Array('subject','invoice_no','invoicestatus','smownerid','accountname','lastname');
 
@@ -53,14 +52,14 @@ class Invoice extends CRMEntity {
 	// This is the list of vtiger_fields that are in the lists.
 	var $list_fields = Array(
 				//'Invoice No'=>Array('crmentity'=>'crmid'),
-				'Invoice No'=>Array('invoice'=>'invoice_no'),		
+				'Invoice No'=>Array('invoice'=>'invoice_no'),
 				'Subject'=>Array('invoice'=>'subject'),
 				'Sales Order'=>Array('invoice'=>'salesorderid'),
 				'Status'=>Array('invoice'=>'invoicestatus'),
 				'Total'=>Array('invoice'=>'total'),
 				'Assigned To'=>Array('crmentity'=>'smownerid')
 				);
-	
+
 	var $list_fields_name = Array(
 				        'Invoice No'=>'invoice_no',
 				        'Subject'=>'subject',
@@ -74,9 +73,9 @@ class Invoice extends CRMEntity {
 	var $search_fields = Array(
 				//'Invoice No'=>Array('crmentity'=>'crmid'),
 				'Invoice No'=>Array('invoice'=>'invoice_no'),
-				'Subject'=>Array('purchaseorder'=>'subject'), 
+				'Subject'=>Array('purchaseorder'=>'subject'),
 				);
-	
+
 	var $search_fields_name = Array(
 				        'Invoice No'=>'',
 				        'Subject'=>'subject',
@@ -90,11 +89,14 @@ class Invoice extends CRMEntity {
 	var $default_sort_order = 'ASC';
 
 	//var $groupTable = Array('vtiger_invoicegrouprelation','invoiceid');
-	
+
 	var $mandatory_fields = Array('subject','createdtime' ,'modifiedtime');
 	var $_salesorderid;
 	var $_recurring_mode;
-	
+
+	// For Alphabetical search
+	var $def_basicsearch_col = 'subject';
+
 	/**	Constructor which will set the column_fields in this object
 	 */
 	function Invoice() {
@@ -107,9 +109,9 @@ class Invoice extends CRMEntity {
 
 
 	/** Function to handle the module specific save operations
-	
+
 	*/
-	
+
 	function save_module($module)
 	{
 		//Checking if vtiger_salesorderid is present and updating the quote status
@@ -124,62 +126,24 @@ class Invoice extends CRMEntity {
 		if(isset($this->_recurring_mode) && $this->_recurring_mode == 'recurringinvoice_from_so' && isset($this->_salesorderid) && $this->_salesorderid!='') {
 			// We are getting called from the RecurringInvoice cron service!
 			$this->createRecurringInvoiceFromSO();
-			
+
 		} else if(isset($_REQUEST)) {
-			if($_REQUEST['action'] != 'InvoiceAjax' && $_REQUEST['ajxaction'] != 'DETAILVIEW' 
+			if($_REQUEST['action'] != 'InvoiceAjax' && $_REQUEST['ajxaction'] != 'DETAILVIEW'
 					&& $_REQUEST['action'] != 'MassEditSave' && $_REQUEST['action'] != 'ProcessDuplicates')
 			{
 				//Based on the total Number of rows we will save the product relationship with this entity
 				saveInventoryProductDetails($this, 'Invoice');
 			}
 		}
-		
-		
+
+
 		// Update the currency id and the conversion rate for the invoice
 		$update_query = "update vtiger_invoice set currency_id=?, conversion_rate=? where invoiceid=?";
-		
-		$update_params = array($this->column_fields['currency_id'], $this->column_fields['conversion_rate'], $this->id); 
+
+		$update_params = array($this->column_fields['currency_id'], $this->column_fields['conversion_rate'], $this->id);
 		$this->db->pquery($update_query, $update_params);
 	}
 
-
-	/**	Function used to get the sort order for Invoice listview
-	 *	@return string	$sorder	- first check the $_REQUEST['sorder'] if request value is empty then check in the $_SESSION['INVOICE_SORT_ORDER'] if this session value is empty then default sort order will be returned. 
-	 */
-	function getSortOrder()
-	{
-		global $log;
-                $log->debug("Entering getSortOrder() method ...");	
-		if(isset($_REQUEST['sorder'])) 
-			$sorder = $this->db->sql_escape_string($_REQUEST['sorder']);
-		else
-			$sorder = (($_SESSION['INVOICE_SORT_ORDER'] != '')?($_SESSION['INVOICE_SORT_ORDER']):($this->default_sort_order));
-		$log->debug("Exiting getSortOrder() method ...");
-		return $sorder;
-	}
-
-	/**	Function used to get the order by value for Invoice listview
-	 *	@return string	$order_by  - first check the $_REQUEST['order_by'] if request value is empty then check in the $_SESSION['INVOICE_ORDER_BY'] if this session value is empty then default order by will be returned. 
-	 */
-	function getOrderBy()
-	{
-		global $log;
-                $log->debug("Entering getOrderBy() method ...");
-                
-		$use_default_order_by = '';		
-		if(PerformancePrefs::getBoolean('LISTVIEW_DEFAULT_SORTING', true)) {
-			$use_default_order_by = $this->default_order_by;
-		}
-		
-		if (isset($_REQUEST['order_by'])) 
-			$order_by = $this->db->sql_escape_string($_REQUEST['order_by']);
-		else
-			$order_by = (($_SESSION['INVOICE_ORDER_BY'] != '')?($_SESSION['INVOICE_ORDER_BY']):($use_default_order_by));
-		$log->debug("Exiting getOrderBy method ...");
-		return $order_by;
-	}	
-
-
 	/**	function used to get the name of the current object
 	 *	@return string $this->name - name of the current object
 	 */
@@ -204,20 +168,20 @@ class Invoice extends CRMEntity {
         $related_module = vtlib_getModuleNameById($rel_tab_id);
 		require_once("modules/$related_module/Activity.php");
 		$other = new Activity();
-        vtlib_setup_modulevars($related_module, $other);		
+        vtlib_setup_modulevars($related_module, $other);
 		$singular_modname = vtlib_toSingular($related_module);
-		
+
 		$parenttab = getParentTab();
-		
+
 		if($singlepane_view == 'true')
 			$returnset = '&return_module='.$this_module.'&return_action=DetailView&return_id='.$id;
 		else
 			$returnset = '&return_module='.$this_module.'&return_action=CallRelatedList&return_id='.$id;
-		
+
 		$button = '';
-				
+
 		$button .= '<input type="hidden" name="activity_mode">';
-		
+
 		if($actions) {
 			if(is_string($actions)) $actions = explode(',', strtoupper($actions));
 			if(in_array('ADD', $actions) && isPermitted($related_module,1, '') == 'yes') {
@@ -229,8 +193,8 @@ class Invoice extends CRMEntity {
 			}
 		}
 
-		$userNameSql = getSqlForNameInDisplayFormat(array('f'=>'vtiger_users.first_name', 'l' => 
-			'vtiger_users.last_name'));
+		$userNameSql = getSqlForNameInDisplayFormat(array('first_name'=>
+							'vtiger_users.first_name', 'last_name' => 'vtiger_users.last_name'), 'Users');
 		$query = "SELECT case when (vtiger_users.user_name not like '') then $userNameSql else vtiger_groups.groupname end as user_name,
 				vtiger_contactdetails.lastname, vtiger_contactdetails.firstname, vtiger_contactdetails.contactid,
 				vtiger_activity.*,vtiger_seactivityrel.*,vtiger_crmentity.crmid, vtiger_crmentity.smownerid,
@@ -245,13 +209,13 @@ class Invoice extends CRMEntity {
 				where vtiger_seactivityrel.crmid=".$id." and activitytype='Task' and vtiger_crmentity.deleted=0
 						and (vtiger_activity.status is not NULL and vtiger_activity.status != 'Completed')
 						and (vtiger_activity.status is not NULL and vtiger_activity.status != 'Deferred')";
-		
-		$return_value = GetRelatedList($this_module, $related_module, $other, $query, $button, $returnset); 
-		
+
+		$return_value = GetRelatedList($this_module, $related_module, $other, $query, $button, $returnset);
+
 		if($return_value == null) $return_value = Array();
 		$return_value['CUSTOM_BUTTON'] = $button;
-		
-		$log->debug("Exiting get_activities method ...");		
+
+		$log->debug("Exiting get_activities method ...");
 		return $return_value;
 	}
 
@@ -263,9 +227,9 @@ class Invoice extends CRMEntity {
 	{
 		global $log;
 		$log->debug("Entering get_history(".$id.") method ...");
-		$userNameSql = getSqlForNameInDisplayFormat(array('f'=>'vtiger_users.first_name', 'l' => 
-			'vtiger_users.last_name'));
-		$query = "SELECT vtiger_contactdetails.lastname, vtiger_contactdetails.firstname, 
+		$userNameSql = getSqlForNameInDisplayFormat(array('first_name'=>
+							'vtiger_users.first_name', 'last_name' => 'vtiger_users.last_name'), 'Users');
+		$query = "SELECT vtiger_contactdetails.lastname, vtiger_contactdetails.firstname,
 				vtiger_contactdetails.contactid,vtiger_activity.*,vtiger_seactivityrel.*,
 				vtiger_crmentity.crmid, vtiger_crmentity.smownerid, vtiger_crmentity.modifiedtime,
 				vtiger_crmentity.createdtime, vtiger_crmentity.description,
@@ -276,7 +240,7 @@ class Invoice extends CRMEntity {
 				left join vtiger_cntactivityrel on vtiger_cntactivityrel.activityid= vtiger_activity.activityid
 				left join vtiger_contactdetails on vtiger_contactdetails.contactid = vtiger_cntactivityrel.contactid
                 left join vtiger_groups on vtiger_groups.groupid=vtiger_crmentity.smownerid
-				left join vtiger_users on vtiger_users.id=vtiger_crmentity.smownerid	
+				left join vtiger_users on vtiger_users.id=vtiger_crmentity.smownerid
 				where vtiger_activity.activitytype='Task'
 					and (vtiger_activity.status = 'Completed' or vtiger_activity.status = 'Deferred')
 					and vtiger_seactivityrel.crmid=".$id."
@@ -294,7 +258,7 @@ class Invoice extends CRMEntity {
 	 *	@return $return_data - array with header and the entries in format Array('header'=>$header,'entries'=>$entries_list) where as $header and $entries_list are arrays which contains header values and all column values of all entries
 	 */
 	function get_invoicestatushistory($id)
-	{	
+	{
 		global $log;
 		$log->debug("Entering get_invoicestatushistory(".$id.") method ...");
 
@@ -311,7 +275,7 @@ class Invoice extends CRMEntity {
 		$header[] = $app_strings['LBL_AMOUNT'];
 		$header[] = $app_strings['LBL_INVOICE_STATUS'];
 		$header[] = $app_strings['LBL_LAST_MODIFIED'];
-		
+
 		//Getting the field permission for the current user. 1 - Not Accessible, 0 - Accessible
 		//Account Name , Amount are mandatory fields. So no need to do security check to these fields.
 		global $current_user;
@@ -355,9 +319,9 @@ class Invoice extends CRMEntity {
 		}
 		return parent::get_column_value($columname, $fldvalue, $fieldname, $uitype, $datatype);
 	}
-	
+
 	/*
-	 * Function to get the secondary query part of a report 
+	 * Function to get the secondary query part of a report
 	 * @param - $module primary module name
 	 * @param - $secmodule secondary module name
 	 * returns the query string formed on fetching the related data for report for secondary module
@@ -365,23 +329,25 @@ class Invoice extends CRMEntity {
 	function generateReportsSecQuery($module,$secmodule){
 		$query = $this->getRelationQuery($module,$secmodule,"vtiger_invoice","invoiceid");
 		$query .= " left join vtiger_crmentity as vtiger_crmentityInvoice on vtiger_crmentityInvoice.crmid=vtiger_invoice.invoiceid and vtiger_crmentityInvoice.deleted=0
-			left join vtiger_invoicecf on vtiger_invoice.invoiceid = vtiger_invoicecf.invoiceid 
+			left join vtiger_invoicecf on vtiger_invoice.invoiceid = vtiger_invoicecf.invoiceid
+			left join vtiger_currency_info as vtiger_currency_info$secmodule on vtiger_currency_info$secmodule.id = vtiger_invoice.currency_id
 			left join vtiger_salesorder as vtiger_salesorderInvoice on vtiger_salesorderInvoice.salesorderid=vtiger_invoice.salesorderid
 			left join vtiger_invoicebillads on vtiger_invoice.invoiceid=vtiger_invoicebillads.invoicebilladdressid
 			left join vtiger_invoiceshipads on vtiger_invoice.invoiceid=vtiger_invoiceshipads.invoiceshipaddressid
-			left join vtiger_inventoryproductrel as vtiger_inventoryproductrelInvoice on vtiger_invoice.invoiceid = vtiger_inventoryproductrelInvoice.id  
-			left join vtiger_products as vtiger_productsInvoice on vtiger_productsInvoice.productid = vtiger_inventoryproductrelInvoice.productid  
-			left join vtiger_service as vtiger_serviceInvoice on vtiger_serviceInvoice.serviceid = vtiger_inventoryproductrelInvoice.productid  
+			left join vtiger_inventoryproductrel as vtiger_inventoryproductrelInvoice on vtiger_invoice.invoiceid = vtiger_inventoryproductrelInvoice.id
+			left join vtiger_products as vtiger_productsInvoice on vtiger_productsInvoice.productid = vtiger_inventoryproductrelInvoice.productid
+			left join vtiger_service as vtiger_serviceInvoice on vtiger_serviceInvoice.serviceid = vtiger_inventoryproductrelInvoice.productid
 			left join vtiger_groups as vtiger_groupsInvoice on vtiger_groupsInvoice.groupid = vtiger_crmentityInvoice.smownerid
 			left join vtiger_users as vtiger_usersInvoice on vtiger_usersInvoice.id = vtiger_crmentityInvoice.smownerid
 			left join vtiger_contactdetails as vtiger_contactdetailsInvoice on vtiger_invoice.contactid = vtiger_contactdetailsInvoice.contactid
-			left join vtiger_account as vtiger_accountInvoice on vtiger_accountInvoice.accountid = vtiger_invoice.accountid ";
+			left join vtiger_account as vtiger_accountInvoice on vtiger_accountInvoice.accountid = vtiger_invoice.accountid
+			left join vtiger_users as vtiger_lastModifiedByInvoice on vtiger_lastModifiedByInvoice.id = vtiger_crmentityInvoice.modifiedby ";
 
 		return $query;
 	}
 
 	/*
-	 * Function to get the relation tables for related modules 
+	 * Function to get the relation tables for related modules
 	 * @param - $secmodule secondary module name
 	 * returns the array with table names and fieldnames storing relations between module and this module
 	 */
@@ -393,17 +359,17 @@ class Invoice extends CRMEntity {
 		);
 		return $rel_tables[$secmodule];
 	}
-	
+
 	// Function to unlink an entity with given Id from another entity
 	function unlinkRelationship($id, $return_module, $return_id) {
 		global $log;
 		if(empty($return_module) || empty($return_id)) return;
-		
+
 		if($return_module == 'Accounts' || $return_module == 'Contacts') {
 			$this->trash('Invoice',$id);
 		} elseif($return_module=='SalesOrder') {
-			$relation_query = 'UPDATE vtiger_invoice set salesorderid=0 where invoiceid=?';
-			$this->db->pquery($relation_query, array($id));
+			$relation_query = 'UPDATE vtiger_invoice set salesorderid=? where invoiceid=?';
+			$this->db->pquery($relation_query, array(null,$id));
 		} else {
 			$sql = 'DELETE FROM vtiger_crmentityrel WHERE (crmid=? AND relmodule=? AND relcrmid=?) OR (relcrmid=? AND module=? AND crmid=?)';
 			$params = array($id, $return_module, $return_id, $id, $return_module, $return_id);
@@ -412,7 +378,7 @@ class Invoice extends CRMEntity {
 	}
 
 	/*
-	 * Function to get the relations of salesorder to invoice for recurring invoice procedure 
+	 * Function to get the relations of salesorder to invoice for recurring invoice procedure
 	 * @param - $salesorder_id Salesorder ID
 	 */
 	function createRecurringInvoiceFromSO(){
@@ -437,13 +403,13 @@ class Invoice extends CRMEntity {
 				$values = array_values($col_value);
 				$query2 = "INSERT INTO vtiger_inventoryproductrel(". implode(",",$columns) .") VALUES (". generateQuestionMarks($values) .")";
 				$adb->pquery($query2, array($values));
-				$prod_id = $col_value['productid'];	
-				$qty = $col_value['quantity'];	
+				$prod_id = $col_value['productid'];
+				$qty = $col_value['quantity'];
 				$update_stock[$col_value['sequence_no']] = $qty;
 				updateStk($prod_id,$qty,'',array(),'Invoice');
 			}
 		}
-		
+
 		$query1 = "SELECT * FROM vtiger_inventorysubproductrel WHERE id=?";
 		$res = $adb->pquery($query1, array($salesorder_id));
 		$no_of_products = $adb->num_rows($res);
@@ -460,12 +426,12 @@ class Invoice extends CRMEntity {
 				$values = array_values($col_value);
 				$query2 = "INSERT INTO vtiger_inventorysubproductrel(". implode(",",$columns) .") VALUES (". generateQuestionMarks($values) .")";
 				$adb->pquery($query2, array($values));
-				$prod_id = $col_value['productid'];	
-				$qty = $update_stock[$col_value['sequence_no']];	
+				$prod_id = $col_value['productid'];
+				$qty = $update_stock[$col_value['sequence_no']];
 				updateStk($prod_id,$qty,'',array(),'Invoice');
 			}
 		}
-		
+
 		// Add the Shipping taxes for the Invoice
 		$query3 = "SELECT * FROM vtiger_inventoryshippingrel WHERE id=?";
 		$res = $adb->pquery($query3, array($salesorder_id));
@@ -485,16 +451,16 @@ class Invoice extends CRMEntity {
 				$adb->pquery($query4, array($values));
 			}
 		}
-		
+
 		//Update the netprice (subtotal), taxtype, discount, S&H charge, adjustment and total for the Invoice
-		
+
 		$updatequery  = " UPDATE vtiger_invoice SET ";
 		$updateparams = array();
 		// Remaining column values to be updated -> column name to field name mapping
 		$invoice_column_field = Array (
 			'adjustment' => 'txtAdjustment',
-			'subtotal' => 'hdnSubTotal', 
-			'total' => 'hdnGrandTotal', 
+			'subtotal' => 'hdnSubTotal',
+			'total' => 'hdnGrandTotal',
 			'taxtype' => 'hdnTaxType',
 			'discount_percent' => 'hdnDiscountPercent',
 			'discount_amount' => 'hdnDiscountAmount',
@@ -507,10 +473,10 @@ class Invoice extends CRMEntity {
 		}
 		if (count($updatecols) > 0) {
 			$updatequery .= implode(",", $updatecols);
-			
+
 			$updatequery .= " WHERE invoiceid=?";
 			array_push($updateparams, $this->id);
-			
+
 			$adb->pquery($updatequery, $updateparams);
 		}
 	}
