@@ -85,7 +85,7 @@ if($singlepane_view == 'true' && $_REQUEST['action'] == 'CallRelatedList' ) {
 	$smarty->assign("ID",$focus->id);
 	$smarty->assign("NAME",$focus->lastname.' '.$focus->firstname);
 	$smarty->assign("EMAIL",$focus->column_fields['email']);
-	$smarty->assign("YAHOO",$focus->column_fields['yahooid']);
+	$smarty->assign("SECONDARY_EMAIL",$focus->column_fields['secondaryemail']);
 	$related_array = getRelatedLists($currentModule,$focus);
 	$smarty->assign("RELATEDLISTS", $related_array);
 		
