@@ -15,7 +15,6 @@
 
 include_once('config.php');
 require_once('include/logging.php');
-require_once('data/SugarBean.php');
 require_once('modules/Calendar/Activity.php');
 require_once('modules/Campaigns/Campaigns.php');
 require_once('modules/Documents/Documents.php');
@@ -34,13 +33,13 @@ class Leads extends CRMEntity {
 	var $tab_name_index = Array('vtiger_crmentity'=>'crmid','vtiger_leaddetails'=>'leadid','vtiger_leadsubdetails'=>'leadsubscriptionid','vtiger_leadaddress'=>'leadaddressid','vtiger_leadscf'=>'leadid');
 
 	var $entity_table = "vtiger_crmentity";
-	
+
 	/**
 	 * Mandatory table for supporting custom fields.
 	 */
 	var $customFieldTable = Array('vtiger_leadscf', 'leadid');
-	
-	//construct this from database;	
+
+	//construct this from database;
 	var $column_fields = Array();
 	var $sortby_fields = Array('lastname','firstname','email','phone','company','smownerid','website');
 
@@ -85,13 +84,16 @@ class Leads extends CRMEntity {
 
 	//Default Fields for Email Templates -- Pavani
 	var $emailTemplate_defaultFields = array('firstname','lastname','leadsource','leadstatus','rating','industry','secondaryemail','email','annualrevenue','designation','salutation');
-	
+
 	//Added these variables which are used as default order by and sortorder in ListView
 	var $default_order_by = 'lastname';
 	var $default_sort_order = 'ASC';
 
+	// For Alphabetical search
+	var $def_basicsearch_col = 'lastname';
+
 	//var $groupTable = Array('vtiger_leadgrouprelation','leadid');
-	
+
 	function Leads()	{
 		$this->log = LoggerManager::getLogger('lead');
 		$this->log->debug("Entering Leads() method ...");
@@ -107,48 +109,6 @@ class Leads extends CRMEntity {
 	}
 
 	// Mike Crowe Mod --------------------------------------------------------Default ordering for us
-	/**
-	 * Function to get sort order
- 	 * return string  $sorder    - sortorder string either 'ASC' or 'DESC'
-	 */
-	function getSortOrder()
-	{	
-		global $log;
-		$log->debug("Entering getSortOrder() method ...");
-		if(isset($_REQUEST['sorder'])) 
-			$sorder = $this->db->sql_escape_string($_REQUEST['sorder']);
-		else
-			$sorder = (($_SESSION['LEADS_SORT_ORDER'] != '')?($_SESSION['LEADS_SORT_ORDER']):($this->default_sort_order));
-
-		$log->debug("Exiting getSortOrder method ...");
-		return $sorder;
-	}
-
-	/**
-	 * Function to get order by
-	 * return string  $order_by    - fieldname(eg: 'leadname')
- 	 */
-	function getOrderBy()
-	{
-		global $log;
-		$log->debug("Entering getOrderBy() method ...");
-		
-		$use_default_order_by = '';		
-		if(PerformancePrefs::getBoolean('LISTVIEW_DEFAULT_SORTING', true)) {
-			$use_default_order_by = $this->default_order_by;
-		}
-		
-		if (isset($_REQUEST['order_by'])) 
-			$order_by = $this->db->sql_escape_string($_REQUEST['order_by']);
-		else
-			$order_by = (($_SESSION['LEADS_ORDER_BY'] != '')?($_SESSION['LEADS_ORDER_BY']):($use_default_order_by));
-
-		$log->debug("Exiting getOrderBy method ...");
-		return $order_by;
-	}	
-	// Mike Crowe Mod --------------------------------------------------------
-
-
 
 	/** Function to export the lead records in CSV Format
 	* @param reference variable - where condition is passed when the query is executed
@@ -166,9 +126,9 @@ class Leads extends CRMEntity {
 		$sql = getPermittedFieldsQuery("Leads", "detail_view");
 		$fields_list = getFieldsListFromQuery($sql);
 
-		$userNameSql = getSqlForNameInDisplayFormat(array('f'=>'vtiger_users.first_name', 'l' => 
-			'vtiger_users.last_name'));
-		$query = "SELECT $fields_list,case when (vtiger_users.user_name not like '') then $userNameSql else vtiger_groups.groupname end as user_name 
+		$userNameSql = getSqlForNameInDisplayFormat(array('first_name'=>
+							'vtiger_users.first_name', 'last_name' => 'vtiger_users.last_name'), 'Users');
+		$query = "SELECT $fields_list,case when (vtiger_users.user_name not like '') then $userNameSql else vtiger_groups.groupname end as user_name
 	      			FROM ".$this->entity_table."
 				INNER JOIN vtiger_leaddetails
 					ON vtiger_crmentity.crmid=vtiger_leaddetails.leadid
@@ -176,7 +136,7 @@ class Leads extends CRMEntity {
 					ON vtiger_leaddetails.leadid = vtiger_leadsubdetails.leadsubscriptionid
 				LEFT JOIN vtiger_leadaddress
 					ON vtiger_leaddetails.leadid=vtiger_leadaddress.leadaddressid
-				LEFT JOIN vtiger_leadscf 
+				LEFT JOIN vtiger_leadscf
 					ON vtiger_leadscf.leadid=vtiger_leaddetails.leadid
 	                        LEFT JOIN vtiger_groups
                         	        ON vtiger_groups.groupid = vtiger_crmentity.smownerid
@@ -197,7 +157,7 @@ class Leads extends CRMEntity {
 	}
 
 
-	
+
 	/** Returns a list of the associated tasks
  	 * @param  integer   $id      - leadid
  	 * returns related Task or Event record in array format
@@ -210,20 +170,20 @@ class Leads extends CRMEntity {
         $related_module = vtlib_getModuleNameById($rel_tab_id);
 		require_once("modules/$related_module/Activity.php");
 		$other = new Activity();
-        vtlib_setup_modulevars($related_module, $other);		
+        vtlib_setup_modulevars($related_module, $other);
 		$singular_modname = vtlib_toSingular($related_module);
-		
+
 		$parenttab = getParentTab();
-		
+
 		if($singlepane_view == 'true')
 			$returnset = '&return_module='.$this_module.'&return_action=DetailView&return_id='.$id;
 		else
 			$returnset = '&return_module='.$this_module.'&return_action=CallRelatedList&return_id='.$id;
-		
+
 		$button = '';
-				
+
 		$button .= '<input type="hidden" name="activity_mode">';
-		
+
 		if($actions) {
 			if(is_string($actions)) $actions = explode(',', strtoupper($actions));
 			if(in_array('ADD', $actions) && isPermitted($related_module,1, '') == 'yes') {
@@ -231,7 +191,7 @@ class Leads extends CRMEntity {
 					$button .= "<input title='".getTranslatedString('LBL_NEW'). " ". getTranslatedString('LBL_TODO', $related_module) ."' class='crmbutton small create'" .
 						" onclick='this.form.action.value=\"EditView\";this.form.module.value=\"$related_module\";this.form.return_module.value=\"$this_module\";this.form.activity_mode.value=\"Task\";' type='submit' name='button'" .
 						" value='". getTranslatedString('LBL_ADD_NEW'). " " . getTranslatedString('LBL_TODO', $related_module) ."'>&nbsp;";
-				}				
+				}
 				if(getFieldVisibilityPermission('Events',$current_user->id,'parent_id', 'readwrite') == '0') {
 					$button .= "<input title='".getTranslatedString('LBL_NEW'). " ". getTranslatedString('LBL_TODO', $related_module) ."' class='crmbutton small create'" .
 						" onclick='this.form.action.value=\"EditView\";this.form.module.value=\"$related_module\";this.form.return_module.value=\"$this_module\";this.form.activity_mode.value=\"Events\";' type='submit' name='button'" .
@@ -240,36 +200,36 @@ class Leads extends CRMEntity {
 			}
 		}
 
-		$userNameSql = getSqlForNameInDisplayFormat(array('f'=>'vtiger_users.first_name', 'l' => 
-			'vtiger_users.last_name'));
-		$query = "SELECT vtiger_activity.*,vtiger_seactivityrel.*, vtiger_contactdetails.lastname, 
-			vtiger_contactdetails.contactid, vtiger_crmentity.crmid, vtiger_crmentity.smownerid, 
-			vtiger_crmentity.modifiedtime,case when (vtiger_users.user_name not like '') then 
+		$userNameSql = getSqlForNameInDisplayFormat(array('first_name'=>
+							'vtiger_users.first_name', 'last_name' => 'vtiger_users.last_name'), 'Users');
+		$query = "SELECT vtiger_activity.*,vtiger_seactivityrel.*, vtiger_contactdetails.lastname,
+			vtiger_contactdetails.contactid, vtiger_crmentity.crmid, vtiger_crmentity.smownerid,
+			vtiger_crmentity.modifiedtime,case when (vtiger_users.user_name not like '') then
 		$userNameSql else vtiger_groups.groupname end as user_name,
-		vtiger_recurringevents.recurringtype 
+		vtiger_recurringevents.recurringtype
 		from vtiger_activity inner join vtiger_seactivityrel on vtiger_seactivityrel.activityid=
 		vtiger_activity.activityid inner join vtiger_crmentity on vtiger_crmentity.crmid=
-		vtiger_activity.activityid left join vtiger_cntactivityrel on 
-		vtiger_cntactivityrel.activityid = vtiger_activity.activityid left join 
-		vtiger_contactdetails on vtiger_contactdetails.contactid = vtiger_cntactivityrel.contactid 
-		left join vtiger_users on vtiger_users.id=vtiger_crmentity.smownerid 
+		vtiger_activity.activityid left join vtiger_cntactivityrel on
+		vtiger_cntactivityrel.activityid = vtiger_activity.activityid left join
+		vtiger_contactdetails on vtiger_contactdetails.contactid = vtiger_cntactivityrel.contactid
+		left join vtiger_users on vtiger_users.id=vtiger_crmentity.smownerid
 		left outer join vtiger_recurringevents on vtiger_recurringevents.activityid=
 		vtiger_activity.activityid left join vtiger_groups on vtiger_groups.groupid=
-		vtiger_crmentity.smownerid where vtiger_seactivityrel.crmid=".$id." and 
-			vtiger_crmentity.deleted = 0 and ((vtiger_activity.activitytype='Task' and 
-			vtiger_activity.status not in ('Completed','Deferred')) or 
-			(vtiger_activity.activitytype NOT in ('Emails','Task') and  
+		vtiger_crmentity.smownerid where vtiger_seactivityrel.crmid=".$id." and
+			vtiger_crmentity.deleted = 0 and ((vtiger_activity.activitytype='Task' and
+			vtiger_activity.status not in ('Completed','Deferred')) or
+			(vtiger_activity.activitytype NOT in ('Emails','Task') and
 			vtiger_activity.eventstatus not in ('','Held'))) ";
-					
-		$return_value = GetRelatedList($this_module, $related_module, $other, $query, $button, $returnset); 
-		
+
+		$return_value = GetRelatedList($this_module, $related_module, $other, $query, $button, $returnset);
+
 		if($return_value == null) $return_value = Array();
 		$return_value['CUSTOM_BUTTON'] = $button;
-		
-		$log->debug("Exiting get_activities method ...");		
+
+		$log->debug("Exiting get_activities method ...");
 		return $return_value;
 	}
-	
+
 	/** Returns a list of the associated Campaigns
 	  * @param $id -- campaign id :: Type Integer
 	  * @returns list of campaigns in array format
@@ -282,52 +242,49 @@ class Leads extends CRMEntity {
         $related_module = vtlib_getModuleNameById($rel_tab_id);
 		require_once("modules/$related_module/$related_module.php");
 		$other = new $related_module();
-        vtlib_setup_modulevars($related_module, $other);		
+        vtlib_setup_modulevars($related_module, $other);
 		$singular_modname = vtlib_toSingular($related_module);
-		
+
 		$parenttab = getParentTab();
-		
+
 		if($singlepane_view == 'true')
 			$returnset = '&return_module='.$this_module.'&return_action=DetailView&return_id='.$id;
 		else
 			$returnset = '&return_module='.$this_module.'&return_action=CallRelatedList&return_id='.$id;
-		
+
 		$button = '';
-		
-		$button .= '<input type="hidden" name="email_directing_module"><input type="hidden" name="record">';	
-                    
+
+		$button .= '<input type="hidden" name="email_directing_module"><input type="hidden" name="record">';
+
 		if($actions) {
 			if(is_string($actions)) $actions = explode(',', strtoupper($actions));
 			if(in_array('SELECT', $actions) && isPermitted($related_module,4, '') == 'yes') {
 				$button .= "<input title='".getTranslatedString('LBL_SELECT')." ". getTranslatedString($related_module). "' class='crmbutton small edit' type='button' onclick=\"return window.open('index.php?module=$related_module&return_module=$currentModule&action=Popup&popuptype=detailview&select=enable&form=EditView&form_submit=false&recordid=$id&parenttab=$parenttab','test','width=640,height=602,resizable=0,scrollbars=0');\" value='". getTranslatedString('LBL_SELECT'). " " . getTranslatedString($related_module) ."'>&nbsp;";
 			}
-			if(in_array('ADD', $actions) && isPermitted($related_module,1, '') == 'yes') {
-				$button .= "<input title='". getTranslatedString('LBL_ADD_NEW')." ". getTranslatedString($singular_modname)."' accessyKey='F' class='crmbutton small create' onclick='fnvshobj(this,\"sendmail_cont\");sendmail(\"$this_module\",$id);' type='button' name='button' value='". getTranslatedString('LBL_ADD_NEW')." ". getTranslatedString($singular_modname)."'></td>";
-			}
-		} 
+		}
 
-		$userNameSql = getSqlForNameInDisplayFormat(array('f'=>'vtiger_users.first_name', 'l' => 
-			'vtiger_users.last_name'));
+		$userNameSql = getSqlForNameInDisplayFormat(array('first_name'=>
+							'vtiger_users.first_name', 'last_name' => 'vtiger_users.last_name'), 'Users');
 		$query = "SELECT case when (vtiger_users.user_name not like '') then $userNameSql else vtiger_groups.groupname end as user_name ,
-				vtiger_campaign.campaignid, vtiger_campaign.campaignname, vtiger_campaign.campaigntype, vtiger_campaign.campaignstatus,  
-				vtiger_campaign.expectedrevenue, vtiger_campaign.closingdate, vtiger_crmentity.crmid, vtiger_crmentity.smownerid,  
-				vtiger_crmentity.modifiedtime from vtiger_campaign  
-				inner join vtiger_campaignleadrel on vtiger_campaignleadrel.campaignid=vtiger_campaign.campaignid 
-				inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_campaign.campaignid		
+				vtiger_campaign.campaignid, vtiger_campaign.campaignname, vtiger_campaign.campaigntype, vtiger_campaign.campaignstatus,
+				vtiger_campaign.expectedrevenue, vtiger_campaign.closingdate, vtiger_crmentity.crmid, vtiger_crmentity.smownerid,
+				vtiger_crmentity.modifiedtime from vtiger_campaign
+				inner join vtiger_campaignleadrel on vtiger_campaignleadrel.campaignid=vtiger_campaign.campaignid
+				inner join vtiger_crmentity on vtiger_crmentity.crmid = vtiger_campaign.campaignid
 				left join vtiger_groups on vtiger_groups.groupid=vtiger_crmentity.smownerid
-				left join vtiger_users on vtiger_users.id = vtiger_crmentity.smownerid	
+				left join vtiger_users on vtiger_users.id = vtiger_crmentity.smownerid
 				where vtiger_campaignleadrel.leadid=".$id." and vtiger_crmentity.deleted=0";
-					
-		$return_value = GetRelatedList($this_module, $related_module, $other, $query, $button, $returnset); 
-		
+
+		$return_value = GetRelatedList($this_module, $related_module, $other, $query, $button, $returnset);
+
 		if($return_value == null) $return_value = Array();
 		$return_value['CUSTOM_BUTTON'] = $button;
-		
-		$log->debug("Exiting get_campaigns method ...");		
-		return $return_value;	
+
+		$log->debug("Exiting get_campaigns method ...");
+		return $return_value;
 	}
-	
-	
+
+
 		/** Returns a list of the associated emails
 	 	 * @param  integer   $id      - leadid
 	 	 * returns related emails record in array format
@@ -340,20 +297,20 @@ class Leads extends CRMEntity {
         $related_module = vtlib_getModuleNameById($rel_tab_id);
 		require_once("modules/$related_module/$related_module.php");
 		$other = new $related_module();
-        vtlib_setup_modulevars($related_module, $other);		
+        vtlib_setup_modulevars($related_module, $other);
 		$singular_modname = vtlib_toSingular($related_module);
-		
+
 		$parenttab = getParentTab();
-		
+
 		if($singlepane_view == 'true')
 			$returnset = '&return_module='.$this_module.'&return_action=DetailView&return_id='.$id;
 		else
 			$returnset = '&return_module='.$this_module.'&return_action=CallRelatedList&return_id='.$id;
-		
+
 		$button = '';
-		
-		$button .= '<input type="hidden" name="email_directing_module"><input type="hidden" name="record">';	
-                    
+
+		$button .= '<input type="hidden" name="email_directing_module"><input type="hidden" name="record">';
+
 		if($actions) {
 			if(is_string($actions)) $actions = explode(',', strtoupper($actions));
 			if(in_array('SELECT', $actions) && isPermitted($related_module,4, '') == 'yes') {
@@ -362,10 +319,10 @@ class Leads extends CRMEntity {
 			if(in_array('ADD', $actions) && isPermitted($related_module,1, '') == 'yes') {
 				$button .= "<input title='". getTranslatedString('LBL_ADD_NEW')." ". getTranslatedString($singular_modname)."' accessyKey='F' class='crmbutton small create' onclick='fnvshobj(this,\"sendmail_cont\");sendmail(\"$this_module\",$id);' type='button' name='button' value='". getTranslatedString('LBL_ADD_NEW')." ". getTranslatedString($singular_modname)."'></td>";
 			}
-		} 
+		}
 
-		$userNameSql = getSqlForNameInDisplayFormat(array('f'=>'vtiger_users.first_name', 'l' => 
-			'vtiger_users.last_name'));
+		$userNameSql = getSqlForNameInDisplayFormat(array('first_name'=>
+							'vtiger_users.first_name', 'last_name' => 'vtiger_users.last_name'), 'Users');
 		$query ="select case when (vtiger_users.user_name not like '') then $userNameSql else vtiger_groups.groupname end as user_name," .
 				" vtiger_activity.activityid, vtiger_activity.subject, vtiger_activity.semodule, vtiger_activity.activitytype," .
 				" vtiger_activity.date_start, vtiger_activity.status, vtiger_activity.priority, vtiger_crmentity.crmid," .
@@ -375,17 +332,17 @@ class Leads extends CRMEntity {
 				" inner join vtiger_crmentity on vtiger_crmentity.crmid=vtiger_activity.activityid" .
 				" left join vtiger_groups on vtiger_groups.groupid=vtiger_crmentity.smownerid" .
 				" left join vtiger_users on  vtiger_users.id=vtiger_crmentity.smownerid" .
-				" where vtiger_activity.activitytype='Emails' and vtiger_crmentity.deleted=0 and vtiger_seactivityrel.crmid=".$id;	
-					
-		$return_value = GetRelatedList($this_module, $related_module, $other, $query, $button, $returnset); 
-		
+				" where vtiger_activity.activitytype='Emails' and vtiger_crmentity.deleted=0 and vtiger_seactivityrel.crmid=".$id;
+
+		$return_value = GetRelatedList($this_module, $related_module, $other, $query, $button, $returnset);
+
 		if($return_value == null) $return_value = Array();
 		$return_value['CUSTOM_BUTTON'] = $button;
-		
-		$log->debug("Exiting get_emails method ...");		
+
+		$log->debug("Exiting get_emails method ...");
 		return $return_value;
 	}
-	
+
 	/**
 	 * Function to get Lead related Task & Event which have activity type Held, Completed or Deferred.
 	 * @param  integer   $id      - leadid
@@ -395,30 +352,30 @@ class Leads extends CRMEntity {
 	{
 		global $log;
 		$log->debug("Entering get_history(".$id.") method ...");
-		$userNameSql = getSqlForNameInDisplayFormat(array('f'=>'vtiger_users.first_name', 'l' => 
-			'vtiger_users.last_name'));
+		$userNameSql = getSqlForNameInDisplayFormat(array('first_name'=>
+							'vtiger_users.first_name', 'last_name' => 'vtiger_users.last_name'), 'Users');
 		$query = "SELECT vtiger_activity.activityid, vtiger_activity.subject, vtiger_activity.status,
-			vtiger_activity.eventstatus, vtiger_activity.activitytype,vtiger_activity.date_start, 
+			vtiger_activity.eventstatus, vtiger_activity.activitytype,vtiger_activity.date_start,
 			vtiger_activity.due_date,vtiger_activity.time_start,vtiger_activity.time_end,
 			vtiger_crmentity.modifiedtime,vtiger_crmentity.createdtime,
 			vtiger_crmentity.description, $userNameSql as user_name,vtiger_groups.groupname
 				from vtiger_activity
 				inner join vtiger_seactivityrel on vtiger_seactivityrel.activityid=vtiger_activity.activityid
 				inner join vtiger_crmentity on vtiger_crmentity.crmid=vtiger_activity.activityid
-				left join vtiger_groups on vtiger_groups.groupid=vtiger_crmentity.smownerid 
+				left join vtiger_groups on vtiger_groups.groupid=vtiger_crmentity.smownerid
 				left join vtiger_users on vtiger_crmentity.smownerid= vtiger_users.id
 				where (vtiger_activity.activitytype != 'Emails')
 				and (vtiger_activity.status = 'Completed' or vtiger_activity.status = 'Deferred' or (vtiger_activity.eventstatus = 'Held' and vtiger_activity.eventstatus != ''))
 				and vtiger_seactivityrel.crmid=".$id."
 	                        and vtiger_crmentity.deleted = 0";
 		//Don't add order by, because, for security, one more condition will be added with this query in include/RelatedListView.php
-	
+
 		$log->debug("Exiting get_history method ...");
 		return getHistory('Leads',$query,$id);
 	}
-		
+
 	/**
-	* Function to get lead related Products 
+	* Function to get lead related Products
 	* @param  integer   $id      - leadid
 	* returns related Products record in array format
 	*/
@@ -430,18 +387,18 @@ class Leads extends CRMEntity {
         $related_module = vtlib_getModuleNameById($rel_tab_id);
 		require_once("modules/$related_module/$related_module.php");
 		$other = new $related_module();
-        vtlib_setup_modulevars($related_module, $other);		
+        vtlib_setup_modulevars($related_module, $other);
 		$singular_modname = vtlib_toSingular($related_module);
-		
+
 		$parenttab = getParentTab();
-		
+
 		if($singlepane_view == 'true')
 			$returnset = '&return_module='.$this_module.'&return_action=DetailView&return_id='.$id;
 		else
 			$returnset = '&return_module='.$this_module.'&return_action=CallRelatedList&return_id='.$id;
-		
+
 		$button = '';
-				
+
 		if($actions) {
 			if(is_string($actions)) $actions = explode(',', strtoupper($actions));
 			if(in_array('SELECT', $actions) && isPermitted($related_module,4, '') == 'yes') {
@@ -452,29 +409,33 @@ class Leads extends CRMEntity {
 					" onclick='this.form.action.value=\"EditView\";this.form.module.value=\"$related_module\"' type='submit' name='button'" .
 					" value='". getTranslatedString('LBL_ADD_NEW'). " " . getTranslatedString($singular_modname) ."'>&nbsp;";
 			}
-		} 
+		}
 
-		$query = "SELECT vtiger_products.productid, vtiger_products.productname, vtiger_products.productcode, 
-				vtiger_products.commissionrate, vtiger_products.qty_per_unit, vtiger_products.unit_price, 
-				vtiger_crmentity.crmid, vtiger_crmentity.smownerid 
-			   FROM vtiger_products 
-			   INNER JOIN vtiger_seproductsrel ON vtiger_products.productid = vtiger_seproductsrel.productid and vtiger_seproductsrel.setype = 'Leads'
-			   INNER JOIN vtiger_crmentity ON vtiger_crmentity.crmid = vtiger_products.productid 
-			   INNER JOIN vtiger_leaddetails ON vtiger_leaddetails.leadid = vtiger_seproductsrel.crmid  
+		$query = "SELECT vtiger_products.productid, vtiger_products.productname, vtiger_products.productcode,
+				vtiger_products.commissionrate, vtiger_products.qty_per_unit, vtiger_products.unit_price,
+				vtiger_crmentity.crmid, vtiger_crmentity.smownerid
+				FROM vtiger_products
+				INNER JOIN vtiger_seproductsrel ON vtiger_products.productid = vtiger_seproductsrel.productid and vtiger_seproductsrel.setype = 'Leads'
+				INNER JOIN vtiger_crmentity ON vtiger_crmentity.crmid = vtiger_products.productid
+				INNER JOIN vtiger_leaddetails ON vtiger_leaddetails.leadid = vtiger_seproductsrel.crmid
+				LEFT JOIN vtiger_users
+					ON vtiger_users.id=vtiger_crmentity.smownerid
+				LEFT JOIN vtiger_groups
+					ON vtiger_groups.groupid = vtiger_crmentity.smownerid
 			   WHERE vtiger_crmentity.deleted = 0 AND vtiger_leaddetails.leadid = $id";
-					
-		$return_value = GetRelatedList($this_module, $related_module, $other, $query, $button, $returnset); 
-		
+
+		$return_value = GetRelatedList($this_module, $related_module, $other, $query, $button, $returnset);
+
 		if($return_value == null) $return_value = Array();
 		$return_value['CUSTOM_BUTTON'] = $button;
-		
-		$log->debug("Exiting get_products method ...");		
+
+		$log->debug("Exiting get_products method ...");
 		return $return_value;
 	}
-	
+
 	/** Function to get the Combo List Values of Leads Field
-	 * @param string $list_option 
-	 * Returns Combo List Options 
+	 * @param string $list_option
+	 * Returns Combo List Options
 	*/
 	function get_lead_field_options($list_option)
 	{
@@ -484,7 +445,7 @@ class Leads extends CRMEntity {
 		$log->debug("Exiting get_lead_field_options method ...");
 		return $comboFieldArray[$list_option];
 	}
-	
+
 	/** Function to get the Columnnames of the Leads Record
 	* Used By vtigerCRM Word Plugin
 	* Returns the Merge Fields for Word Plugin
@@ -524,22 +485,22 @@ class Leads extends CRMEntity {
 	/**
 	 * Move the related records of the specified list of id's to the given record.
 	 * @param String This module name
-	 * @param Array List of Entity Id's from which related records need to be transfered 
+	 * @param Array List of Entity Id's from which related records need to be transfered
 	 * @param Integer Id of the the Record to which the related records are to be moved
 	 */
 	function transferRelatedRecords($module, $transferEntityIds, $entityId) {
 		global $adb,$log;
 		$log->debug("Entering function transferRelatedRecords ($module, $transferEntityIds, $entityId)");
-		
+
 		$rel_table_arr = Array("Activities"=>"vtiger_seactivityrel","Documents"=>"vtiger_senotesrel","Attachments"=>"vtiger_seattachmentsrel",
 					"Products"=>"vtiger_seproductsrel","Campaigns"=>"vtiger_campaignleadrel");
-		
+
 		$tbl_field_arr = Array("vtiger_seactivityrel"=>"activityid","vtiger_senotesrel"=>"notesid","vtiger_seattachmentsrel"=>"attachmentsid",
-					"vtiger_seproductsrel"=>"productid","vtiger_campaignleadrel"=>"campaignid");	
-		
+					"vtiger_seproductsrel"=>"productid","vtiger_campaignleadrel"=>"campaignid");
+
 		$entity_tbl_field_arr = Array("vtiger_seactivityrel"=>"crmid","vtiger_senotesrel"=>"crmid","vtiger_seattachmentsrel"=>"crmid",
 					"vtiger_seproductsrel"=>"crmid","vtiger_campaignleadrel"=>"leadid");
-		
+
 		foreach($transferEntityIds as $transferId) {
 			foreach($rel_table_arr as $rel_module=>$rel_table) {
 				$id_field = $tbl_field_arr[$rel_table];
@@ -552,35 +513,35 @@ class Leads extends CRMEntity {
 				if($res_cnt > 0) {
 					for($i=0;$i<$res_cnt;$i++) {
 						$id_field_value = $adb->query_result($sel_result,$i,$id_field);
-						$adb->pquery("update $rel_table set $entity_id_field=? where $entity_id_field=? and $id_field=?", 
-							array($entityId,$transferId,$id_field_value));	
+						$adb->pquery("update $rel_table set $entity_id_field=? where $entity_id_field=? and $id_field=?",
+							array($entityId,$transferId,$id_field_value));
 					}
-				}				
+				}
 			}
 		}
 		$log->debug("Exiting transferRelatedRecords...");
 	}
 
 	/*
-	 * Function to get the secondary query part of a report 
+	 * Function to get the secondary query part of a report
 	 * @param - $module primary module name
 	 * @param - $secmodule secondary module name
 	 * returns the query string formed on fetching the related data for report for secondary module
 	 */
 	function generateReportsSecQuery($module,$secmodule){
 		$query = $this->getRelationQuery($module,$secmodule,"vtiger_leaddetails","leadid");
-		$query .= " left join vtiger_crmentity as vtiger_crmentityLeads on vtiger_crmentityLeads.crmid = vtiger_leaddetails.leadid and vtiger_crmentityLeads.deleted=0 
-			left join vtiger_leadaddress on vtiger_leaddetails.leadid = vtiger_leadaddress.leadaddressid 
-			left join vtiger_leadsubdetails on vtiger_leadsubdetails.leadsubscriptionid = vtiger_leaddetails.leadid 
-			left join vtiger_leadscf on vtiger_leadscf.leadid = vtiger_leaddetails.leadid 
+		$query .= " left join vtiger_crmentity as vtiger_crmentityLeads on vtiger_crmentityLeads.crmid = vtiger_leaddetails.leadid and vtiger_crmentityLeads.deleted=0
+			left join vtiger_leadaddress on vtiger_leaddetails.leadid = vtiger_leadaddress.leadaddressid
+			left join vtiger_leadsubdetails on vtiger_leadsubdetails.leadsubscriptionid = vtiger_leaddetails.leadid
+			left join vtiger_leadscf on vtiger_leadscf.leadid = vtiger_leaddetails.leadid
 			left join vtiger_groups as vtiger_groupsLeads on vtiger_groupsLeads.groupid = vtiger_crmentityLeads.smownerid
-			left join vtiger_users as vtiger_usersLeads on vtiger_usersLeads.id = vtiger_crmentityLeads.smownerid ";
-
+			left join vtiger_users as vtiger_usersLeads on vtiger_usersLeads.id = vtiger_crmentityLeads.smownerid
+            left join vtiger_users as vtiger_lastModifiedByLeads on vtiger_lastModifiedByLeads.id = vtiger_crmentityLeads.modifiedby ";
 		return $query;
 	}
 
 	/*
-	 * Function to get the relation tables for related modules 
+	 * Function to get the relation tables for related modules
 	 * @param - $secmodule secondary module name
 	 * returns the array with table names and fieldnames storing relations between module and this module
 	 */
@@ -594,12 +555,12 @@ class Leads extends CRMEntity {
 		);
 		return $rel_tables[$secmodule];
 	}
-	
+
 	// Function to unlink an entity with given Id from another entity
 	function unlinkRelationship($id, $return_module, $return_id) {
 		global $log;
 		if(empty($return_module) || empty($return_id)) return;
-		
+
 		if($return_module == 'Campaigns') {
 			$sql = 'DELETE FROM vtiger_campaignleadrel WHERE leadid=? AND campaignid=?';
 			$this->db->pquery($sql, array($id, $return_id));
@@ -614,7 +575,37 @@ class Leads extends CRMEntity {
 		}
 	}
 	
-//End
+	function getListButtons($app_strings) {
+		$list_buttons = Array();
+
+		if(isPermitted('Leads','Delete','') == 'yes') {
+			$list_buttons['del'] =	$app_strings[LBL_MASS_DELETE];
+		}
+		if(isPermitted('Leads','EditView','') == 'yes') {
+			$list_buttons['mass_edit'] = $app_strings[LBL_MASS_EDIT];
+			$list_buttons['c_owner'] = $app_strings[LBL_CHANGE_OWNER];
+		}
+		if(isPermitted('Emails','EditView','') == 'yes')
+			$list_buttons['s_mail'] = $app_strings[LBL_SEND_MAIL_BUTTON];
+		
+		// end of mailer export
+		return $list_buttons;
+	}
+
+	function save_related_module($module, $crmid, $with_module, $with_crmids) {
+		$adb = PearDatabase::getInstance();
+
+		if(!is_array($with_crmids)) $with_crmids = Array($with_crmids);
+		foreach($with_crmids as $with_crmid) {
+			if($with_module == 'Products')
+				$adb->pquery("insert into vtiger_seproductsrel values (?,?,?)", array($crmid, $with_crmid, $module));
+			elseif($with_module == 'Campaigns')
+				$adb->pquery("insert into  vtiger_campaignleadrel values(?,?,1)", array($with_crmid, $crmid));
+			else {
+				parent::save_related_module($module, $crmid, $with_module, $with_crmid);
+			}
+		}
+	}
 
 }
 
