@@ -100,7 +100,7 @@ function get_available_module_picklist($picklist_details){
  * @param string $fieldName - the name of the field
  * @return array $arr - the array containing the picklist values 
  */
-function getAllPickListValues($fieldName){
+function getAllPickListValues($fieldName,$lang = Array() ){
 	global $adb;
 	$sql = 'SELECT * FROM vtiger_'.$adb->sql_escape_string($fieldName);
 	$result = $adb->query($sql);
@@ -108,7 +108,13 @@ function getAllPickListValues($fieldName){
 	
 	$arr = array();
 	for($i=0;$i<$count;$i++){
-		$arr[] = $adb->query_result($result, $i, $fieldName);
+		$pick_val = decode_html($adb->query_result($result, $i, $fieldName));
+		if($lang[$pick_val] != ''){
+			$arr[$pick_val] = $lang[$pick_val];
+		}
+		else{
+			$arr[$pick_val] = $pick_val;
+		}
 	}
 	return $arr;
 }
@@ -121,7 +127,7 @@ function getAllPickListValues($fieldName){
  * @param object $adb - the peardatabase object
  * @return array $pick - the editable picklist values
  */
-function getEditablePicklistValues($fieldName, $lang, $adb){
+function getEditablePicklistValues($fieldName, $lang= array(), $adb){
 	$values = array();
 	$fieldName = $adb->sql_escape_string($fieldName);
 	$sql="select $fieldName from vtiger_$fieldName where presence=1 and $fieldName <> '--None--'";
@@ -131,9 +137,9 @@ function getEditablePicklistValues($fieldName, $lang, $adb){
 		for($i=0;$i<$RowCount;$i++){
 			$pick_val = $adb->query_result($res,$i,$fieldName);
 			if($lang[$pick_val] != ''){
-				$values[]=$lang[$pick_val];
+				$values[$pick_val]=$lang[$pick_val];
 			}else{
-				$values[]=$pick_val;
+				$values[$pick_val]=$pick_val;
 			}
 		}
 	}
@@ -147,7 +153,7 @@ function getEditablePicklistValues($fieldName, $lang, $adb){
  * @param object $adb - the peardatabase object
  * @return array $pick - the no-editable picklist values
  */
-function getNonEditablePicklistValues($fieldName, $lang, $adb){
+function getNonEditablePicklistValues($fieldName, $lang=array(), $adb){
 	$values = array();
 	$fieldName = $adb->sql_escape_string($fieldName);
 	$sql = "select $fieldName from vtiger_$fieldName where presence=0";
@@ -174,7 +180,7 @@ function getNonEditablePicklistValues($fieldName, $lang, $adb){
  * @param object $adb - the peardatabase object
  * @return array $val - the assigned picklist values in array format
  */
-function getAssignedPicklistValues($tableName, $roleid, $adb){
+function getAssignedPicklistValues($tableName, $roleid, $adb, $lang=array()){
 	$arr = array();
 	
 	$sub = getSubordinateRoleAndUsers($roleid);
@@ -200,7 +206,13 @@ function getAssignedPicklistValues($tableName, $roleid, $adb){
 		
 		if($count) {
 			while($resultrow = $adb->fetch_array($result)) {
-				$arr[] = $resultrow[$tableName];
+				$pick_val = decode_html($resultrow[$tableName]);
+				if($lang[$pick_val] != '') {
+					$arr[$pick_val] = $lang[$pick_val];
+				}
+				else {
+					$arr[$pick_val] = $pick_val;
+				}
 			}
 		}
 	}
