@@ -10,13 +10,12 @@
 require_once('include/database/PearDatabase.php');
 @include_once('user_privileges/default_module_view.php');
 
-global $adb, $singlepane_view, $currentModule;
+global $singlepane_view, $currentModule;
 $idlist = vtlib_purify($_REQUEST['idlist']);
 $dest_mod = vtlib_purify($_REQUEST['destination_module']);
 $parenttab = getParentTab();
 
 $forCRMRecord = vtlib_purify($_REQUEST['parentid']);
-$mode = $_REQUEST['mode'];
 
 if($singlepane_view == 'true')
 	$action = "DetailView";
@@ -31,22 +30,8 @@ if(!empty($_REQUEST['idlist'])) {
 	$storearray = array($_REQUEST['entityid']);
 }
 $focus = CRMEntity::getInstance($currentModule);
-foreach($storearray as $id)
-{
-	if($id != '')
-	{
-		if($dest_mod == 'Documents')
-			$adb->pquery("insert into vtiger_senotesrel values (?,?)", array($forCRMRecord, $id));
-		elseif($dest_mod =='Leads' || $dest_mod =='Accounts' ||$dest_mod =='Contacts' ||$dest_mod =='Potentials' || $dest_mod=='Products'){
-			$query = $adb->pquery("SELECT * from vtiger_seproductsrel WHERE crmid=? and productid=?",array($forCRMRecord,$id));
-			if($adb->num_rows($query)==0){
-				$adb->pquery("insert into vtiger_seproductsrel values (?,?,?)", array($id, $forCRMRecord, $dest_mod));
-			}
-		}
-		else {
-			$focus->save_related_module($currentModule, $forCRMRecord, $dest_mod, $id);
-		}
-	}
+if(!empty($storearray)) {
+	relateEntities($focus, $currentModule, $forCRMRecord, $dest_mod, $storearray);
 }
 
 header("Location: index.php?action=$action&module=$currentModule&record=".$forCRMRecord."&parenttab=".$parenttab);
