@@ -61,6 +61,8 @@ $smarty->assign("UPDATEINFO",updateInfo($focus->id));
 
 $smarty->assign("CUSTOMFIELD", $cust_fld);
 $smarty->assign("ID", vtlib_purify($_REQUEST['record']));
+$quote_no = getModuleSequenceNumber($currentModule,vtlib_purify($_REQUEST['record']));
+$smarty->assign("QUO_NO",$quote_no);
 
 // Module Sequence Numbering
 $mod_seq_field = getModuleSequenceField($currentModule);
