@@ -9,13 +9,13 @@
  *
  ********************************************************************************/
 include_once 'modules/Quotes/QuotePDFController.php';
-
 $controller = new Vtiger_QuotePDFController($currentModule);
 $controller->loadRecord(vtlib_purify($_REQUEST['record']));
 
 $filenameid = $_REQUEST['record'];
+$quote_no = getModuleSequenceNumber($currentModule,vtlib_purify($_REQUEST['record']));
 if(empty($filenameid)) $filenameid = time();
-$filepath="storage/Quote_$filenameid.pdf";
+$filepath="storage/Quote_".$quote_no.".pdf";
 //added file name to make it work in IE, also forces the download giving the user the option to save
 $controller->Output($filepath,'F');
 
