@@ -12,6 +12,7 @@ require_once('include/logging.php');
 require_once('include/database/PearDatabase.php');
 require_once("include/Zend/Json.php");
 require_once 'modules/Reports/ReportUtils.php';
+require_once('modules/Reports/CustomReportUtils.php');
 
 global $adb;
 global $log,$current_user;
@@ -28,6 +29,13 @@ $sort_by2 =decode_html(vtlib_purify($_REQUEST["Group2"]));
 $sort_order2 = vtlib_purify($_REQUEST["Sort2"]);
 $sort_by3 = decode_html(vtlib_purify($_REQUEST["Group3"]));
 $sort_order3 = vtlib_purify($_REQUEST["Sort3"]);
+
+//<<<<<<<reportgrouptime>>>>>>>
+$groupTime1 = vtlib_purify($_REQUEST['groupbytime1']);
+$groupTime2 = vtlib_purify($_REQUEST['groupbytime2']);
+$groupTime3 = vtlib_purify($_REQUEST['groupbytime3']);
+//<<<<<<<reportgrouptime>>>>>>>
+
 //<<<<<<<reportsortcol>>>>>>>>>
 $selectedcolumns = explode(";",$selectedcolumnstring);
 if(!in_array($sort_by1,$selectedcolumns)){
@@ -54,8 +62,17 @@ $folderid = vtlib_purify($_REQUEST["folder"]);
 //<<<<<<<standarfilters>>>>>>>>>
 $stdDateFilterField = vtlib_purify($_REQUEST["stdDateFilterField"]);
 $stdDateFilter = vtlib_purify($_REQUEST["stdDateFilter"]);
-$startdate = DateTimeField::convertToDBFormat($_REQUEST["startdate"]);
-$enddate = DateTimeField::convertToDBFormat($_REQUEST["enddate"]);
+$startdate = $_REQUEST["startdate"];
+$enddate = $_REQUEST["enddate"];
+$dbCurrentDateTime = new DateTimeField(date('Y-m-d H:i:s'));
+if(!empty($startdate)) {
+	$startDateTime = new DateTimeField($startdate.' '. $dbCurrentDateTime->getDisplayTime());
+	$startdate = $startDateTime->getDBInsertDateValue();
+}
+if(!empty($enddate)) {
+	$endDateTime = new DateTimeField($enddate.' '. $dbCurrentDateTime->getDisplayTime());
+	$enddate = $endDateTime->getDBInsertDateValue();
+}
 //<<<<<<<standardfilters>>>>>>>>>
 
 //<<<<<<<shared entities>>>>>>>>>
@@ -148,16 +165,28 @@ if($reportid == "")
 					{
 						$sort_by1sql = "insert into vtiger_reportsortcol (SORTCOLID,REPORTID,COLUMNNAME,SORTORDER) values (?,?,?,?)";
 						$sort_by1result = $adb->pquery($sort_by1sql, array(1, $genQueryId, $sort_by1, $sort_order1));
+						if(CustomReportUtils::IsDateField($sort_by1)){
+							$groupByTime1Sql = "INSERT INTO vtiger_reportgroupbycolumn(REPORTID,SORTID,SORTCOLNAME,DATEGROUPBYCRITERIA) values(?,?,?,?)";
+							$groupByTime1Res = $adb->pquery($groupByTime1Sql,array($genQueryId,1,$sort_by1,$groupTime1));
+						}
 					}
 					if($sort_by2 != "")
 					{
 						$sort_by2sql = "insert into vtiger_reportsortcol (SORTCOLID,REPORTID,COLUMNNAME,SORTORDER) values (?,?,?,?)";
 						$sort_by2result = $adb->pquery($sort_by2sql, array(2,$genQueryId,$sort_by2,$sort_order2));
+						if(CustomReportUtils::IsDateField($sort_by2)){
+                            $groupByTime2Sql = "INSERT INTO vtiger_reportgroupbycolumn(REPORTID,SORTID,SORTCOLNAME,DATEGROUPBYCRITERIA) values(?,?,?,?)";
+                            $groupByTime2Res = $adb->pquery($groupByTime2Sql,array($genQueryId,2,$sort_by2,$groupTime2));
+                        }
 					}
 					if($sort_by3 != "")
 					{
 						$sort_by3sql = "insert into vtiger_reportsortcol (SORTCOLID,REPORTID,COLUMNNAME,SORTORDER) values (?,?,?,?)";
 						$sort_by3result = $adb->pquery($sort_by3sql, array(3,$genQueryId,$sort_by3,$sort_order3));
+						if(CustomReportUtils::IsDateField($sort_by3)){
+                            $groupByTime3Sql = "INSERT INTO vtiger_reportgroupbycolumn(REPORTID,SORTID,SORTCOLNAME,DATEGROUPBYCRITERIA) values(?,?,?,?)";
+                            $groupByTime3Res = $adb->pquery($groupByTime3Sql,array($genQueryId,3,$sort_by3,$groupTime3));
+                        }
 					}
 					$log->info("Reports :: Save->Successfully saved vtiger_reportsortcol");
 					//<<<<step3 vtiger_reportsortcol>>>>>>>
@@ -177,17 +206,17 @@ if($reportid == "")
 					$log->info("Reports :: Save->Successfully saved vtiger_reportsummary");
 					//<<<<step4 columnstototal>>>>>>>
 
-					//<<<<step5 advancedfilter>>>>>>>					
+					//<<<<step5 advancedfilter>>>>>>>
 					foreach($advft_criteria as $column_index => $column_condition) {
-						
+
 						if(empty($column_condition)) continue;
-						
+
 						$adv_filter_column = $column_condition["columnname"];
 						$adv_filter_comparator = $column_condition["comparator"];
 						$adv_filter_value = $column_condition["value"];
 						$adv_filter_column_condition = $column_condition["columncondition"];
 						$adv_filter_groupid = $column_condition["groupid"];
-					
+
 						$column_info = explode(":",$adv_filter_column);
 						$moduleFieldLabel = $column_info[2];
 						$fieldName = $column_info[3];
@@ -199,7 +228,7 @@ if($reportid == "")
 							$field = WebserviceField::fromArray($adb, $fieldInfo);
 							$fieldType = $field->getFieldDataType();
 						}
-						
+
 						if($fieldType == 'currency') {
 							if($field->getUIType() == '71') {
 								$adv_filter_value = CurrencyField::convertToDBFormat($adv_filter_value, null, true);
@@ -207,7 +236,7 @@ if($reportid == "")
 								$adv_filter_value = CurrencyField::convertToDBFormat($adv_filter_value);
 							}
 						}
-						
+
 						$temp_val = explode(",",$adv_filter_value);
 						if(($column_info[4] == 'D' || ($column_info[4] == 'T' && $column_info[1] != 'time_start' && $column_info[1] != 'time_end') || ($column_info[4] == 'DT')) && ($column_info[4] != '' && $adv_filter_value != '' ))
 						{
@@ -216,7 +245,7 @@ if($reportid == "")
 								if(trim($temp_val[$x]) != '') {
 									$date = new DateTimeField(trim($temp_val[$x]));
 									if($column_info[4] == 'D') {
-										$val[$x] = DateTimeField::convertToUserFormat(
+										$val[$x] = DateTimeField::convertToDBFormat(
 												trim($temp_val[$x]));
 									} elseif($column_info[4] == 'DT') {
 										$val[$x] = $date->getDBInsertDateTimeValue();
@@ -230,7 +259,7 @@ if($reportid == "")
 
 						$irelcriteriasql = "insert into vtiger_relcriteria(QUERYID,COLUMNINDEX,COLUMNNAME,COMPARATOR,VALUE,GROUPID,COLUMN_CONDITION) values (?,?,?,?,?,?,?)";
 						$irelcriteriaresult = $adb->pquery($irelcriteriasql, array($genQueryId, $column_index, $adv_filter_column, $adv_filter_comparator, $adv_filter_value, $adv_filter_groupid, $adv_filter_column_condition));
-					
+
 						// Update the condition expression for the group to which the condition column belongs
 						$groupConditionExpression = '';
 						if(!empty($advft_criteria_groups[$adv_filter_groupid]["conditionexpression"])) {
@@ -239,12 +268,12 @@ if($reportid == "")
 						$groupConditionExpression = $groupConditionExpression .' '. $column_index .' '. $adv_filter_column_condition;
 						$advft_criteria_groups[$adv_filter_groupid]["conditionexpression"] = $groupConditionExpression;
 					}
-			
-					foreach($advft_criteria_groups as $group_index => $group_condition_info) {				
-						
+
+					foreach($advft_criteria_groups as $group_index => $group_condition_info) {
+
 						if(empty($group_condition_info)) continue;
 						if(empty($group_condition_info["conditionexpression"])) continue; // Case when the group doesn't have any column criteria
-						
+
 						$irelcriteriagroupsql = "insert into vtiger_relcriteria_grouping(GROUPID,QUERYID,GROUP_CONDITION,CONDITION_EXPRESSION) values (?,?,?,?)";
 						$irelcriteriagroupresult = $adb->pquery($irelcriteriagroupsql, array($group_index, $genQueryId, $group_condition_info["groupcondition"], $group_condition_info["conditionexpression"]));
 					}
@@ -307,13 +336,13 @@ if($reportid == "")
 				$icolumnsqlresult = $adb->pquery($icolumnsql, array($reportid,$temp[1],$temp[0]));
 			}
 		}
-		
+
 		//<<<<reportmodules>>>>>>>
 		$ireportmodulesql = "UPDATE vtiger_reportmodules SET primarymodule=?,secondarymodules=? WHERE reportmodulesid=?";
 		$ireportmoduleresult = $adb->pquery($ireportmodulesql, array($pmodule, $smodule,$reportid));
 		$log->info("Reports :: Save->Successfully saved vtiger_reportmodules");
 		//<<<<reportmodules>>>>>>>
-		
+
 		$ireportsql = "update vtiger_report set REPORTNAME=?, DESCRIPTION=?, REPORTTYPE=?, SHARINGTYPE=? where REPORTID=?";
 		$ireportparams = array($reportname, $reportdescription, $reporttype, $sharetype, $reportid);
 		$ireportresult = $adb->pquery($ireportsql, $ireportparams);
@@ -321,6 +350,9 @@ if($reportid == "")
 
 		$idelreportsortcolsql = "delete from vtiger_reportsortcol where reportid=?";
 		$idelreportsortcolsqlresult = $adb->pquery($idelreportsortcolsql, array($reportid));
+		$delReportGroupTimeSQL = "DELETE FROM vtiger_reportgroupbycolumn WHERE reportid=?";
+        $delReportGroupTimeRES = $adb->pquery($delReportGroupTimeSQL,array($reportid));
+		
 		$log->info("Reports :: Save->Successfully deleted vtiger_reportsortcol");
 
 		if($idelreportsortcolsqlresult!=false)
@@ -330,16 +362,28 @@ if($reportid == "")
 			{
 				$sort_by1sql = "insert into vtiger_reportsortcol (SORTCOLID,REPORTID,COLUMNNAME,SORTORDER) values (?,?,?,?)";
 				$sort_by1result = $adb->pquery($sort_by1sql, array(1, $reportid, $sort_by1, $sort_order1));
+				if(CustomReportUtils::IsDateField($sort_by1)){
+                    $groupByTime1Sql = "INSERT INTO vtiger_reportgroupbycolumn(REPORTID,SORTID,SORTCOLNAME,DATEGROUPBYCRITERIA) values(?,?,?,?)";
+                    $groupByTime1Res = $adb->pquery($groupByTime1Sql,array($reportid,1,$sort_by1,$groupTime1));
+                }
 			}
 			if($sort_by2 != "")
 			{
 				$sort_by2sql = "insert into vtiger_reportsortcol (SORTCOLID,REPORTID,COLUMNNAME,SORTORDER) values (?,?,?,?)";
 				$sort_by2result = $adb->pquery($sort_by2sql, array(2, $reportid, $sort_by2, $sort_order2));
+				if(CustomReportUtils::IsDateField($sort_by2)){
+		            $groupByTime2Sql = "INSERT INTO vtiger_reportgroupbycolumn(REPORTID,SORTID,SORTCOLNAME,DATEGROUPBYCRITERIA) values(?,?,?,?)";
+		            $groupByTime2Res = $adb->pquery($groupByTime2Sql,array($reportid,2,$sort_by2,$groupTime2));
+		        }
 			}
 			if($sort_by3 != "")
 			{
 				$sort_by3sql = "insert into vtiger_reportsortcol (SORTCOLID,REPORTID,COLUMNNAME,SORTORDER) values (?,?,?,?)";
 				$sort_by3result = $adb->pquery($sort_by3sql, array(3, $reportid, $sort_by3, $sort_order3));
+				if(CustomReportUtils::IsDateField($sort_by3)){
+                    $groupByTime3Sql = "INSERT INTO vtiger_reportgroupbycolumn(REPORTID,SORTID,SORTCOLNAME,DATEGROUPBYCRITERIA) values(?,?,?,?)";
+                    $groupByTime3Res = $adb->pquery($groupByTime3Sql,array($reportid,3,$sort_by3,$groupTime3));
+                }
 			}
 			$log->info("Reports :: Save->Successfully saved vtiger_reportsortcol");
 			//<<<<step3 vtiger_reportsortcol>>>>>>>
@@ -373,17 +417,17 @@ if($reportid == "")
 
 			$idelrelcriteriagroupsql = "delete from vtiger_relcriteria_grouping where queryid=?";
 			$idelrelcriteriagroupsqlresult = $adb->pquery($idelrelcriteriagroupsql, array($reportid));
-			
+
 			foreach($advft_criteria as $column_index => $column_condition) {
-						
+
 				if(empty($column_condition)) continue;
-						
+
 				$adv_filter_column = $column_condition["columnname"];
 				$adv_filter_comparator = $column_condition["comparator"];
 				$adv_filter_value = $column_condition["value"];
 				$adv_filter_column_condition = $column_condition["columncondition"];
 				$adv_filter_groupid = $column_condition["groupid"];
-			
+
 				$column_info = explode(":",$adv_filter_column);
 				$moduleFieldLabel = $column_info[2];
 				$fieldName = $column_info[3];
@@ -404,7 +448,7 @@ if($reportid == "")
 						$adv_filter_value = CurrencyField::convertToDBFormat($adv_filter_value);
 					}
 				}
-				
+
 				$temp_val = explode(",",$adv_filter_value);
 				if(($column_info[4] == 'D' || ($column_info[4] == 'T' && $column_info[1] != 'time_start' && $column_info[1] != 'time_end') || ($column_info[4] == 'DT')) && ($column_info[4] != '' && $adv_filter_value != '' ))
 				{
@@ -413,7 +457,7 @@ if($reportid == "")
 						if(trim($temp_val[$x]) != '') {
 							$date = new DateTimeField(trim($temp_val[$x]));
 							if($column_info[4] == 'D') {
-								$val[$x] = DateTimeField::convertToUserFormat(
+								$val[$x] = DateTimeField::convertToDBFormat(
 										trim($temp_val[$x]));
 							} elseif($column_info[4] == 'DT') {
 								$val[$x] = $date->getDBInsertDateTimeValue();
@@ -427,7 +471,7 @@ if($reportid == "")
 
 				$irelcriteriasql = "insert into vtiger_relcriteria(QUERYID,COLUMNINDEX,COLUMNNAME,COMPARATOR,VALUE,GROUPID,COLUMN_CONDITION) values (?,?,?,?,?,?,?)";
 				$irelcriteriaresult = $adb->pquery($irelcriteriasql, array($reportid, $column_index, $adv_filter_column, $adv_filter_comparator, $adv_filter_value, $adv_filter_groupid, $adv_filter_column_condition));
-			
+
 				// Update the condition expression for the group to which the condition column belongs
 				$groupConditionExpression = '';
 				if(!empty($advft_criteria_groups[$adv_filter_groupid]["conditionexpression"])) {
@@ -436,12 +480,12 @@ if($reportid == "")
 				$groupConditionExpression = $groupConditionExpression .' '. $column_index .' '. $adv_filter_column_condition;
 				$advft_criteria_groups[$adv_filter_groupid]["conditionexpression"] = $groupConditionExpression;
 			}
-			
-			foreach($advft_criteria_groups as $group_index => $group_condition_info) {				
-						
+
+			foreach($advft_criteria_groups as $group_index => $group_condition_info) {
+
 				if(empty($group_condition_info)) continue;
 				if(empty($group_condition_info["conditionexpression"])) continue; // Case when the group doesn't have any column criteria
-									
+
 				$irelcriteriagroupsql = "insert into vtiger_relcriteria_grouping(GROUPID,QUERYID,GROUP_CONDITION,CONDITION_EXPRESSION) values (?,?,?,?)";
 				$irelcriteriagroupresult = $adb->pquery($irelcriteriagroupsql, array($group_index, $reportid, $group_condition_info["groupcondition"], $group_condition_info["conditionexpression"]));
 			}
@@ -464,7 +508,7 @@ if($reportid == "")
 				}
 			}
 			//<<<<step7 scheduledReport>>>>>>>
-			
+
 		}else
 		{
 			$errormessage = "<font color='red'><B>Error Message<ul>
