@@ -1,12 +1,11 @@
 <?php
-/*********************************************************************************
-** The contents of this file are subject to the vtiger CRM Public License Version 1.0
+/*+********************************************************************************
+ * The contents of this file are subject to the vtiger CRM Public License Version 1.0
  * ("License"); You may not use this file except in compliance with the License
  * The Original Code is:  vtiger CRM Open Source
  * The Initial Developer of the Original Code is vtiger.
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
-*
  ********************************************************************************/
 require_once('modules/Reports/Reports.php');
 require_once('include/logging.php');
@@ -17,34 +16,28 @@ global $default_charset;
 $local_log =& LoggerManager::getLogger('index');
 $focus = new Reports();
 
-$rfid = $_REQUEST['record'];
-$mode = $_REQUEST['savemode'];
-$foldername = $_REQUEST["foldername"];
+$rfid = vtlib_purify($_REQUEST['record']);
+$mode = vtlib_purify($_REQUEST['savemode']);
+$foldername = vtlib_purify($_REQUEST["foldername"]);
 $foldername = function_exists(iconv) ? @iconv("UTF-8",$default_charset, $foldername) : $foldername;
-$folderdesc = $_REQUEST["folderdesc"];
+$folderdesc = vtlib_purify($_REQUEST["folderdesc"]);
 $foldername = str_replace('*amp*','&',$foldername);
 $folderdesc = str_replace('*amp*','&',$folderdesc);
-/*if($foldername =="")
-{
-	echo "Please Enter valid Name";
-//	header("Location: index.php?action=ReportsAjax&file=ListView&mode=ajax&module=Reports");
 
-}
-else*/
 if($mode=="Save")
 {
 	if($rfid=="")
 	{
 		$sql = "INSERT INTO vtiger_reportfolder ";
-		$sql .= "(FOLDERID,FOLDERNAME,DESCRIPTION,STATE) VALUES (?,?,?,?)";
-		$sql_params = array('', trim($foldername), $folderdesc,'CUSTOMIZED');
+		$sql .= "(FOLDERNAME,DESCRIPTION,STATE) VALUES (?,?,?)";
+		$sql_params = array(trim($foldername), $folderdesc,'CUSTOMIZED');
 		$result = $adb->pquery($sql, $sql_params);
 		if($result!=false)
 		{
 			header("Location: index.php?action=ReportsAjax&file=ListView&mode=ajax&module=Reports");
 		}else
 		{
-			include('themes/'.$theme.'/header.php');
+			include('modules/Vtiger/header.php');
 			$errormessage = "<font color='red'><B>Error Message<ul>
 			<li><font color='red'>Error while inserting the record</font>
 			</ul></B></font> <br>" ;
@@ -64,7 +57,7 @@ if($mode=="Save")
 			header("Location: index.php?action=ReportsAjax&file=ListView&mode=ajax&module=Reports");
 		}else
 		{
-			include('themes/'.$theme.'/header.php');
+			include('modules/Vtiger/header.php');
 			$errormessage = "<font color='red'><B>Error Message<ul>
 			<li><font color='red'>Error while updating the record</font>
 			</ul></B></font> <br>" ;
@@ -72,6 +65,5 @@ if($mode=="Save")
 		}   
 	}
 }
-
-   	
-?>
+ 	
+?>
\ No newline at end of file
