@@ -15,7 +15,7 @@ global $mod_strings,$app_strings,$app_list_strings,$theme,$adb,$log;
 
 $theme_path="themes/".$theme."/";
 
-require_once($theme_path.'layout_utils.php');
+require_once('modules/Vtiger/layout_utils.php');
 
 $tabid=vtlib_purify($_REQUEST['tabid']);
 $blockid=vtlib_purify($_REQUEST['blockid']);
