@@ -11,6 +11,7 @@
 
 require_once('modules/Settings/MailScanner/core/MailScannerInfo.php');
 require_once('Smarty_setup.php');
+require_once('vtlib/Vtiger/Cron.php');
 
 global $app_strings, $mod_strings, $currentModule, $theme, $current_language;
 global $application_unique_key; // defined in config.inc.php
@@ -26,6 +27,7 @@ $scanners = Vtiger_MailScannerInfo::listAll();
 
 $smarty->assign("SCANNERS", $scanners);
 $smarty->assign("APP_KEY", $application_unique_key);
+$smarty->assign("CRON_TASK", Vtiger_Cron::getInstance('MailScanner'));
 
 $smarty->display('MailScanner/MailScannerInfo.tpl');
 
