@@ -10,12 +10,13 @@
  ********************************************************************************/
 
 require_once('include/database/PearDatabase.php');
-global $adb;
+require_once('include/utils/VtlibUtils.php');
 
+global $adb;
 if(isset($_REQUEST['record']) && $_REQUEST['record']!='')
 {
-	$query="UPDATE vtiger_inventorynotification set notificationsubject=?, notificationbody=? where notificationid=?";
-	$params = array($_REQUEST['notifysubject'], $_REQUEST['notifybody'], $_REQUEST['record']);
+	$query="UPDATE vtiger_inventorynotification set notificationsubject=?, notificationbody=?, status=?  where notificationid=?";
+	$params = array(vtlib_purify($_REQUEST['notifysubject']), vtlib_purify($_REQUEST['notifybody']), vtlib_purify($_REQUEST['status']), vtlib_purify($_REQUEST['record']) );
 	$adb->pquery($query, $params);	
 }
 $loc = "Location: index.php?action=SettingsAjax&file=listinventorynotifications&module=Settings&directmode=ajax";
