@@ -9,11 +9,12 @@
 *
  ********************************************************************************/
 require_once('Smarty_setup.php');
+require_once 'include/utils/utils.php';
 global $mod_strings;
 global $app_strings;
 global $app_list_strings;
 
-global $theme;
+global $theme, $adb;
 $theme_path="themes/".$theme."/";
 $image_path=$theme_path."images/";
 
@@ -22,6 +23,12 @@ $smarty->assign("APP", $app_strings);
 $smarty->assign("MODULE", 'Settings');
 $smarty->assign("CATEGORY", 'Settings');
 $smarty->assign("MOD", $mod_strings);
+$smarty->assign("THEME", $theme);
 $smarty->assign("IMAGE_PATH", $image_path);
+$smarty->assign("IMAGES", "themes/images/");
+$smarty->assign("BLOCKS", getSettingsBlocks());
+$smarty->assign("FIELDS", getSettingsFields());
+$smarty->assign("NUMBER_OF_COLUMNS", 4);	//this is the number of columns in the settings page
+
 $smarty->display("Settings.tpl");
 ?>
