@@ -173,19 +173,19 @@ function verify_data(form) {
 		return false;
 	}
 	form.email1.value = trim(form.email1.value);
-	if (form.email1.value != "" && !/^\w+([!"#$%&'()*+,./:;<=>?@\^_`{|}~-]?\w+)*@\w+([\.-]?\w+)*(\.\w{2,4})+$/.test(form.email1.value)) {
+	if (form.email1.value != "" && !/^[a-zA-Z0-9]+([!"#$%&'()*+,./:;<=>?@\^_`{|}~-]?[a-zA-Z0-9])*@[a-zA-Z0-9]+([\_\-\.]?[a-zA-Z0-9]+)*\.([\-\_]?[a-zA-Z0-9])+(\.?[a-zA-Z0-9]+)?$/.test(form.email1.value)) {
 		alert("$the_emailid"+form.email1.value+"$email_field_is");
 		form.email1.focus();
 		return false;
 	}
 	form.email2.value = trim(form.email2.value);
-	if (form.email2.value != "" && !/^\w+([!"#$%&'()*+,./:;<=>?@\^_`{|}~-]?\w+)*@\w+([\.-]?\w+)*(\.\w{2,4})+$/.test(form.email2.value)) {
+	if (form.email2.value != "" && !/^[a-zA-Z0-9]+([!"#$%&'()*+,./:;<=>?@\^_`{|}~-]?[a-zA-Z0-9])*@[a-zA-Z0-9]+([\_\-\.]?[a-zA-Z0-9]+)*\.([\-\_]?[a-zA-Z0-9])+(\.?[a-zA-Z0-9]+)?$/.test(form.email2.value)) {
 		alert("$the_emailid"+form.email2.value+"$other_email_field_is");
 		form.email2.focus();
 		return false;
 	}
 	form.secondaryemail.value = trim(form.secondaryemail.value); 
-	if (form.secondaryemail.value != "" && !/^\w+([!"#$%&'()*+,./:;<=>?@\^_`{|}~-]?\w+)*@\w+([\.-]?\w+)*(\.\w{2,4})+$/.test(form.secondaryemail.value)){
+	if (form.secondaryemail.value != "" && !/^[a-zA-Z0-9]+([!"#$%&'()*+,./:;<=>?@\^_`{|}~-]?[a-zA-Z0-9])*@[a-zA-Z0-9]+([\_\-\.]?[a-zA-Z0-9]+)*\.([\-\_]?[a-zA-Z0-9])+(\.?[a-zA-Z0-9]+)?$/.test(form.secondaryemail.value)){
 		alert("$the_emailid"+form.secondaryemail.value+"$secondary_email_field_is");
 		form.secondaryemail.focus();
 		return false;
