@@ -22,9 +22,13 @@ if(isset($_REQUEST['templateid']) && $_REQUEST['templateid'] !='')
 <?php echo htmlentities($templatedetails[1], ENT_NOQUOTES, $default_charset); ?>
 </textarea>
 </form>
-<script language="javascript">
-window.opener.document.getElementById('subject').value = window.document.frmrepstr.subject.value
-window.opener.document.getElementById('description').value = window.document.frmrepstr.repstr.value
-window.opener.oFCKeditor.ReplaceTextarea();
+<script type="text/javascript">
+//my changes
+if(typeof window.opener.document.getElementById('subject') != 'undefined' &&
+	window.opener.document.getElementById('subject') != null){
+	window.opener.document.getElementById('subject').value = window.document.frmrepstr.subject.value;
+	window.opener.document.getElementById('description').value = window.document.frmrepstr.repstr.value;
+	window.opener.oCKeditor.setData(window.document.frmrepstr.repstr.value);
+}
 window.close();
 </script>
